Package: metalite.sl
Title: Subject-Level Analysis Using 'metalite'
Version: 0.1.3
Authors@R: c(
    person("Yujie", "Zhao", email = "yujie.zhao@merck.com", role = c("aut", "cre")),
    person("Benjamin", "Wang", email = "benjamin.wang@merck.com", role = "aut"),
    person("Hiroaki", "Fukuda", role = "aut"),
    person("PoYao", "Niu", role = "aut"),
    person("Nan", "Xiao", role = "aut"),
    person("Jeetener", "Chauhan", role = "ctb"),
    person("Li", "Ma", role = "ctb"),
    person("Chen", "Wang", role = "ctb"),
    person("Merck Sharp & Dohme Corp", role = "cph")
    )
Description: Analyzes subject-level data in clinical trials using the 'metalite'
    data structure. The package simplifies the workflow to create
    production-ready tables, listings, and figures discussed in the
    subject-level analysis chapters of
    "R for Clinical Study Reports and Submission"
    by Zhang et al. (2022) <https://r4csr.org/>.
Depends: R (>= 4.1.0)
License: GPL (>= 3)
URL: https://merck.github.io/metalite.sl/,
        https://github.com/Merck/metalite.sl
Imports: glue, metalite, metalite.ae, r2rtf, reactable, stringr, rlang,
        plotly, htmltools, brew, uuid, htmlwidgets
Suggests: dplyr, knitr, testthat (>= 3.0.0), tidyr
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
LazyData: true
NeedsCompilation: no
Packaged: 2026-08-26 13:43:10 UTC; zhayuji4
Author: Yujie Zhao [aut, cre],
  Benjamin Wang [aut],
  Hiroaki Fukuda [aut],
  PoYao Niu [aut],
  Nan Xiao [aut],
  Jeetener Chauhan [ctb],
  Li Ma [ctb],
  Chen Wang [ctb],
  Merck Sharp & Dohme Corp [cph]
Maintainer: Yujie Zhao <yujie.zhao@merck.com>
Repository: CRAN
Date/Publication: 2026-08-26 14:50:02 UTC

# Generated by roxygen2: do not edit by hand

export(collect_baseline)
export(defmt_pct)
export(extend_exp_duration)
export(format_base_char)
export(format_base_char_subgroup)
export(format_disposition)
export(format_exp_duration)
export(format_sl_summary)
export(format_trt_compliance)
export(meta_sl)
export(plotly_exp_duration)
export(prepare_base_char)
export(prepare_base_char_subgroup)
export(prepare_disposition)
export(prepare_exp_duration)
export(prepare_sl_summary)
export(prepare_trt_compliance)
export(react_base_char)
export(react_disposition)
export(rtf_base_char)
export(rtf_base_char_subgroup)
export(rtf_disposition)
export(rtf_exp_duration)
export(rtf_sl_summary)
export(rtf_trt_compliance)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(stats,reshape)

# metalite.sl <img src="man/figures/logo.png" align="right" width="120" />

<!-- badges: start -->
[![Codecov test coverage](https://codecov.io/gh/Merck/metalite.sl/branch/main/graph/badge.svg)](https://app.codecov.io/gh/Merck/metalite.sl?branch=main)
[![R-CMD-check](https://github.com/Merck/metalite.sl/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/Merck/metalite.sl/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

## Overview

R package designed for the analysis & reporting of subject baseline characteristics in clinical trials.
We assume ADaM datasets are ready for analysis and
leverage [metalite](https://merck.github.io/metalite/) data structure to define
inputs and outputs.

## Workflow

The general workflow is:

1. Define metadata information using metalite.
2. `prepare_sl_summary()` prepares datasets for summary of baseline characteristics.
3. `format_base_char()` formats output layout.
4. `rtf_base_char()` creates TLFs.

Here is a quick example

```r
library("metalite.sl")

metadata_sl <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char",
    population = "apat",
    observation = "apat",
    parameter = "age;gender"
  )) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  metalite::define_parameter(
    name = "gender",
    var = "SEX",
    label = "Gender"
  ) |>
  metalite::define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group"
  ) |>
  metalite::meta_build()

metadata_sl |>
  prepare_sl_summary(
    population = "apat",
    analysis = "base_char",
    parameter = "age;gender"
  ) |>
  format_base_char() |>
  rtf_base_char(
    source = "Source: [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = tempfile(fileext = ".rtf")
  )
```

## Highlighted features

- Avoid duplicated input by using metadata structure.
  - For example, define analysis population once to use in all adverse events analysis.
- Consistent input and output in standard functions.
- Streamlines mock table generation.

## -----------------------------------------------------------------------------
library(metalite)
library(metalite.sl)

## ----out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"----
knitr::include_graphics("pdf/exp0duration.pdf")

## -----------------------------------------------------------------------------
adsl <- r2rtf::r2rtf_adsl
adexsum <- data.frame(USUBJID = adsl$USUBJID)
adexsum$TRTA <- factor(adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

adexsum$APERIODC <- "Base"
adexsum$APERIOD <- 1

set.seed(123) # Set a seed for reproducibility
adexsum$AVAL <- sample(x = 0:(24 * 7), size = length(adexsum$USUBJID), replace = TRUE)
adexsum$EXDURGR <- "not treated"
adexsum$EXDURGR[adexsum$AVAL >= 1] <- ">=1 day"
adexsum$EXDURGR[adexsum$AVAL >= 7] <- ">=7 days"
adexsum$EXDURGR[adexsum$AVAL >= 28] <- ">=28 days"
adexsum$EXDURGR[adexsum$AVAL >= 12 * 7] <- ">=12 weeks"
adexsum$EXDURGR[adexsum$AVAL >= 24 * 7] <- ">=24 weeks"

adexsum$EXDURGR <- factor(adexsum$EXDURGR,
  levels = c("not treated", ">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
)
unique(adexsum$EXDURGR)

## -----------------------------------------------------------------------------
plan <- metalite::plan(
  analysis = "exp_dur", population = "apat",
  observation = "apat", parameter = "expdur"
)

meta <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()

## -----------------------------------------------------------------------------
outdata <- prepare_exp_duration(meta)
outdata

## -----------------------------------------------------------------------------
outdata$n[, 1:5]

## -----------------------------------------------------------------------------
charn <- data.frame(outdata$char_n[1])
head(charn[, 1:5], 6)

## -----------------------------------------------------------------------------
charp <- data.frame(outdata$char_prop[1])
head(charp[, 1:5], 6)

## -----------------------------------------------------------------------------
chars <- data.frame(outdata$char_n[1])
tail(chars[, 1:5], 8)

## -----------------------------------------------------------------------------
tbl <- format_exp_duration(outdata, display_col = c("n", "prop", "total"))
head(tbl$tbl)

## ----warning=FALSE------------------------------------------------------------
outdata <- format_exp_duration(outdata, display_col = c("n", "prop", "total")) |>
  rtf_exp_duration(
    source = "Source:  [CDISCpilot: adam-adexsum]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = "outtable/exp0duration.rtf"
  )

## ----out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"----
knitr::include_graphics("pdf/exp0duration.pdf")

## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150,
  eval = TRUE
)

## -----------------------------------------------------------------------------
library(metalite)
library(metalite.sl)

## ----eval = FALSE-------------------------------------------------------------
# meta_sl_example() |>
#   prepare_base_char(
#     population = "apat",
#     analysis = "base_char",
#     parameter = "age;gender"
#   ) |>
#   format_base_char() |>
#   rtf_base_char(
#     source = "Source: [CDISCpilot: adam-adsl]",
#     path_outdata = tempfile(fileext = ".Rdata"),
#     path_outtable = tempfile(fileext = ".rtf")
#   )

## ----out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"----
knitr::include_graphics("pdf/base0char.pdf")

## -----------------------------------------------------------------------------
react_base_char(
  metadata_sl = meta_sl_example(),
  metadata_ae = metalite.ae::meta_ae_example(),
  population = "apat",
  observation = "wk12",
  display_total = TRUE,
  sl_parameter = "age;race",
  ae_subgroup = c("age", "race"),
  ae_specific = "rel",
  width = 1200
)

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

sysfonts::font_add("Invention", regular = "Invention_Lt.ttf")

hexSticker::sticker(
  subplot = ~ plot.new(), s_x = 1, s_y = 1, s_width = 0.1, s_height = 0.1,
  package = "metalite.sl", p_family = "Invention",
  p_color = "#ffffff", p_x = 1, p_y = 1.05, p_size = 24,
  h_fill = "#00857c", h_color = "#005c55", h_size = 1.2,
  filename = "man/figures/logo.png", dpi = 320
)

magick::image_read("man/figures/logo.png")

rstudioapi::restartSession()

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Prepare data for baseline characteristic table
#'
#' @param meta A metadata object created by metalite.
#' @param population A character value of population term name.
#'   The term name is used as key to link information.
#' @param analysis A character value of analysis term name.
#'   The term name is used as key to link information.
#' @param parameter A character value of parameter term name.
#'   The term name is used as key to link information.
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "age;gender"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat",
#'     group = "TRTA",
#'     subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age",
#'     var = "AGE",
#'     label = "Age (years)",
#'     vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |> prepare_base_char()
prepare_base_char <- function(meta,
                              analysis = "base_char",
                              population = meta$plan[meta$plan$analysis == analysis, ]$population,
                              parameter = paste(meta$plan[meta$plan$analysis == analysis, ]$parameter, collapse = ";")) {
  return(
    prepare_sl_summary(meta,
      analysis = analysis,
      population = population,
      parameter = parameter
    )
  )
}

# library(metalite)
#
# outdata <- prepare_base_char(meta,
#   population = "apat",
#   parameter = "age;gender"
# )
#
# #### Test 1 ######
# test_that("rtf output: n, and prop, NO total. With 2 decimal places.", {
#   path_rtf <- file.path(tempdir(), "base0char1.rtf")
#   path_rdata <- tempfile(fileext = ".Rdata")
#
#   tbl <- outdata |>
#     format_base_char(
#       display_col = c("n", "prop"),
#       digits_prop = 4
#     ) |>
#     rtf_base_char(
#       source = "Source: [CDISCpilot: adam-adsl]",
#       path_outdata = path_rdata,
#       path_outtable = path_rtf
#     )
#
#   testthat::expect_snapshot_file(path_rtf)
# })
#
# #### Test 2 #####
# test_that("rtf output: n, prop and total, with Landscape, manual entory of col_rel_width", {
#   path_rtf <- file.path(tempdir(), "base0char2.rtf")
#   path_rdata <- tempfile(fileext = ".Rdata")
#
#   tbl <- outdata |>
#     format_base_char() |>
#     rtf_base_char(
#       orientation = "landscape",
#       col_rel_width = c(4, 2, 2, 2, 2, 2, 2, 2, 2, 3),
#       source = "Source: [CDISCpilot: adam-adsl]",
#       path_outdata = path_rdata,
#       path_outtable = path_rtf
#     )
#
#   testthat::expect_snapshot_file(path_rtf)
# })
#
#
# #### Test 3 #####
# test_that("rtf output: n, prop and total, with no value of col_rel_width", {
#   path_rtf <- file.path(tempdir(), "base0char3.rtf")
#   path_rdata <- tempfile(fileext = ".Rdata")
#
#   tbl <- outdata |>
#     format_base_char(display_col = c("n", "prop", "total")) |>
#     rtf_base_char(
#       col_rel_width = c(4, 2, 2, 2, 2, 2, 2, 3, 3, 3),
#       source = "Source: [CDISCpilot: adam-adsl]",
#       path_outdata = path_rdata,
#       path_outtable = path_rtf
#     )
#
#   testthat::expect_snapshot_file(path_rtf)
# })

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Baseline characteristic table
#'
#' @param outdata An `outdata` object created by [prepare_sl_summary()].
#' @param source A character value of the data source.
#' @inheritParams r2rtf::rtf_page
#' @inheritParams r2rtf::rtf_body
#' @param footnotes A character vector of table footnotes.
#' @param title Term "analysis", "observation" and "population") for collecting title from metadata or a character vector of table titles.
#' @param path_outdata A character string of the outdata path.
#' @param path_outtable A character string of the outtable path.
#'
#' @return RTF file and source dataset for baseline characteristic table.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char", population = "apat",
#'     observation = "apat", parameter = "age;gender"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_sl_summary(
#'     population = "apat",
#'     analysis = "base_char",
#'     parameter = "age;gender"
#'   ) |>
#'   format_sl_summary() |>
#'   rtf_sl_summary(
#'     source = "Source: [CDISCpilot: adam-adsl]",
#'     path_outdata = tempfile(fileext = ".Rdata"),
#'     path_outtable = tempfile(fileext = ".rtf")
#'   )
rtf_sl_summary <- function(
  outdata,
  source,
  col_rel_width = NULL,
  text_font_size = 9,
  orientation = "portrait",
  footnotes = NULL,
  title = NULL,
  path_outdata = NULL,
  path_outtable = NULL
) {
  # Set default column width


  tbl <- outdata$tbl
  display_total <- "total" %in% outdata$display_col
  if (display_total == TRUE) {
    group <- c(levels(outdata$group_label), "Total")
    n_group <- length(outdata$group_label) + 1
  } else {
    group <- levels(outdata$group_label)
    n_group <- length(outdata$group_label)
  }
  n_row <- nrow(tbl)
  n_col <- ncol(tbl)

  if (!is.null(col_rel_width) && !(n_col == length(col_rel_width))) {
    stop(
      "col_rel_width must have the same length (has ",
      length(col_rel_width),
      ") as `outdata$tbl` has number of columns (has ",
      n_col, ").",
      call. = FALSE
    )
  }

  # Set default title
  if (is.null(title)) {
    title <- metalite::collect_title(outdata$meta,
      outdata$population,
      "",
      outdata$parameter,
      analysis = outdata$analysis
    )
  }

  # Set default footnote
  footnotes_stat <- NULL
  if (("integer" %in% outdata$var_type) || ("numeric" %in% outdata$var_type)) {
    if ("sd" %in% tolower(outdata$display_stat)) {
      footnotes_stat <- c(footnotes_stat, "SD=Standard deviation")
    }
    if ("se" %in% tolower(outdata$display_stat)) {
      footnotes_stat <- c(footnotes_stat, paste0("SE=Standard err", "or"))
    }
    if ("q1 to q3" %in% tolower(outdata$display_stat)) {
      footnotes_stat <- c(footnotes_stat, "Q1=First quartile, Q3=Third quartile")
    }
    # combine footnotes for abbreviation of statistics
    footnotes_stat <- paste(footnotes_stat, collapse = "; ")
    # combine with user defined footnotes if not NULL
    if (nchar(footnotes_stat) > 0) {
      if (!is.null(footnotes)) {
        footnotes <- c(paste0(footnotes_stat, "."), footnotes)
      } else {
        footnotes <- paste0(footnotes_stat, ".")
      }
    }
  }

  # Set column header
  colheader <- c(
    paste0(" | ", paste(group, collapse = " | ")),
    paste0(" | ", paste(rep("n | (%)", n_group), collapse = " | "))
  )

  # Set relative width
  if (is.null(col_rel_width)) {
    rel_width_body <- c(3, rep(1, 2 * n_group), 1)
  } else {
    rel_width_body <- col_rel_width
  }

  rel_width_head2 <- rel_width_body[1:(length(rel_width_body) - 1)]

  rel_width_head1 <- c(
    rel_width_head2[1],
    tapply(rel_width_head2[2:(n_group * 2 + 1)], c(rep(1:n_group, each = 2)), sum),
    rel_width_head2[-(1:(n_group * 2 + 1))]
  )

  # Column boarder
  border_top <- c("", rep("single", n_group * 2))
  border_top_body <- c(rep("", n_col - 1), "single")
  border_bottom <- c(rep("", n_col - 1), "single")
  border_left <- c("single", rep(c("single", ""), n_group))
  border_left_body <- c(border_left, "single")

  text_format <- c(rep("", 1 + n_group * 2), "b")

  # Using order number to customize row format
  text_justification <- c("l", rep("c", n_group * 2), "l")
  text_indent <- matrix(0, nrow = n_row, ncol = n_col)
  text_indent[, 1] <- ifelse(FALSE, 0, 100)
  text_indent[1, 1] <- 0

  # Use r2rtf
  outdata$rtf <- tbl |>
    r2rtf::rtf_page(orientation = orientation) |>
    r2rtf::rtf_title(title) |>
    r2rtf::rtf_colheader(
      colheader = colheader[1],
      col_rel_width = rel_width_head1,
      text_font_size = text_font_size
    ) |>
    r2rtf::rtf_colheader(
      colheader = colheader[2],
      border_top = border_top,
      border_left = border_left,
      col_rel_width = rel_width_head2,
      text_font_size = text_font_size
    ) |>
    r2rtf::rtf_body(
      page_by = "var_label",
      col_rel_width = rel_width_body,
      border_left = border_left_body,
      border_top = border_top_body,
      border_bottom = border_bottom,
      text_justification = text_justification,
      text_indent_first = text_indent,
      text_indent_left = text_indent,
      text_format = text_format,
      text_font_size = text_font_size
    )

  if (!is.null(footnotes)) {
    outdata$rtf <- outdata$rtf |>
      r2rtf::rtf_footnote(footnotes,
        text_font_size = text_font_size
      )
  }

  if (!is.null(source)) {
    outdata$rtf <- outdata$rtf |>
      r2rtf::rtf_source(source,
        text_font_size = text_font_size
      )
  }

  # Prepare output
  rtf_output(outdata, path_outdata, path_outtable)
}

#' Baseline characteristic table
#'
#' @inheritParams rtf_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char", population = "apat",
#'     observation = "apat", parameter = "age;gender"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_base_char(
#'     population = "apat",
#'     analysis = "base_char",
#'     parameter = "age;gender"
#'   ) |>
#'   format_base_char() |>
#'   rtf_base_char(
#'     source = "Source: [CDISCpilot: adam-adsl]",
#'     path_outdata = tempfile(fileext = ".Rdata"),
#'     path_outtable = tempfile(fileext = ".rtf")
#'   )
rtf_base_char <- rtf_sl_summary

#' Treatment compliance table
#'
#' @inheritParams rtf_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "trt_compliance", population = "apat",
#'     observation = "apat", parameter = "comp8;comp16"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "comp8", var = "COMP8FL", label = "Compliance (Week 8)"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "comp16", var = "COMP16FL", label = "Compliance (Week 16)"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "trt_compliance", title = "Summary of Treatment Compliance"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_trt_compliance(population = "apat", parameter = "comp8;comp16") |>
#'   format_trt_compliance() |>
#'   rtf_trt_compliance(
#'     source = "Source: [CDISCpilot: adam-adsl]",
#'     path_outdata = tempfile(fileext = ".Rdata"),
#'     path_outtable = tempfile(fileext = ".rtf")
#'   )
rtf_trt_compliance <- rtf_sl_summary


#' Disposition table
#'
#' @inheritParams rtf_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "disp", population = "apat",
#'     observation = "apat", parameter = "disposition;medical-disposition"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "disposition", var = "EOSSTT", label = "Trial Disposition",
#'     var_lower = "DCSREAS"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "medical-disposition", var = "EOTSTT",
#'     label = "Participant Study Medication Disposition", var_lower = "DCTREAS"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "disp", title = "Disposition of Participant"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_disposition(population = "apat", parameter = "disposition;medical-disposition") |>
#'   format_disposition() |>
#'   rtf_disposition(
#'     source = "Source: [CDISCpilot: adam-adsl]",
#'     path_outdata = tempfile(fileext = ".Rdata"),
#'     path_outtable = tempfile(fileext = ".rtf")
#'   )
rtf_disposition <- rtf_sl_summary

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

utils::globalVariables(c("SAFFL", "TRTDURGR", "USUBJID", "AEACN"))

meta_ae_sl_example <- function() {
  analysis_plan <- metalite::plan(
    analysis = "ae_specific",
    population = "apat",
    observation = "wk12",
    parameter = "any;rel"
  )

  metalite::meta_adam(
    observation = metalite_sl_adae,
    population = metalite_sl_adsl
  ) |>
    metalite::define_plan(analysis_plan) |>
    metalite::define_population(
      name = "apat",
      var = c(
        "USUBJID", "SAFFL", "TRTA", "TRTDUR",
        "SITEID", "SEX", "RACE", "AGE"
      ),
      group = "TRTA",
      subset = SAFFL == "Y",
      label = "All Participants as Treated"
    ) |>
    metalite::define_observation(
      name = "wk12",
      var = c(
        "USUBJID", "SAFFL", "TRTA", "SEX", "AEDECOD", "AEBODSYS", "AEREL",
        "AESER", "AEOUT", "AEACN", "AESDTH", "ASTDT", "AENDT"
      ),
      group = "TRTA",
      subset = SAFFL == "Y",
      label = "Weeks 0 to 12"
    ) |>
    metalite::define_parameter(
      name = "any",
      term1 = "",
      term2 = "",
      var = "AEDECOD",
      soc = "AEBODSYS",
      label = "All AEs"
    ) |>
    metalite::define_parameter(
      name = "rel",
      term1 = "Drug-Related",
      term2 = "",
      subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
      var = "AEDECOD",
      soc = "AEBODSYS",
      label = "Drug-related AEs"
    ) |>
    metalite::define_analysis(
      name = "ae_specific",
      title = "Participants With Drug-Related Adverse Events"
    ) |>
    metalite::meta_build()
}

library(reactable)
library(htmltools)

test_that("Testing react_base_char function", {
  # the "react_subgroup_table()" function is called inside the "react_base_char()" function

  table <- react_base_char(
    metadata_sl = meta_sl_test(),
    metadata_ae = meta_ae_sl_example(),
    population = "apat",
    observation = "wk12",
    display_total = TRUE,
    sl_parameter = "age;gender;race",
    ae_subgroup = c("age", "race", "gender"),
    ae_specific = "rel",
    width = 1200
  )

  html <- gsub("id=\"htmlwidget-[A-Za-z0-9]+\"", "id=\"htmlwidget-123456\"", table)
  html <- gsub(
    "\"dataKey\":\"[a-f0-9]{32}\"", # Regex pattern to match the dataKey
    "\"dataKey\":\"fixed_data_key\"", # New fixed dataKey value
    html
  )

  expect_snapshot(html)
})

library(reactable)
library(htmltools)

test_that("Testing react_subgroup_table function", {
  # the "react_subgroup_table()" function is called inside the "react_base_char()" function
  outdata <- metalite.ae::prepare_ae_specific_subgroup(
    meta_ae_sl_example(),
    population = "apat",
    observation = "wk12",
    parameter = "rel",
    subgroup_var = "SEX",
    display_subgroup_total = FALSE # total display for subgroup is not needed
  ) |>
    metalite.ae::format_ae_specific_subgroup()

  table <- react_subgroup_table(outdata$tbl, outdata$group, "F")

  html <- gsub("id=\"htmlwidget-[A-Za-z0-9]+\"", "id=\"htmlwidget-123456\"", table)
  html <- gsub(
    "\"dataKey\":\"[a-f0-9]{32}\"", # Regex pattern to match the dataKey
    "\"dataKey\":\"fixed_data_key\"", # New fixed dataKey value
    html
  )

  expect_snapshot(html)
})

library(reactable)
library(htmltools)

# Test 1 Overall testing for react_disposition function
test_that("Testing react_disposition function", {
  set.seed(123)

  table <- react_disposition(
    metadata_sl = meta_sl_test(),
    metadata_ae = meta_ae_sl_example(),
    trtvar = "trt01a",
    width = 1200
  )

  html <- gsub("id=\"htmlwidget-[A-Za-z0-9]+\"", "id=\"htmlwidget-123456\"", table)
  html <- gsub(
    "dataKey = \"[a-f0-9]{32}\"",
    "dataKey = \"fixed_data_key\"",
    html
  )

  expect_snapshot(html)
})

# Test 2 Testing AE selected column
test_that("Testing react_disposition function AE selection column", {
  set.seed(123)

  table <- react_disposition(
    metadata_sl = meta_sl_test(),
    metadata_ae = meta_ae_sl_example(),
    trtvar = "trt01a",
    ae_col_selected = c("AESOC", "ASTDT", "AENDT", "AETERM", "duration", "AESEV", "AESER", "related", "AEACN", "AEOUT"),
    ae_col_names = c("SOC", "Onset Date", "End Date", "AE", "Duraion", "Intensity", "Serious", "Related", "Action Taken", "Outcome"),
    width = 1200
  )

  html <- gsub("id=\"htmlwidget-[A-Za-z0-9]+\"", "id=\"htmlwidget-123456\"", table)
  html <- gsub(
    "dataKey = \"[a-f0-9]{32}\"",
    "dataKey = \"fixed_data_key\"",
    html
  )

  expect_snapshot(html)
})

# Test 3 Testing Disposition selected column
test_that("Testing react_disposition function Disposition selection column", {
  set.seed(123)

  table <- react_disposition(
    metadata_sl = meta_sl_test(),
    metadata_ae = meta_ae_sl_example(),
    trtvar = "trt01a",
    sl_col_selected = c("trt01a", "siteid", "subjid", "sex", "age", "weightbl"),
    sl_col_names = c("Treatment", "Site", "Subject ID", "Sex", "Age (Year)", "Weight (kg)"),
    width = 1200
  )

  html <- gsub("id=\"htmlwidget-[A-Za-z0-9]+\"", "id=\"htmlwidget-123456\"", table)
  html <- gsub(
    "dataKey = \"[a-f0-9]{32}\"",
    "dataKey = \"fixed_data_key\"",
    html
  )

  expect_snapshot(html)
})

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Create interactive table for a subgroup
#'
#' @param tbl A tibble to create reactable.
#' @param group Treatment group label.
#' @param subgroup_name Subgroup label.
#' @param col_title Column title for the reactable.
#'
#' @noRd
#'
#' @return A reactable combining both baseline characteristic table
#'   and AE subgroup specific tables for a subgroup.
react_subgroup_table <- function(
  tbl,
  group,
  subgroup_name,
  col_title = NULL
) {
  names(tbl) <- tolower(names(tbl))
  subgroup_name <- tolower(subgroup_name)
  race_columns <- grep(tolower(subgroup_name), tolower(names(tbl)), value = TRUE)

  selected_columns <- c("name", race_columns)

  formatted_data <- tbl[, selected_columns]

  # Remove row with no observation
  formatted_data1 <- formatted_data[1:4, ]
  formatted_data2 <- formatted_data[5:nrow(formatted_data), ]
  formatted_data2 <- formatted_data2[which(rowSums(formatted_data2[, grepl("n_", colnames(formatted_data2))]) > 0), ]
  formatted_data <- rbind(formatted_data1, formatted_data2)

  prop_prefix <- paste0(subgroup_name, "prop_")
  n_prefix <- paste0(subgroup_name, "n_")

  prop_indices <- grep(prop_prefix, names(formatted_data))
  n_indices <- grep(n_prefix, names(formatted_data))

  # formatted_data <- formatted_data[, c(1, prop_indices, n_indices)]

  num_columns <- length(prop_indices)

  col_defs <- list()
  col_group_defs <- list()
  all_columns <- c("name")

  js_filterminvalue <- readLines(system.file("js/filterMinValue.js", package = "metalite.sl"))
  js_rangeFilter <- readLines(system.file("js/rangeFilter.js", package = "metalite.sl"))

  for (i in seq_len(num_columns)) {
    prop_name <- names(formatted_data)[prop_indices[i]]
    prop_num_name <- sub(prop_prefix, paste0(prop_name, "_num"), prop_name)

    n_name <- names(formatted_data)[n_indices[i]]

    formatted_data[[prop_num_name]] <- ifelse(is.na(formatted_data[[prop_name]]), 0, defmt_pct(formatted_data[[prop_name]]))

    all_columns <- append(all_columns, c(n_name, prop_name, prop_num_name))

    col_defs[["name"]] <- reactable::colDef(name = col_title, show = TRUE, searchable = TRUE, minWidth = 500)
    col_defs[[n_name]] <- reactable::colDef(name = "n", show = TRUE, na = "", searchable = FALSE)
    col_defs[[prop_name]] <- reactable::colDef(show = FALSE)
    col_defs[[prop_num_name]] <- reactable::colDef(name = "%", filterMethod = reactable::JS(js_filterminvalue), filterInput = reactable::JS(js_rangeFilter))

    col_group_defs <- append(col_group_defs, list(reactable::colGroup(name = group[i], columns = c(n_name, prop_name, prop_num_name))))
  }

  # Row 4 is the empty row to separate summary and specified AE, leave columns as empty
  formatted_data[4, ] <- NA

  formatted_data <- formatted_data |> dplyr::select(dplyr::all_of(all_columns))

  reactable::reactable(
    formatted_data,
    filterable = TRUE,
    columns = col_defs,
    columnGroups = col_group_defs
  )
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Subgroup Analysis for Baseline Characteristic
#'
#' @param outdata An `outdata` object created by [prepare_base_char_subgroup()]
#' @param source A character value of the data source.
#' @inheritParams r2rtf::rtf_page
#' @inheritParams r2rtf::rtf_body
#' @param footnotes A character vector of table footnotes.
#' @param title Term "analysis", "observation" and "population") for collecting title from metadata or a character vector of table titles.
#' @param path_outdata A character string of the outdata path.
#' @param path_outtable A character string of the outtable path.
#'
#' @return RTF file and source dataset for baseline characteristic table.
#' @export
#'
#' @examples
#' \donttest{
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char_subgroup", population = "apat",
#'     observation = "apat", parameter = "age"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "base_char_subgroup", title = "Participant by Age Category and Sex"
#'   ) |>
#'   metalite::meta_build()
#'
#' outdata <- prepare_base_char_subgroup(
#'   meta,
#'   population = "apat",
#'   parameter = "age",
#'   subgroup_var = "TRTA",
#'   subgroup_header = c("SEX", "TRTA")
#' )
#'
#' outdata |>
#'   format_base_char_subgroup() |>
#'   rtf_base_char_subgroup(
#'     source = "Source:  [CDISCpilot: adam-adsl]",
#'     path_outdata = tempfile(fileext = ".Rdata"),
#'     path_outtable = tempfile(fileext = ".rtf")
#'   )
#' }
rtf_base_char_subgroup <- function(
  outdata,
  source,
  col_rel_width = NULL,
  text_font_size = 8,
  orientation = "landscape",
  footnotes = NULL,
  title = NULL,
  path_outdata = NULL,
  path_outtable = NULL
) {
  out_all <- outdata$out_all
  tbl <- outdata$tbl

  tbl1 <- tbl[!names(tbl) %in% c("order")]
  tgroup <- outdata$group
  sgroup <- outdata$subgroup
  if (outdata$display_total) {
    sgroup <- c(sgroup, "Total")
  }
  if ("total" %in% outdata$display) {
    tgroup <- c(tgroup, "Total")
  }
  n_sgroup <- length(sgroup)
  n_tgroup <- length(tgroup)
  n_row <- nrow(tbl1)
  n_col <- ncol(tbl1)

  if (!is.null(col_rel_width) && !n_col == length(col_rel_width)) {
    stop(
      "col_rel_width must have the same length (has ",
      length(col_rel_width),
      ") as outdata$tbl has number of columns (has ",
      n_col, ")."
    )
  }

  # Define title
  if (is.null(title)) {
    title <- metalite::collect_title(outdata$meta,
      outdata$population,
      "",
      outdata$parameter,
      analysis = "base_char_subgroup"
    )
  }

  # Set default footnote
  footnotes_stat <- NULL
  if ("sd" %in% tolower(outdata$display_stat)) {
    footnotes_stat <- c(footnotes_stat, "SD=Standard deviation")
  }
  if ("se" %in% tolower(outdata$display_stat)) {
    footnotes_stat <- c(footnotes_stat, paste0("SE=Standard err", "or"))
  }
  if ("q1 to q3" %in% tolower(outdata$display_stat)) {
    footnotes_stat <- c(footnotes_stat, "Q1=First quartile, Q3=Third quartile")
  }
  # combine footnotes for abbreviation of statistics
  footnotes_stat <- paste(footnotes_stat, collapse = "; ")
  # combine with user defined footnotes if not NULL
  if (nchar(footnotes_stat) > 0) {
    if (!is.null(footnotes)) {
      footnotes <- paste0(footnotes_stat, ".\n", footnotes)
    } else {
      footnotes <- paste0(footnotes_stat, ".")
    }
  }

  col_tbl_within <- outdata$display

  col_tbl_within <- col_tbl_within |>
    (\(list) list[list %in% c("n", "prop")])() |>
    unique()

  colhead_within <- paste(
    vapply(
      X = col_tbl_within,
      FUN.VALUE = "character",
      FUN = switch,
      "n" = "n",
      "prop" = "(%)"
    ),
    collapse = " | "
  )

  colhead_1_within <- paste(sgroup, collapse = " |")
  colhead_2_within <- paste(rep(tgroup, n_sgroup), collapse = " | ")
  colhead_3_within <- paste(rep(colhead_within, n_sgroup * n_tgroup), collapse = " | ")

  colborder_within <- vapply(
    X = col_tbl_within,
    FUN.VALUE = "character",
    FUN = switch,
    "n" = "single",
    "prop" = "",
    USE.NAMES = FALSE
  )

  rwidth_3_within <- rep(1, length(col_tbl_within) * n_sgroup * n_tgroup)

  rwidth_2_within <- tapply(
    rwidth_3_within,
    c(rep(1:(n_sgroup * n_tgroup), each = length(col_tbl_within))),
    sum
  )
  names(rwidth_2_within) <- NULL

  rwidth_1_within <- tapply(
    rwidth_3_within,
    c(rep(1:n_sgroup, each = length(col_tbl_within) * n_tgroup)),
    sum
  )
  names(rwidth_1_within) <- NULL


  colborder_within <- rep(colborder_within, n_sgroup * n_tgroup)

  # Column headers

  colheader <- c(
    paste0(" | ", colhead_1_within),
    paste0(" | ", colhead_2_within),
    paste0(" | ", colhead_3_within)
  )

  # Relative width

  if (is.null(col_rel_width)) {
    rwidth_1 <- c(2, rwidth_1_within)
    rwidth_2 <- c(2, rwidth_2_within)
    rwidth_3 <- c(2, rwidth_3_within)
  } else {
    rwidth_3 <- col_rel_width[1:(length(col_rel_width) - 1)]

    rwidth_2 <- tapply(
      rwidth_3[2:length(rwidth_3)],
      c(rep(1:(n_sgroup * n_tgroup), each = length(col_tbl_within))),
      sum
    )

    rwidth_2 <- c(
      rwidth_3[1],
      rwidth_2
    )


    rwidth_1 <- tapply(
      rwidth_3[2:length(rwidth_3)],
      c(rep(1:n_sgroup, each = length(col_tbl_within) * n_tgroup)),
      sum
    )

    rwidth_1 <- c(
      rwidth_3[1],
      rwidth_1
    )
  }

  if ((sum(rwidth_1) != sum(rwidth_2)) || (sum(rwidth_1) != sum(rwidth_3))) {
    stop("Width calculation breaks, contact developer.")
  }

  # Column border
  border_top2 <- c("", rep("single", n_sgroup * n_tgroup))
  border_top3 <- c("", rep("single", n_sgroup * n_tgroup * 2))

  border_left2 <- c("single", rep("single", n_sgroup * n_tgroup))
  border_left3 <- c("single", colborder_within)
  border_left4 <- c(rep("single", 2), colborder_within)

  # Using order number to customize row format

  text_justification <- c("l", rep("l", n_sgroup * n_tgroup * 2), "l")
  # text_format <- c(rep("", 1 + n_sgroup * n_tgroup * 2), "b")

  text_indent <- matrix(0, nrow = n_row, ncol = n_col)
  text_indent[, 1] <- ifelse(FALSE, 0, 100)
  text_indent[1, 1] <- 0

  # Using r2rtf
  outdata$rtf <- tbl1 |>
    r2rtf::rtf_page(orientation = orientation) |>
    r2rtf::rtf_title(title) |>
    r2rtf::rtf_colheader(
      colheader = colheader[1],
      col_rel_width = rwidth_1,
      text_font_size = text_font_size
    ) |>
    r2rtf::rtf_colheader(
      colheader = colheader[2],
      border_top = border_top2,
      border_left = border_left2,
      col_rel_width = rwidth_2,
      text_font_size = text_font_size
    ) |>
    r2rtf::rtf_colheader(
      colheader = colheader[3],
      border_top = border_top3,
      border_left = border_left3,
      col_rel_width = rwidth_3,
      text_font_size = text_font_size
    ) |>
    r2rtf::rtf_body(
      page_by = "var_label",
      col_rel_width = c(rwidth_3, 1),
      border_left = border_left4,
      text_justification = text_justification,
      text_indent_first = text_indent,
      text_indent_left = text_indent,
      # text_format = text_format,
      text_font_size = text_font_size
    )

  if (!is.null(footnotes)) {
    outdata$rtf <- outdata$rtf |>
      r2rtf::rtf_footnote(footnotes,
        text_font_size = text_font_size
      )
  }

  if (!is.null(source)) {
    outdata$rtf <- outdata$rtf |>
      r2rtf::rtf_source(source,
        text_font_size = text_font_size
      )
  }

  # Prepare output
  rtf_output(outdata, path_outdata, path_outtable)

  # to_pdf(
  #  path_outtable,
  #  output = gsub("\\.[[:alnum:]]+$", ".pdf", path_outtable),
  #  timeout = 120,
  #  UserInstallation = NULL
  # )
}

meta <- meta_sl_test()
data_population <- meta$data_population
data_population$AGEGR1 <- factor(
  data_population$AGEGR1,
  levels = c("<65", "65-80", ">80"),
  labels = c("<65", "65-80", ">80")
)
data_population$SEX <- factor(
  data_population$SEX,
  levels = c("F", "M"),
  labels = c("Female", "Male")
)
meta$data_population <- data_population


test_that("rtf output: n and prop including subgroup total w/o total", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "age",
    subgroup_var = "TRTA",
    subgroup_header = c("SEX", "TRTA")
  )
  tbl <- outdata |>
    format_base_char_subgroup(
      display = c("n", "prop"),
      display_total = TRUE
    ) |>
    rtf_base_char_subgroup(
      source = "Source:  [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "base0char0subgroup1.rtf")
    )

  expect_rtf_snapshot(tbl, "base0char0subgroup1")
})

test_that("rtf output: n and prop including subgroup total w/ total", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "age",
    subgroup_var = "TRTA",
    subgroup_header = c("SEX", "TRTA")
  )
  tbl <- outdata |>
    format_base_char_subgroup(
      display = c("n", "prop", "total"),
      display_total = TRUE
    ) |>
    rtf_base_char_subgroup(
      source = "Source:  [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "base0char0subgroup2.rtf")
    )

  expect_rtf_snapshot(tbl, "base0char0subgroup2")
})

test_that("rtf output: n and prop not including subgroup total w/o total", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "age",
    subgroup_var = "TRTA",
    subgroup_header = c("SEX", "TRTA")
  )
  tbl <- outdata |>
    format_base_char_subgroup(
      display = c("n", "prop"),
      display_total = FALSE
    ) |>
    rtf_base_char_subgroup(
      source = "Source:  [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "base0char0subgroup3.rtf")
    )

  expect_rtf_snapshot(tbl, "base0char0subgroup3")
})

test_that("rtf output: n and prop not including subgroup total w/ total", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "age",
    subgroup_var = "TRTA",
    subgroup_header = c("SEX", "TRTA")
  )
  tbl <- outdata |>
    format_base_char_subgroup(
      display = c("n", "prop", "total"),
      display_total = FALSE
    ) |>
    rtf_base_char_subgroup(
      source = "Source:  [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "base0char0subgroup4.rtf")
    )

  expect_rtf_snapshot(tbl, "base0char0subgroup4")
})


test_that("rtf output: no group/subgroup total when a subgroup has no subject", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "race",
    subgroup_var = "SEX",
    subgroup_header = c("SEX", "TRTA")
  )
  tbl <- outdata |>
    format_base_char_subgroup(
      display = c("n", "prop"),
      display_total = FALSE
    ) |>
    rtf_base_char_subgroup(
      source = "Source:  [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "base0char0subgroup5.rtf")
    )

  expect_rtf_snapshot(tbl, "base0char0subgroup5")
})

test_that("rtf output: group/subgroup total when a subgroup has no subject", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "race",
    subgroup_var = "SEX",
    subgroup_header = c("SEX", "TRTA")
  )
  tbl <- outdata |>
    format_base_char_subgroup(
      display = c("n", "prop", "total"),
      display_total = TRUE
    ) |>
    rtf_base_char_subgroup(
      source = "Source:  [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "base0char0subgroup6.rtf")
    )

  expect_rtf_snapshot(tbl, "base0char0subgroup6")
})

test_that("relative width 'works' with display_subgroup_total = FALSE", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "age",
    subgroup_var = "TRTA",
    subgroup_header = c("SEX", "TRTA")
  )

  expect_error(
    {
      tbl <- outdata |>
        format_base_char_subgroup(
          display = c("n", "prop"),
          display_total = FALSE
        ) |>
        rtf_base_char_subgroup(
          source = "Source:  [CDISCpilot: adam-adsl]",
          col_rel_width = c(3, rep(2, 2 * 2 * 3)),
          path_outdata = tempfile(fileext = ".Rdata"),
          path_outtable = file.path(tempdir(), "rwnt_base0char0subgroup.rtf")
        )
    },
    regexp = "col_rel_width must have the same length"
  )
  expect_message(
    {
      tbl <- outdata |>
        format_base_char_subgroup(
          display = c("n", "prop"),
          display_total = FALSE
        ) |>
        rtf_base_char_subgroup(
          source = "Source:  [CDISCpilot: adam-adsl]",
          col_rel_width = c(3, rep(2, 2 * 2 * 3), 2),
          path_outdata = tempfile(fileext = ".Rdata"),
          path_outtable = file.path(tempdir(), "rwnt_base0char0subgroup2.rtf")
        )
    },
    regexp = "The outdata is saved"
  )
})

test_that("relative width 'works' display_subgroup_total = TRUE", {
  outdata <- prepare_base_char_subgroup(
    meta,
    population = "apat",
    parameter = "age",
    subgroup_var = "TRTA",
    subgroup_header = c("SEX", "TRTA")
  )

  expect_error(
    {
      tbl <- outdata |>
        format_base_char_subgroup(
          display = c("n", "prop"),
          display_total = TRUE
        ) |>
        rtf_base_char_subgroup(
          source = "Source:  [CDISCpilot: adam-adsl]",
          col_rel_width = c(3, rep(2, 2 * 2 * 4)),
          path_outdata = tempfile(fileext = ".Rdata"),
          path_outtable = file.path(tempdir(), "rwt_base0char0subgroup.rtf")
        )
    },
    regexp = "col_rel_width must have the same length"
  )
  expect_message(
    {
      tbl <- outdata |>
        format_base_char_subgroup(
          display = c("n", "prop"),
          display_total = TRUE
        ) |>
        rtf_base_char_subgroup(
          source = "Source:  [CDISCpilot: adam-adsl]",
          col_rel_width = c(3, rep(2, 2 * 2 * 4), 2),
          path_outdata = tempfile(fileext = ".Rdata"),
          path_outtable = file.path(tempdir(), "rwt_base0char0subgroup2.rtf")
        )
    },
    regexp = "The outdata is saved"
  )
})

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Create metadata for subject-level analysis table
#'
#' @param dataset_population Source dataset of population.
#' @param dataset_observation Source dataset of observation
#' @param population_term A character value of population term name.
#' @param observation_term A character value of observation term name.
#' @param parameter_term A character value of parameter term name.
#'   If there are multiple terms, they are separated by the semicolon (;).
#' @param parameter_var A character value of parameter variable name.
#'   If there are multiple variables, they are separated by the semicolon (;).
#'   A group variable can be specified followed by a variable
#'   and the hat symbol (^).
#' @param parameter_labels A character vector of parameter label name.
#'   The length of vector should be the same as the number of parameter terms.
#'   A label from an input data is used if `NA` for a variable is specified.
#' @param analysis_term A character value of analysis term name.
#' @param analysis_title A character value of analysis title name.
#' @param population_subset An unquoted condition for selecting the
#'   populations from dataset of population.
#' @param observation_subset An unquoted condition for selecting the
#'   populations from dataset of observation
#' @param population_label A character value of population label.
#' @param treatment_group A character value of treatment group name.
#'
#' @return A metalite object.
#'
#' @export
#'
#' @examples
#' meta_sl(
#'   dataset_population = r2rtf::r2rtf_adsl,
#'   population_term = "apat",
#'   parameter_term = "age;race",
#'   parameter_var = "AGE^AGEGR1;RACE"
#' )
meta_sl <- function(
  dataset_population,
  dataset_observation = NULL,
  population_term,
  observation_term = NULL,
  parameter_term = "age;race;gender",
  parameter_var = "AGE^AGEGR1;RACE;SEX",
  parameter_labels = NULL,
  analysis_term = "base_char",
  analysis_title = "Participant Baseline Characteristics by Treatment Group",
  population_subset = SAFFL == "Y",
  observation_subset = NULL,
  population_label = "All Participants as Treated",
  treatment_group = "TRT01A"
) {
  # Check input
  if (is.null(dataset_observation)) {
    dataset_observation <- dataset_population
  }
  if (is.null(observation_term)) {
    observation_term <- population_term
  }
  if (rlang::quo_is_null(rlang::enquo(observation_subset))) {
    observation_subset <- rlang::enquo(population_subset)
  }

  # Parse parameters
  parameter_terms <- unlist(strsplit(parameter_term, ";"))

  if (!length(parameter_terms) == length(unlist(strsplit(parameter_var, ";")))) {
    stop("The number of parameter labels should be the same as that of parameter terms.")
  }
  parameter_vars <- strsplit(unlist(strsplit(parameter_var, ";")), "^", fixed = TRUE)

  meta <- metalite::meta_adam(
    population = as.data.frame(dataset_population),
    observation = as.data.frame(dataset_observation)
  ) |>
    metalite::define_plan(plan = metalite::plan(
      analysis = analysis_term,
      population = population_term,
      observation = observation_term,
      parameter = parameter_term
    )) |>
    metalite::define_population(
      name = population_term,
      group = treatment_group,
      subset = !!rlang::enquo(population_subset),
      var = names(dataset_population),
      label = population_label
    ) |>
    metalite::define_observation(
      name = observation_term,
      group = treatment_group,
      subset = !!rlang::enquo(observation_subset),
      var = names(dataset_observation),
      label = ""
    )

  for (i in seq(parameter_terms)) {
    var <- parameter_vars[[i]]
    vargroup <- NULL
    if (length(parameter_vars[[i]]) > 2) {
      warning("The hat symbol (^) can separate only 2 input, a variable and its group variable.")
    } else if (length(parameter_vars[[i]]) == 2) {
      var <- parameter_vars[[i]][[1]]
      vargroup <- parameter_vars[[i]][[2]]
    }
    if (!is.null(parameter_labels)) {
      varlabel <- ifelse(!is.na(parameter_labels[i]),
        parameter_labels[i],
        attr(dataset_population[[var]], "label")
      )
    } else {
      varlabel <- attr(dataset_population[[var]], "label")
    }

    meta <- meta |>
      metalite::define_parameter(
        name = parameter_terms[[i]],
        var = var,
        vargroup = vargroup,
        label = varlabel
      )
  }

  meta <- meta |>
    metalite::define_analysis(
      name = analysis_term,
      label = "",
      title = analysis_title,
      var_name = unlist(parameter_vars)
    ) |>
    metalite::meta_build()

  meta
}

library(metalite)

# Prepare test data
adsl <- r2rtf::r2rtf_adsl
adsl$TRTA <- adsl$TRT01A
adsl$TRTA <- factor(
  adsl$TRTA,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

meta <- meta_sl(
  dataset_population = adsl,
  population_term = "apat",
  parameter_term = "age;gender;race",
  parameter_var = "AGE^AGEGR1;SEX;RACE",
  treatment_group = "TRTA"
)

# Test
test_that("There is one analysis: base_char", {
  expect_equal(names(meta$analysis), "base_char")
})

test_that("There is one observation: apat", {
  expect_equal(names(meta$observation), c("apat"))
})

test_that("There is one population: apat", {
  expect_equal(names(meta$population), "apat")
})

test_that("There are three parameters: age, gender, race", {
  expect_equal(names(meta$parameter), c("age", "gender", "race"))
})

test_that("There is one group parameter for age: agegr1", {
  expect_equal(meta$parameter$age$vargroup, "AGEGR1")
})

test_that("Output from meta_sl is a list", {
  expect_type(meta, "list")
})

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Display interactive disposition tables with AE subgroup analysis
#'
#' @param metadata_sl A metadata created by metalite,
#'   which builds the baseline characteristic table
#' @param metadata_ae A metadata created by metalite,
#'   which builds the AE subgroup specific table
#' @param analysis The analysis label provided in \code{metadata_sl}.
#' @param trtvar A character that indicate variable for the treatment group.
#' @param population A character value of population term name.
#'   The term name is used as key to link information.
#' @param display_total Display total column or not.
#' @param sl_parameter A character value of parameter term name for
#'   the baseline characteristic table.
#'   The term name is used as key to link information.
#' @param sl_col_selected A character vector of variable which will be shown in the participant detail.
#' @param sl_col_names A character vector for the columns names of the participant detail. Same length as sl_col_selected.
#' @param ae_observation The meta parameter of the observation in adverse event listing.
#' @param ae_population The meta parameter of the population in adverse event listing.
#' @param ae_parameter A character value of the parameter in adverse event listing.
#' @param ae_col_selected A character vector of variable which will be shown in the AE detail.
#' @param ae_col_names A character vector for the columns names of the AE detail. Same length as ae_col_selected.
#' @param width A numeric value of width of the table in pixels.
#'
#' @return An reactable combing both baseline characteristic table
#'   and AE subgroup specific tables.
#'
#' @export
#'
#' @examples
#' if (interactive()) {
#'   sl_plan <- metalite::plan(
#'     analysis = "disp",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "disposition;medical-disposition"
#'   )
#'
#'   metadata_sl <- metalite::meta_adam(
#'     observation = metalite_sl_adsl,
#'     population = metalite_sl_adsl
#'   ) |>
#'     metalite::define_plan(sl_plan) |>
#'     metalite::define_population(
#'       name = "apat",
#'       group = "TRTA",
#'       subset = SAFFL == "Y"
#'     ) |>
#'     metalite::define_parameter(
#'       name = "disposition",
#'       var = "EOSSTT",
#'       label = "Trial Disposition",
#'       var_lower = "DCSREAS"
#'     ) |>
#'     metalite::define_parameter(
#'       name = "medical-disposition",
#'       var = "EOTSTT",
#'       label = "Participant Study Medication Disposition",
#'       var_lower = "DCTREAS"
#'     ) |>
#'     metalite::define_analysis(
#'       name = "disp",
#'       title = "Disposition of Participant"
#'     ) |>
#'     metalite::meta_build()
#'
#'   analysis_plan <- metalite::plan(
#'     analysis = "ae_specific",
#'     population = "apat",
#'     observation = "wk12",
#'     parameter = "any"
#'   )
#'
#'   metadata_ae <- metalite::meta_adam(
#'     observation = metalite_sl_adae,
#'     population = metalite_sl_adsl
#'   ) |>
#'     metalite::define_plan(analysis_plan) |>
#'     metalite::define_population(
#'       name = "apat",
#'       group = "TRTA",
#'       subset = SAFFL == "Y",
#'       label = "All Participants as Treated"
#'     ) |>
#'     metalite::define_observation(
#'       name = "wk12",
#'       group = "TRTA",
#'       subset = SAFFL == "Y",
#'       label = "Weeks 0 to 12"
#'     ) |>
#'     metalite::define_parameter(
#'       name = "any",
#'       term1 = "",
#'       term2 = "",
#'       var = "AEDECOD",
#'       soc = "AEBODSYS",
#'       label = "All AEs"
#'     ) |>
#'     metalite::define_analysis(
#'       name = "ae_specific",
#'       title = "Participants With Adverse Events"
#'     ) |>
#'     metalite::meta_build()
#'
#'   react_disposition(
#'     metadata_sl = metadata_sl,
#'     metadata_ae = metadata_ae
#'   )
#' }
react_disposition <- function(
  metadata_sl,
  metadata_ae,
  analysis = "disp",
  trtvar = metalite::collect_adam_mapping(metadata_sl, population)$group,
  population = metadata_sl$plan$population[metadata_sl$plan$analysis == analysis],
  sl_parameter = paste(metadata_sl$plan$parameter[metadata_sl$plan$analysis == analysis], collapse = ";"),
  sl_col_selected = c("siteid", "subjid", "sex", "age", "weightbl"),
  sl_col_names = c("Site", "Subject ID", "Sex", "Age (Year)", "Weight (kg)"),
  ae_observation = "wk12",
  ae_population = population,
  ae_parameter = "any",
  ae_col_selected = c("AESOC", "ASTDT", "AENDT", "AETERM", "duration", "AESEV", "AESER", "related", "AEACN", "AEOUT"),
  ae_col_names = c("SOC", "Onset Date", "End Date", "AE", "Duraion", "Intensity", "Serious", "Related", "Action Taken", "Outcome"),
  display_total = TRUE,
  width = 1200
) {
  # ----------------------------------------- #
  #   total setting                           #
  # ----------------------------------------- #

  if (display_total == TRUE) {
    display_sl <- c("n", "prop", "total")
  } else {
    display_sl <- c("n", "prop")
  }

  # ----------------------------------------- #
  #   prepare the disposition table numbers   #
  # ----------------------------------------- #
  x_sl <- metadata_sl |>
    prepare_disposition(
      population = population,
      analysis = analysis,
      parameter = sl_parameter
    ) |>
    format_disposition(display_col = display_sl, digits_prop = 2)

  tbl_sl <- x_sl$tbl
  tbl_sl$var_label[tbl_sl$name == "Participants in population"] <- "Participants in population"

  # Define Column
  col_defs <- list()
  for (sl_name in names(tbl_sl)) {
    if (startsWith(sl_name, "n_")) {
      col_defs[[sl_name]] <- reactable::colDef(name = "n")
    } else if (startsWith(sl_name, "p_")) {
      col_defs[[sl_name]] <- reactable::colDef(name = "(%)")
    } else {
      col_defs[[sl_name]] <- reactable::colDef(name = " ")
    }
  }

  # Define Column Group
  col_group_defs <- list()
  for (i in 1:length(x_sl$group_label)) {
    group <- levels(x_sl$group_label)[i]
    col_group_defs <- append(
      col_group_defs,
      list(reactable::colGroup(
        name = group,
        columns = c(paste0("n_", i), paste0("p_", i))
      ))
    )
  }
  if (display_total == TRUE) {
    col_group_defs <- append(
      col_group_defs,
      list(reactable::colGroup(
        name = "Total",
        columns = c("n_9999", "p_9999")
      ))
    )
  }

  # Define columns for subject list
  sl_col_selected <- toupper(sl_col_selected)
  if (!(toupper(trtvar) %in% sl_col_selected)) {
    sl_col_selected <- c(toupper(trtvar), sl_col_selected)
    sl_col_names <- c("Treatment", sl_col_names)
  }
  u_sl_col_selected <- unique(c("USUBJID", sl_col_selected))
  if (!length(sl_col_names) == length(sl_col_selected)) {
    message(paste(
      "`sl_col_names` and `sl_col_selected` should have the same length.",
      "`sl_col_selected` will be used as column names."
    ))
    sl_col_names <- sl_col_selected
  }
  sl_col_def <- list()
  for (i in 1:length(sl_col_selected)) sl_col_def[[sl_col_selected[i]]] <- reactable::colDef(sl_col_names[i])

  # ----------------------------------------- #
  #   get AE listing                          #
  # ----------------------------------------- #
  ae_list <- metalite::collect_observation_record(metadata_ae, ae_population, ae_observation, parameter = ae_parameter, var = names(metadata_ae$data_observation))

  # Define columns for AE list
  if (!length(ae_col_names) == length(ae_col_selected)) {
    message(paste(
      "`ae_col_names` and `ae_col_selected` should have the same length.",
      "`ae_col_selected` will be used as column names."
    ))
    ae_col_names <- ae_col_selected
  }
  ae_col_def <- list()
  for (i in 1:length(ae_col_selected)) ae_col_def[[ae_col_selected[i]]] <- reactable::colDef(ae_col_names[i])

  # ----------------------------------------- #
  #   making react table                      #
  # ----------------------------------------- #
  trt_grp <- toupper(trtvar)
  # show participant details when category not in "participants in population", "discontinued", "participants ongoing", "complete"
  details <- function(index) {
    dcsreas <- stringr::str_trim(tolower(tbl_sl$name[index]))
    if (!is.na(tbl_sl$name[index]) & !(dcsreas %in% c("participants in population", "discontinued", "participants ongoing", "complete"))) {
      if (stringr::str_trim(tolower(tbl_sl$var_label[index])) == "trial disposition") {
        var <- metadata_sl$parameter[["disposition"]]$var
        var_lower <- metadata_sl$parameter[["disposition"]]$var_lower
      }
      if (stringr::str_trim(tolower(tbl_sl$var_label[index])) == "participant study medication disposition") {
        var <- metadata_sl$parameter[["medical-disposition"]]$var
        var_lower <- metadata_sl$parameter[["medical-disposition"]]$var_lower
      }
      # get discontinued subject list
      data_sl <- metalite::collect_population_record(metadata_sl, population, var = names(metadata_sl$data_population))
      usubjids <- data_sl$USUBJID |>
        subset(tolower(data_sl[[var_lower]]) == dcsreas & tolower(data_sl[[var]]) == "discontinued")
      subj_list <- data_sl |> subset(
        subset = data_sl$USUBJID %in% usubjids,
        select = u_sl_col_selected
      )

      subj_list[, sl_col_selected] |>
        reactable::reactable(
          filterable = TRUE, defaultExpanded = FALSE, striped = TRUE, groupBy = trt_grp,
          columns = sl_col_def,
          details = function(index) {
            usubjid <- subj_list$USUBJID[index]
            # get AE list of a subject if discontinued because of AE
            if ((var == "EOTSTT" && dcsreas %in% c("adverse event")) | (var == "EOSSTT" && dcsreas %in% c("other"))) {
              sub_ae_listing <- ae_list |> subset(
                subset = ae_list$USUBJID %in% usubjid,
                select = ae_col_selected
              )
              sub_ae_listing |> reactable::reactable(striped = FALSE, columns = ae_col_def, defaultExpanded = FALSE, filterable = TRUE)
            }
          }
        )
    }
  }


  reactable::reactable(
    tbl_sl,
    sortable = FALSE,
    groupBy = "var_label",
    width = width,
    columns = col_defs,
    columnGroups = col_group_defs,
    details = details
  )
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Prepare data for Subgroup Analysis for Baseline Characteristic
#'
#' @param outdata A metadata object created by [prepare_base_char_subgroup()].
#' @param display Column wants to display on the table.
#'   The term could be selected from `c("n", "prop", "total")`.
#'   "total" can display the total column for the first level header.
#' @param display_stat A vector of statistics term name.
#'   The term name could be selected from
#'   `c("mean", "sd", "se", "median", "q1 to q3", "range", "q1", "q3", "min", "max")`.
#' @param display_total A logic value of displaying the total column
#'   for the second level header.
#'
#' @return A list of analysis raw datasets.
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char_subgroup",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "age"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat",
#'     group = "TRTA",
#'     subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age",
#'     var = "AGE",
#'     label = "Age (years)",
#'     vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "base_char_subgroup",
#'     title = "Participant by Age Category and Sex"
#'   ) |>
#'   metalite::meta_build()
#'
#' outdata <- prepare_base_char_subgroup(
#'   meta,
#'   population = "apat",
#'   parameter = "age",
#'   subgroup_var = "TRTA",
#'   subgroup_header = c("SEX", "TRTA")
#' )
#'
#' outdata |> format_base_char_subgroup()
format_base_char_subgroup <- function(
  outdata,
  display = c("n", "prop", "total"),
  display_stat = c("mean", "sd", "median", "range"),
  display_total = TRUE
) {
  out_all <- outdata$out_all

  outlst <- list()
  for (i in seq_along(out_all)) {
    tbl <- out_all[[i]] |>
      format_base_char(
        display_col = display,
        digits_prop = 1,
        display_stat = display_stat
      )

    names(tbl$tbl)[-1] <- ifelse(grepl("_label", names(tbl$tbl)[-1]) %in% "FALSE", paste0(names(out_all[i]), names(tbl$tbl)[-1]), names(tbl$tbl)[-1])

    # Get row order from total
    if (i == length(out_all)) {
      tbl_order <- tbl$tbl[, c("name", "var_label")]
      tbl_order$order <- as.numeric(rownames(tbl$tbl))
    }

    outlst[[i]] <- tbl$tbl
  }

  names(outlst) <- names(out_all)
  if (!display_total) {
    outlst <- outlst[-length(outlst)]
  }

  # Left join to the frame with order
  tbl <- tbl_order
  for (x in outlst) {
    tbl <- merge(tbl, x, by = c("name", "var_label"), all.x = TRUE)
  }

  # Assign zero for missing data
  max_nchar <- apply(tbl[!tbl$name %in% c("Mean", "SD", "Median", "Range"), ], 2, function(x) {
    max(nchar(x), na.rm = TRUE)
  })
  tbl <- apply(tbl, 1, function(x) {
    if (is.na(x[["name"]]) | x[["name"]] %in% c("Participants in population", "Mean", "SD", "Median", "Range")) {
      x
    } else {
      sapply(names(tbl), function(y) {
        if (grepl("n_", y) & is.na(x[[y]])) {
          if (any(tbl$name %in% c("Mean", "SD", "Median", "Range"))) {
            x[[y]] <- "0"
          } else {
            x[[y]] <- paste0(paste0(rep(" ", (max_nchar[[y]] - 1)), collapse = ""), "0")
          }
        } else if (grepl("p_", y) & is.na(x[[y]])) {
          x[[y]] <- paste0(paste0(rep(" ", (max_nchar[[y]] - 5)), collapse = ""), "(0.0)")
        } else {
          x[[y]]
        }
      })
    }
  }, simplify = TRUE) |>
    t() |>
    as.data.frame()

  outdata$tbl <- tbl[order(tbl$order), ]
  outdata$display <- display
  outdata$display_stat <- display_stat
  outdata$display_total <- display_total
  outdata
}

meta <- meta_sl_test()
# Standard example
outdata <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "age",
  subgroup_var = "TRTA",
  subgroup_header = c("SEX", "TRTA")
)
# Without summary statistics
outdata_nostat <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "gender",
  subgroup_var = "TRTA",
  subgroup_header = c("AGEGR1", "TRTA")
)
# Get values
agegr1_value <- as.character(sort(unique(meta$data_population$AGEGR1)))
sex_value <- as.character(sort(unique(meta$data_population$SEX)))

# Testing
test_that("When display is n, prop then display only n and prop", {
  test1 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop")
  )
  exp_header <-
    c(
      lapply(c(outdata$subgroup, "Total"), function(x) paste0(x, "n_", seq_along(outdata$group))) |> unlist(),
      lapply(c(outdata$subgroup, "Total"), function(x) paste0(x, "p_", seq_along(outdata$group))) |> unlist()
    )

  expect_equal(test1$display, c("n", "prop"))
  expect_true(all(exp_header %in% names(test1$tbl)))
})

test_that("When display is n, prop, total then display only n, prop and total", {
  test2 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop", "total")
  )
  exp_header <-
    c(
      lapply(c(outdata$subgroup, "Total"), function(x) paste0(x, "n_", c(seq_along(outdata$group), 9999))) |> unlist(),
      lapply(c(outdata$subgroup, "Total"), function(x) paste0(x, "p_", c(seq_along(outdata$group), 9999))) |> unlist()
    )

  expect_equal(test2$display, c("n", "prop", "total"))
  expect_true(all(exp_header %in% names(test2$tbl)))
})

test_that("When display_stat contains mean then Mean row is included", {
  test3 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop"),
    display_stat = c("mean")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      NA,
      "Mean"
    ),
    test3$tbl[["name"]]
  )
})

test_that("When display_stat contains sd then SD row is included", {
  test4 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop"),
    display_stat = c("sd")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      NA,
      "SD"
    ),
    test4$tbl[["name"]]
  )
})

test_that("When display_stat contains median then Median row is included", {
  test5 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop"),
    display_stat = c("median")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      NA,
      "Median"
    ),
    test5$tbl[["name"]]
  )
})

test_that("When display_stat contains range then Range row is included", {
  test6 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop"),
    display_stat = c("range")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      NA,
      "Range"
    ),
    test6$tbl[["name"]]
  )
})

test_that("Summary statistics are not displyed when they are not included", {
  test7 <- format_base_char_subgroup(
    outdata_nostat,
    display = c("n", "prop")
  )

  expect_equal(
    c(
      "Participants in population",
      sex_value
    ),
    test7$tbl[["name"]]
  )
})

test_that("When display_total is FALSE w/ total then subgroup total columns are not displayed", {
  test8 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop", "total"),
    display_total = FALSE
  )
  exp_header <-
    c(
      lapply(outdata$subgroup, function(x) paste0(x, "n_", c(seq_along(outdata$group), 9999))) |> unlist(),
      lapply(outdata$subgroup, function(x) paste0(x, "p_", c(seq_along(outdata$group), 9999))) |> unlist()
    )

  expect_equal(test8$display_total, FALSE)
  expect_true(all(exp_header %in% names(test8$tbl)))
})

test_that("When display_total is FALSE w/o total then subgroup total columns are not displayed", {
  test9 <- format_base_char_subgroup(
    outdata,
    display = c("n", "prop"),
    display_total = FALSE
  )
  exp_header <-
    c(
      lapply(outdata$subgroup, function(x) paste0(x, "n_", c(seq_along(outdata$group)))) |> unlist(),
      lapply(outdata$subgroup, function(x) paste0(x, "p_", c(seq_along(outdata$group)))) |> unlist()
    )

  expect_equal(test9$display_total, FALSE)
  expect_true(all(exp_header %in% names(test9$tbl)))
})

## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150,
  eval = TRUE
)

## -----------------------------------------------------------------------------
library(metalite)
library(metalite.sl)

## -----------------------------------------------------------------------------
sl_plan <- plan(
  analysis = "base_char",
  population = "apat",
  observation = "apat",
  parameter = "age;gender;race"
)

metadata_sl <- meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  define_plan(sl_plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  define_parameter(name = "gender", var = "SEX", label = "Gender") |>
  define_parameter(name = "race", var = "RACE", label = "Race") |>
  define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group"
  ) |>
  meta_build()

## ----eval = FALSE-------------------------------------------------------------
# metadata_sl |>
#   prepare_base_char(
#     population = "apat",
#     analysis = "base_char",
#     parameter = "age;gender"
#   ) |>
#   format_base_char() |>
#   rtf_base_char(
#     source = "Source: [CDISCpilot: adam-adsl]",
#     path_outdata = tempfile(fileext = ".Rdata"),
#     path_outtable = tempfile(fileext = ".rtf")
#   )

## ----out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"----
knitr::include_graphics("pdf/base0char.pdf")

## -----------------------------------------------------------------------------
analysis_plan <- plan(
  analysis = "ae_specific",
  population = "apat",
  observation = "wk12",
  parameter = "rel"
)

metadata_ae <- meta_adam(
  observation = metalite_sl_adae,
  population = metalite_sl_adsl
) |>
  define_plan(analysis_plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "All Participants as Treated"
  ) |>
  define_observation(
    name = "wk12",
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "Weeks 0 to 12"
  ) |>
  define_parameter(
    name = "rel",
    term1 = "Drug-Related",
    term2 = "",
    subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
    var = "AEDECOD",
    soc = "AEBODSYS",
    label = "Drug-related AEs"
  ) |>
  define_analysis(
    name = "ae_specific",
    title = "Participants With Drug-Related Adverse Events"
  ) |>
  meta_build()

react_base_char(
  metadata_sl = metadata_sl,
  metadata_ae = metadata_ae,
  population = "apat",
  observation = "wk12",
  display_total = TRUE,
  sl_parameter = "age;race",
  ae_subgroup = c("age", "race"),
  ae_specific = "rel",
  width = 1200
)

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150
)

## ----setup, message=FALSE-----------------------------------------------------
library(metalite.sl)
library(metalite.ae)
library(metalite)
library(dplyr)

## -----------------------------------------------------------------------------
adsl <- metalite_sl_adsl
adae <- metalite_sl_adae

ae_plan <- plan(
  analysis = "ae_specific",
  population = "apat",
  observation = "wk12",
  parameter = "any"
)

metadata_ae <- meta_adam(observation = adae, population = adsl) |>
  define_plan(ae_plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "All Participants as Treated"
  ) |>
  define_observation(
    name = "wk12",
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "Weeks 0 to 12"
  ) |>
  define_parameter(
    name = "any",
    term1 = "",
    term2 = "",
    var = "AEDECOD",
    soc = "AEBODSYS",
    label = "All AEs"
  ) |>
  define_analysis(
    name = "ae_specific",
    title = "Participants With Adverse Events"
  ) |>
  meta_build()

head(adsl)

## -----------------------------------------------------------------------------
plan <- plan(
  analysis = "disp", population = "apat",
  observation = "apat", parameter = "disposition;medical-disposition"
)

## -----------------------------------------------------------------------------
meta <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y")
  ) |>
  define_parameter(
    name = "disposition",
    var = "EOSSTT",
    label = "Trial Disposition",
    var_lower = "DCSREAS"
  ) |>
  define_parameter(
    name = "medical-disposition",
    var = "EOTSTT",
    label = "Participant Study Medication Disposition",
    var_lower = "DCTREAS"
  ) |>
  define_analysis(
    name = "disp",
    title = "Disposition of Participant",
    label = "disposition table"
  ) |>
  meta_build()

## -----------------------------------------------------------------------------
react_disposition(
  metadata_sl = meta,
  metadata_ae = metadata_ae,
  width = 1200
)

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Deformat percent
#'
#' @param pct string eager to remove percent
#'
#' @return Numeric value without percent
#' @export
#'
#' @examples
#' defmt_pct("10.0%")
#' defmt_pct(c("10.0%", "(11.2%)"))
defmt_pct <- function(pct) {
  as.numeric(stringr::str_extract(pct, "\\d+\\.*\\d*"))
}

#' Save outputs for RTF generation
#'
#' @param outdata An `outdata` object.
#' @param path_outdata A character string of file path to save the outdata.
#' @param pat_outtable A character string of file path to save the RTF table.
#'
#' @noRd
rtf_output <- function(
  outdata,
  path_outdata,
  path_outtable
) {
  if (!is.null(path_outdata)) {
    save(outdata, file = path_outdata)
    message("The outdata is saved in", normalizePath(path_outdata))
  }

  if (!is.null(path_outtable)) {
    outdata$rtf |>
      r2rtf::rtf_encode() |>
      r2rtf::write_rtf(file = path_outtable)
    message("The output is saved in", normalizePath(path_outtable))
  }

  invisible(outdata)
}

#' Obtain a list of category ranges from a character label for exposure duration analysis
#'
#' @param labels A character vector of a category label
#'
#' @noRd
extract_duration_category_ranges <- function(labels) {
  times <- labels |>
    stringr::str_extract_all(pattern = "\\d+") |>
    lapply(function(x) {
      if (length(x) == 0) {
        stop("A real number for duration category is not recognized. Please rename the category label in the input data, or use `duration_category_list` and `duration_category_labels`.")
      }
      as.numeric(x)
    })

  factors <- labels |>
    stringr::str_extract_all(pattern = "\\d+ ?([a-zA-Z]+)") |>
    lapply(
      function(x) {
        unit <- stringr::str_extract(x, pattern = "\\d+ ?([a-zA-Z])", group = 1)
        factor <- sapply(unit, USE.NAMES = FALSE, function(y) {
          if (toupper(y) == "D") {
            1
          } else if (toupper(y) == "W") {
            7
          } else if (toupper(y) == "M") {
            30.4367
          } else if (toupper(y) == "Y") {
            365.24
          } else {
            warning("The unit of duration category is not recognized. The unit is handled as day(s).")
            1
          }
        })
        return(factor)
      }
    )

  list <- lapply(
    seq_along(times),
    function(x) {
      if (length(times[[x]]) < 2) {
        time <- c(times[[x]], rep(NA, 2 - length(times[[x]])))
      } else {
        time <- times[[x]]
      }
      if (length(factors[[x]]) == 1) {
        factor <- rep(factors[[x]], 2)
      } else if (length(factors[[x]]) == 0) {
        factor <- rep(1, 2)
      } else {
        factor <- factors[[x]]
      }
      return(time * factor)
    }
  )
  return(list)
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Prepare data for baseline characteristic table
#'
#' @param meta A metadata object created by metalite.
#' @param population A character value of population term name.
#'   The term name is used as key to link information.
#' @param analysis A character value of analysis term name.
#'   The term name is used as key to link information.
#' @param parameter A character value of parameter term name.
#'   The term name is used as key to link information.
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "age;gender;race"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat",
#'     group = "TRTA",
#'     subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age",
#'     var = "AGE",
#'     label = "Age (years)",
#'     vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'   metalite::define_parameter(name = "race", var = "RACE", label = "Race") |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |> prepare_sl_summary(population = "apat", analysis = "base_char")
prepare_sl_summary <- function(
  meta,
  population,
  analysis,
  parameter = paste(names(meta$parameter), collapse = ";")
) {
  parameters <- unlist(strsplit(parameter, ";"))
  observation <- population
  # obtain variables
  pop_var <- metalite::collect_adam_mapping(meta, population)$var
  par_var <- do.call(c, lapply(parameters, function(x) {
    metalite::collect_adam_mapping(meta, x)$var
  }))

  par_var_group <- do.call(c, lapply(parameters, function(x) {
    metalite::collect_adam_mapping(meta, x)$vargroup
  }))

  par_var_lower <- do.call(c, lapply(parameters, function(x) {
    metalite::collect_adam_mapping(meta, x)$var_lower
  }))

  pop_group <- metalite::collect_adam_mapping(meta, population)$group

  pop_id <- metalite::collect_adam_mapping(meta, population)$id

  # obtain data
  pop <- metalite::collect_population_record(meta, population, var = c(par_var, par_var_group, par_var_lower))

  # obtain group names
  group <- unique(pop[[pop_group]])

  # count the number of subjects in each arms
  n_pop <- metalite::n_subject(id = pop[[pop_id]], group = pop[[pop_group]])
  names(n_pop) <- do.call(
    c,
    lapply(
      factor(names(n_pop), levels = levels(pop[[pop_group]])) |> as.numeric(),
      function(x) {
        paste0("n_", x)
      }
    )
  )
  n_pop$n_9999 <- sum(n_pop[1, ])
  n_pop$name <- "Participants in population"
  n_pop <- n_pop[, c(length(group) + 2, 1:(length(group) + 1))]
  n_pop$var_label <- "-----"

  # Get the baseline characteristics variables in adsl
  # char_var <- collect_adam_mapping(meta, analysis)$var_name
  char_var <- par_var

  # Get the baseline characteristics counts
  char_n <- lapply(parameters, function(x) {
    collect_baseline(meta, population, x)[[2]]
  })

  # Get the baseline characteristics propositions
  char_prop <- lapply(parameters, function(x) {
    collect_baseline(meta, population, x)[[3]]
  })

  # Get the variable date type
  var_type <- lapply(parameters, function(x) {
    collect_baseline(meta, population, x)[[4]]
  })

  ans <- metalite::outdata(
    meta, population, observation, parameter,
    n = n_pop,
    order = NULL, group = pop_group, reference_group = NULL,
    char_n = char_n,
    char_var = char_var,
    char_prop = char_prop,
    var_type = var_type,
    group_label = unique(pop[[pop_group]]),
    analysis = analysis
  )

  return(ans)
}

library(metalite)
library(metalite.ae)
library(dplyr)
library(tidyr)

# Read data
adsl <- r2rtf::r2rtf_adsl
adsl$TRT01A <- factor(
  adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

# Define plan
plan <- plan(
  analysis = "base_char",
  population = "apat",
  observation = "apat",
  parameter = "age;agen;race;gender"
)

meta_test <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(
    plan = plan
  ) |>
  define_population(
    name = "apat",
    group = "TRT01A",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRT01A", "SAFFL", "AGEGR1", "AGE", "SEX", "RACE")
  ) |>
  define_observation(
    name = "apat",
    group = "TRT01A",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRT01A", "SAFFL", "AGEGR1", "AGE", "SEX", "RACE")
  ) |>
  define_parameter(
    name = "age",
    var = "AGEGR1",
    label = "Age (years)"
  ) |>
  define_parameter(
    name = "agen",
    var = "AGE",
    label = "Age (years)"
  ) |>
  define_parameter(
    name = "gender",
    var = "SEX",
    label = "Gender"
  ) |>
  define_parameter(
    name = "race",
    var = "RACE",
    label = "Race"
  ) |>
  define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group",
    var_name = c("AGEGR1", "AGE", "RACE", "SEX")
  )

# Prepare test data by the tested function
test_meta_base_char <- prepare_sl_summary(
  meta_test,
  population = "apat",
  analysis = "base_char",
  parameter = "age;agen;gender;race"
)

# all
test_meta_n_all <- tibble(test_meta_base_char$n)

# Count and proportion, or statistics for variables
test_meta_n_char <- NULL
test_meta_prop_char <- NULL
test_meta_n_num <- NULL
test_meta_prop_num <- NULL
for (i in (1:length(test_meta_base_char$char_var))) {
  if (test_meta_base_char$var_type[[i]] == "character") {
    test_meta_n_char <-
      rbind(
        test_meta_n_char,
        tibble(test_meta_base_char$char_n[[i]])
      )
    test_meta_prop_char <-
      rbind(
        test_meta_prop_char,
        tibble(test_meta_base_char$char_prop[[i]])
      )
  } else {
    test_meta_n_num <-
      rbind(
        test_meta_n_num,
        tibble(test_meta_base_char$char_n[[i]])
      )
    test_meta_prop_num <-
      rbind(
        test_meta_prop_num,
        tibble(test_meta_base_char$char_prop[[i]])
      )
  }
}


# Prepare compare data for calculation
adsl_tot <- adsl |> mutate(TRT01AN = 9999)
adsl_tot <- rbind(adsl, adsl_tot)
adsl_tot$AGEGR1 <- factor(adsl_tot$AGEGR1)
adsl_tot$SEX <- factor(adsl_tot$SEX)
adsl_tot$RACE <- factor(adsl_tot$RACE)

res_tot <- adsl_tot |>
  summarise(n = n_distinct(USUBJID), .by = c(TRT01AN, SAFFL))

# Testing
test_that("Group matching", {
  expect_equal(
    test_meta_base_char$group_label,
    factor(c("Placebo", "High Dose", "Low Dose"),
      levels = c("Placebo", "Low Dose", "High Dose")
    )
  )
})

test_that("Participants in population", {
  res <-
    res_tot |>
    mutate(x = case_when(
      TRT01AN == 9999 ~ "n_9999",
      TRUE ~ paste0("n_", row_number())
    ))

  pop_cnt <- res |>
    pivot_wider(
      id_cols = "SAFFL",
      names_from = "x",
      values_from = n,
      values_fill = list(n = 0)
    )

  expect_equal(
    test_meta_n_all |> select(c(n_1, n_2, n_3, n_9999)),
    tibble(pop_cnt) |> select(-c(SAFFL))
  )
  expect_equal(test_meta_base_char$n[["name"]], "Participants in population")
  expect_equal(test_meta_base_char$n[["var_label"]], "-----")
})

test_that("Character variables count", {
  char_var <- c("AGEGR1", "SEX", "RACE")
  res_frq_n <- NULL
  res_frq_prop <- NULL

  for (var in char_var) {
    res_frq <-
      adsl_tot |>
      summarise(n = n_distinct(USUBJID), .by = c(TRT01AN, SAFFL, !!var)) |>
      arrange(!!var, TRT01AN) |>
      mutate(x = case_when(
        TRT01AN == 0 ~ "Placebo",
        TRT01AN == 54 ~ "Low Dose",
        TRT01AN == 81 ~ "High Dose",
        TRT01AN == 9999 ~ "Total"
      )) |>
      rename(name = !!var)

    attr(res_frq[["name"]], "label") <- NULL

    res_frq <-
      data.frame(full_join(
        res_frq, res_tot |> rename(z = n),
        by = c("TRT01AN", "SAFFL"),
        multiple = "all"
      )) |>
      mutate(
        pct = 100 * n / z,
      ) |>
      mutate(p = case_when(
        TRT01AN == 0 ~ "Placebo",
        TRT01AN == 54 ~ "Low Dose",
        TRT01AN == 81 ~ "High Dose",
        TRT01AN == 9999 ~ "Total"
      ))

    res_frq1 <- res_frq |>
      filter(SAFFL == "Y") |>
      pivot_wider(
        id_cols = c("name"),
        names_from = "x",
        values_from = n,
        values_fill = c(n = 0)
      ) |>
      arrange(name) |>
      mutate(var_label = case_when(
        !!var == "AGEGR1" ~ "Age (years)",
        !!var == "SEX" ~ "Gender",
        !!var == "RACE" ~ "Race"
      ))

    res_frq2 <- res_frq |>
      filter(SAFFL == "Y") |>
      pivot_wider(
        id_cols = c("name"),
        names_from = "p",
        values_from = pct,
        values_fill = c(pct = 0)
      ) |>
      arrange(name) |>
      mutate(var_label = case_when(
        !!var == "AGEGR1" ~ "Age (years)",
        !!var == "SEX" ~ "Gender",
        !!var == "RACE" ~ "Race"
      ))

    res_frq_n <- rbind(res_frq_n, res_frq1)
    res_frq_prop <- rbind(res_frq_prop, res_frq2)
  }

  res_frq_n$name <- as.character(res_frq_n$name)
  res_frq_prop$name <- as.character(res_frq_prop$name)

  for (col in (names(res_frq_n))) {
    names(res_frq_n[[col]]) <- NULL
    names(res_frq_prop[[col]]) <- NULL
  }

  # Test n
  expect_equal(
    test_meta_n_char,
    tibble(res_frq_n)
  )
  # Test proportion
  expect_equal(
    test_meta_prop_char,
    tibble(res_frq_prop)
  )
})

test_that("Numeric variables summary", {
  char_var <- c("AGE")
  res_stat_n <- NULL
  res_stat_prop <- NULL

  for (var in char_var) {
    res_stat <-
      adsl_tot |>
      summarise(
        n = n_distinct(USUBJID, na.rm = TRUE),
        Mean = mean(AGE, na.rm = TRUE),
        SD = sd(AGE, na.rm = TRUE),
        SE = SD / sqrt(n),
        Median = median(AGE, na.rm = TRUE),
        Min = min(AGE, na.rm = TRUE),
        Max = max(AGE, na.rm = TRUE),
        Q1 = quantile(AGE, probs = 0.25, na.rm = TRUE),
        Q3 = quantile(AGE, probs = 0.75, na.rm = TRUE),
        .by = c(TRT01AN, SAFFL)
      ) |>
      mutate(
        Q1_to_Q3 = paste0(Q1, " to ", Q3),
        Range = paste0(Min, " to ", Max)
      ) |>
      arrange(TRT01AN) |>
      mutate(x = case_when(
        TRT01AN == 0 ~ "Placebo",
        TRT01AN == 54 ~ "Low Dose",
        TRT01AN == 81 ~ "High Dose",
        TRT01AN == 9999 ~ "Total"
      ))

    res_stat[c("n", "Mean", "SD", "SE", "Median", "Min", "Max")] <-
      lapply(
        res_stat[c("n", "Mean", "SD", "SE", "Median", "Min", "Max")],
        \(x) formatC(x, format = "f", digits = 1)
      )

    res_stat1 <- res_stat |>
      filter(SAFFL == "Y") |>
      select(-Q1, -Q3) |>
      select(-c(TRT01AN, SAFFL, n)) |>
      pivot_longer(
        cols = -c(x),
        names_to = "name",
        values_to = "stat"
      ) |>
      pivot_wider(
        id_cols = c("name"),
        names_from = "x",
        values_from = stat,
        values_fill = c(stat = "0")
      ) |>
      mutate(name = gsub("_", " ", name)) |>
      mutate(var_label = case_when(
        !!var == "AGE" ~ "Age (years)"
      ))

    res_stat1$name <- factor(res_stat1$name,
      levels = c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range")
    )

    res_stat_n <- rbind(
      res_stat_n,
      res_stat1 |> arrange(name)
    )
  }

  res_stat_n$name <- as.character(res_stat_n$name)

  for (col in (names(res_stat_n))) {
    names(res_stat_n[[col]]) <- NULL
  }

  # Test n
  expect_equal(
    test_meta_n_num,
    tibble(res_stat_n)
  )

  res_stat_prop <- res_stat_n
  res_stat_prop[c("Placebo", "Low Dose", "High Dose", "Total")] <- NA

  # Test proportion
  expect_equal(
    test_meta_prop_num,
    tibble(res_stat_prop)
  )
})

test_that("Population matching", {
  expect_equal(test_meta_base_char$population, "apat")
})

test_that("Observation matching", {
  expect_equal(test_meta_base_char$observation, "apat")
})

test_that("Parameter matching", {
  expect_equal(test_meta_base_char$parameter, "age;agen;gender;race")
})

test_that("Output from prepare_sl_summary is a list", {
  expect_true("outdata" %in% class(test_meta_base_char))
})

library(metalite)

set.seed(123)
metatest <- meta_sl_exposure_test()

outdata <- prepare_sl_summary(
  meta = metatest,
  population = "apat",
  analysis = "exp_dur",
  parameter = "expdur"
)


# #### Test 1 ######
test_that("rtf output: n, and prop, NO total. With 2 decimal places.", {
  tbl <- outdata |>
    format_exp_duration(
      display_col = c("n", "prop"),
      digits_prop = 2
    ) |>
    rtf_exp_duration(
      source = "Source: [CDISCpilot: adam-adexsum]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "exp0duration1.rtf")
    )

  expect_rtf_snapshot(tbl, "exp0duration1")
})

# #### Test 2 #####
test_that("rtf output: n, prop and total, with Landscape", {
  tbl <- outdata |>
    format_exp_duration(display_col = c("n", "prop", "total")) |>
    rtf_exp_duration(
      orientation = "landscape",
      col_rel_width = NULL,
      source = "Source: [CDISCpilot: adam-adexsum]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "exp0duration2.rtf")
    )

  expect_rtf_snapshot(tbl, "exp0duration2")
})


# #### Test 3 #####
test_that("rtf output: n, prop and total, with no value of col_rel_width", {
  tbl <- outdata |>
    format_exp_duration(display_col = c("n", "prop", "total")) |>
    rtf_exp_duration(
      col_rel_width = c(4, 2, 2, 2, 2, 2, 2, 3, 3, 3),
      source = "Source: [CDISCpilot: adam-adexsum]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "exp0duration3.rtf")
    )

  expect_rtf_snapshot(tbl, "exp0duration3")
})

library(metalite)
library(metalite.ae)
library(dplyr)
library(tidyr)

# Read data
adsl <- r2rtf::r2rtf_adsl


# Create ADEXSUM dataset
adexsum <- data.frame(USUBJID = adsl$USUBJID)
adexsum$TRTA <- factor(adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

adexsum$TRTAN <- adsl$TRT01AN
adexsum$SAFFL <- adsl$SAFFL

names(adexsum$TRTA) <- "TREATMENT"

adexsum$APERIODC <- "Base"
adexsum$APERIOD <- 1
adexsum$AVAL <- sample(x = 0:(24 * 7), size = length(adexsum$USUBJID), replace = TRUE)
adexsum$EXDURGR <- "not treated"
adexsum$EXDURGR[adexsum$AVAL >= 1] <- ">=1 day"
adexsum$EXDURGR[adexsum$AVAL >= 7] <- ">=7 days"
adexsum$EXDURGR[adexsum$AVAL >= 28] <- ">=28 days"
adexsum$EXDURGR[adexsum$AVAL >= 12 * 7] <- ">=12 weeks"
adexsum$EXDURGR[adexsum$AVAL >= 24 * 7] <- ">=24 weeks"

adexsum$EXDURGR <- factor(adexsum$EXDURGR,
  levels = c("not treated", ">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
)

plan <- metalite::plan(
  analysis = "exp_dur",
  population = "apat",
  observation = "apat",
  parameter = "expdur"
)


meta_test <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  )


# Prepare test data by the tested function
test_meta_exp_dur <- prepare_sl_summary(
  meta_test,
  population = "apat",
  analysis = "exp_dur",
  parameter = "expdur"
)

# all
test_meta_n_all <- tibble(test_meta_exp_dur$n)

# Count and proportion, or statistics for variables
test_meta_n_char <- NULL
test_meta_prop_char <- NULL
test_meta_n_num <- NULL
test_meta_prop_num <- NULL
test_meta_n_num1 <- NULL
test_meta_prop_num1 <- NULL

for (i in (1:length(test_meta_exp_dur$char_var))) {
  if (test_meta_exp_dur$var_type[[i]] == "integer") {
    test_meta_n_char <-
      rbind(
        test_meta_n_char,
        tibble(test_meta_exp_dur$char_n[[i]])
      )
    test_meta_prop_char <-
      rbind(
        test_meta_prop_char,
        tibble(test_meta_exp_dur$char_prop[[i]])
      )
  } else {
    test_meta_n_num <-
      rbind(
        test_meta_n_num,
        tibble(test_meta_exp_dur$char_n[[i]])
      )
    test_meta_prop_num <-
      rbind(
        test_meta_prop_num,
        tibble(test_meta_exp_dur$char_prop[[i]])
      )
  }
}


# Prepare compare data for calculation
adexsum_tot <- adexsum |>
  select(-c(TRTAN)) |>
  mutate(TRTA = "Overall")

adexsum_tot <- adexsum_tot |> mutate(TRTAN = 9999)

adexsum_tot <- rbind(adexsum, adexsum_tot)

adexsum_tot <- adexsum_tot |> filter(APERIOD == 1 & AVAL > 0 & SAFFL == "Y")


res_tot <- adexsum_tot |>
  summarise(n = n_distinct(USUBJID), .by = c(TRTAN, TRTA))

# Testing

# 1
test_that("Group matching", {
  expect_equal(
    test_meta_exp_dur$group_label,
    factor(c("Placebo", "High Dose", "Low Dose"),
      levels = c("Placebo", "Low Dose", "High Dose")
    )
  )
})


# 2
test_that("Participants in population", {
  res <-
    res_tot |>
    arrange(TRTAN) |>
    mutate(x = case_when(
      TRTA == "Overall" ~ "n_9999",
      TRUE ~ paste0("n_", row_number())
    ))


  pop_cnt <- res |>
    select(-c(TRTA, TRTAN)) |>
    pivot_wider(
      names_from = "x",
      values_from = n,
      values_fill = list(n = 0)
    )


  expect_equal(
    test_meta_n_all |> select(c(n_1, n_2, n_3, n_9999)),
    tibble(pop_cnt)
  )

  expect_equal(test_meta_exp_dur$n[["name"]], "Participants in population")
  expect_equal(test_meta_exp_dur$n[["var_label"]], "-----")
})


# 3
test_that("Character variables count", {
  char_var <- c("EXDURGR")
  res_frq_n <- NULL
  res_frq_prop <- NULL

  for (var in char_var) {
    res_frq <-
      adexsum_tot |>
      summarise(n = n_distinct(USUBJID), .by = c(TRTAN, TRTA, !!var)) |>
      arrange(!!var, TRTAN) |>
      mutate(x = case_when(
        TRTAN == 0 ~ "Placebo",
        TRTAN == 54 ~ "Low Dose",
        TRTAN == 81 ~ "High Dose",
        TRTAN == 9999 ~ "Total"
      )) |>
      rename(name = !!var)

    attr(res_frq[["name"]], "label") <- NULL

    res_frq <-
      data.frame(full_join(
        res_frq, res_tot |> rename(z = n, TRTA_ = TRTA),
        by = c("TRTAN"),
        multiple = "all"
      )) |>
      mutate(
        pct = 100 * n / z,
      ) |>
      mutate(p = case_when(
        TRTAN == 0 ~ "Placebo",
        TRTAN == 54 ~ "Low Dose",
        TRTAN == 81 ~ "High Dose",
        TRTAN == 9999 ~ "Total"
      ))

    res_frq1 <- res_frq |>
      select(-c(TRTA_)) |>
      pivot_wider(
        id_cols = c("name"),
        names_from = "x",
        values_from = n,
        values_fill = c(n = 0)
      ) |>
      arrange(name)


    res_frq2 <- res_frq |>
      pivot_wider(
        id_cols = c("name"),
        names_from = "p",
        values_from = pct,
        values_fill = c(pct = 0)
      ) |>
      arrange(name)


    res_frq_n <- rbind(res_frq_n, res_frq1)
    res_frq_prop <- rbind(res_frq_prop, res_frq2)
  }


  for (col in (names(res_frq_n))) {
    names(res_frq_n[[col]]) <- NULL
    names(res_frq_prop[[col]]) <- NULL
  }


  test_meta_n_num <- dplyr::select(test_meta_n_char, -var_label)

  test_meta_prop_num <- dplyr::select(test_meta_prop_char, -var_label)


  test_meta_n_num1 <- test_meta_n_num[!(test_meta_n_num$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range", "not treated")), ]

  test_meta_prop_num1 <- test_meta_prop_num[!(test_meta_prop_num$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range", "not treated")), ]


  test_meta_n_num1$name <- factor(test_meta_n_num1$name, levels = levels(res_frq_n$name))
  test_meta_prop_num1$name <- factor(test_meta_prop_num1$name, levels = levels(res_frq_prop$name))

  # Specify the variables to be updated
  vars_to_update <- c("Placebo", "Low Dose", "High Dose", "Total")

  # Update selected variables to character type
  test_meta_n_num1 <- test_meta_n_num1 %>%
    mutate_at(vars_to_update, as.integer)

  # Filter out empty line with NA
  test_meta_n_num1 <- na.omit(test_meta_n_num1)

  # Remove the na.action attribute from the object to avoid inequality comparsion at below expect_equal" step
  attr(test_meta_n_num1, "na.action") <- NULL

  # Filter out empty line with NA
  test_meta_prop_num1 <- na.omit(test_meta_prop_num1)
  # Remove the na.action attribute from the object to avoid inequality comparsion at below "expect_equal" step
  attr(test_meta_prop_num1, "na.action") <- NULL

  # Test n
  expect_equal(
    test_meta_n_num1,
    tibble(res_frq_n)
  )

  # Test proportion
  expect_equal(
    test_meta_prop_num1,
    tibble(res_frq_prop)
  )
})


# 4
test_that("Numeric variables summary", {
  char_var <- c("AVAL")
  res_stat_n <- NULL
  res_stat_prop <- NULL

  for (var in char_var) {
    res_stat <-
      adexsum_tot |>
      summarise(
        n = n_distinct(USUBJID, na.rm = TRUE),
        Mean = mean(AVAL, na.rm = TRUE),
        SD = sd(AVAL, na.rm = TRUE),
        SE = SD / sqrt(n),
        Median = median(AVAL, na.rm = TRUE),
        Min = min(AVAL, na.rm = TRUE),
        Max = max(AVAL, na.rm = TRUE),
        Q1 = quantile(AVAL, probs = 0.25, na.rm = TRUE),
        Q3 = quantile(AVAL, probs = 0.75, na.rm = TRUE),
        .by = c(TRTAN, SAFFL)
      ) |>
      mutate(
        Q1_to_Q3 = paste0(Q1, " to ", Q3),
        Range = paste0(Min, " to ", Max)
      ) |>
      arrange(TRTAN) |>
      mutate(x = case_when(
        TRTAN == 0 ~ "Placebo",
        TRTAN == 54 ~ "Low Dose",
        TRTAN == 81 ~ "High Dose",
        TRTAN == 9999 ~ "Total"
      ))

    res_stat[c("n", "Mean", "SD", "SE", "Median", "Min", "Max")] <-
      lapply(
        res_stat[c("n", "Mean", "SD", "SE", "Median", "Min", "Max")],
        \(x) formatC(x, format = "f", digits = 1)
      )

    res_stat1 <- res_stat |>
      filter(SAFFL == "Y") |>
      select(-Q1, -Q3) |>
      select(-c(TRTAN, SAFFL, n)) |>
      pivot_longer(
        cols = -c(x),
        names_to = "name",
        values_to = "stat"
      ) |>
      pivot_wider(
        id_cols = c("name"),
        names_from = "x",
        values_from = stat,
        values_fill = c(stat = "0")
      ) |>
      mutate(name = gsub("_", " ", name)) |>
      mutate(var_label = case_when(
        !!var == "AVAL" ~ "Exposure Duration (Days)"
      ))

    res_stat1$name <- factor(res_stat1$name,
      levels = c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range")
    )

    res_stat_n <- rbind(
      res_stat_n,
      res_stat1 |> arrange(name)
    )
  }

  res_stat_n$name <- as.character(res_stat_n$name)

  for (col in (names(res_stat_n))) {
    names(res_stat_n[[col]]) <- NULL
  }


  test_meta_n_num1 <- test_meta_n_char[(test_meta_n_char$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range")), ]

  # Test n
  expect_equal(
    test_meta_n_num1,
    tibble(res_stat_n)
  )
})

test_that("Population matching", {
  expect_equal(test_meta_exp_dur$population, "apat")
})

test_that("Observation matching", {
  expect_equal(test_meta_exp_dur$observation, "apat")
})

test_that("Parameter matching", {
  expect_equal(test_meta_exp_dur$parameter, "expdur")
})

test_that("Output from prepare_sl_summary is a list", {
  expect_true("outdata" %in% class(test_meta_exp_dur))
})

library(metalite)
library(metalite.ae)
library(dplyr)
library(tidyr)

# Read data
adsl <- r2rtf::r2rtf_adsl


# Create ADEXSUM dataset
adexsum <- data.frame(USUBJID = adsl$USUBJID)
adexsum$TRTA <- factor(adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

adexsum$TRTAN <- adsl$TRT01AN
adexsum$SAFFL <- adsl$SAFFL

names(adexsum$TRTA) <- "TREATMENT"

adexsum$APERIODC <- "Base"
adexsum$APERIOD <- 1
adexsum$AVAL <- sample(x = 0:(24 * 7), size = length(adexsum$USUBJID), replace = TRUE)
adexsum$EXDURGR <- "not treated"
adexsum$EXDURGR[adexsum$AVAL >= 1] <- ">=1 day"
adexsum$EXDURGR[adexsum$AVAL >= 7] <- ">=7 days"
adexsum$EXDURGR[adexsum$AVAL >= 28] <- ">=28 days"
adexsum$EXDURGR[adexsum$AVAL >= 12 * 7] <- ">=12 weeks"
adexsum$EXDURGR[adexsum$AVAL >= 24 * 7] <- ">=24 weeks"

adexsum$EXDURGR <- factor(adexsum$EXDURGR,
  levels = c("not treated", ">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
)

plan <- metalite::plan(
  analysis = "exp_dur",
  population = "apat",
  observation = "apat",
  parameter = "expdur"
)

# Create test metadata
meta_test <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  )


# Prepare test data by the tested function
test_meta_exp_dur <- prepare_sl_summary(
  meta_test,
  population = "apat",
  analysis = "exp_dur",
  parameter = "expdur"
)


# Prepare adding more info
adexsum_tot <- adexsum |>
  select(-c(TRTAN)) |>
  mutate(TRTA = "Overall")

adexsum_tot <- adexsum_tot |> mutate(TRTAN = 9999)

adexsum_tot <- rbind(adexsum, adexsum_tot)

adexsum_tot <- adexsum_tot |> filter(APERIOD == 1 & AVAL > 0 & SAFFL == "Y")

exdurgr_value <- as.character(sort(unique(adexsum_tot$EXDURGR)))


# Testing


# 1
test_that("When display_col contains n and prop then the total column disappears", {
  dis <- c("n", "prop")
  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = dis
  )

  display_total <- "total" %in% dis

  if ("n" %in% dis) {
    if (display_total) {
      n_col <- test$char_n[[1]]
      names(n_col) <- c("name", paste0("n_", seq(1, 3)), "n_9999", "var_label")
    } else {
      n_col <- test$char_n[[1]] |> select(-c("Total"))
      names(n_col) <- c("name", paste0("n_", seq(1, 3)), "var_label")
    }
    n_col_names <- names(n_col)
  }

  if ("prop" %in% dis) {
    if (display_total) {
      prop_col <- test$char_prop[[1]]
      names(prop_col) <- c("name", paste0("p_", seq(1, 3)), "p_9999", "var_label")
    } else {
      prop_col <- test$char_n[[1]] |> select(-c("Total"))
      names(prop_col) <- c("name", paste0("p_", seq(1, 3)), "var_label")
    }
    prop_col_names <- names(prop_col)
  }

  expect_col_names <- sort(unique(c(n_col_names, prop_col_names)))

  format_tbl_col_names <- sort(names(test$tbl))

  expect_equal(format_tbl_col_names, expect_col_names)
})

# 2
test_that("When digits_prop is specified then the proportions are rounded to the decimal place", {
  dis <- c("n", "prop", "total")

  test_dig0 <- format_exp_duration(
    test_meta_exp_dur,
    display_col = dis,
    digits_prop = 0
  )

  test_dig2 <- format_exp_duration(
    test_meta_exp_dur,
    display_col = dis,
    digits_prop = 2
  )

  test_meta_exp_dur$char_prop
  test_meta_prop_char <- NULL

  for (i in (1:length(test_meta_exp_dur$char_var))) {
    test_meta_prop_char <-
      rbind(
        test_meta_prop_char,
        tibble(test_meta_exp_dur$char_prop[[i]])
      )
  }

  test_meta_prop_char_val <-
    test_meta_prop_char |> select(-c("name", "var_label"))

  res_frq_prop0 <-
    data.frame(
      test_meta_prop_char$name,
      apply(
        test_meta_prop_char_val,
        2,
        \(x) formatC(paste0("(", formatC(x, digits = 0, format = "f"), ")"), format = "f")
      )
    )

  res_frq_prop2 <-
    data.frame(
      test_meta_prop_char$name,
      apply(
        test_meta_prop_char_val,
        2,
        \(x) formatC(paste0("(", formatC(x, digits = 2, format = "f"), ")"), format = "f")
      )
    )

  if ("total" %in% dis) {
    names(res_frq_prop0) <- c("name", paste0("p_", seq(1, length(test_meta_exp_dur$group_label))), "p_9999")
    names(res_frq_prop2) <- c("name", paste0("p_", seq(1, length(test_meta_exp_dur$group_label))), "p_9999")
  } else {
    names(res_frq_prop0) <- c("name", paste0("p_", seq(1, length(test_meta_exp_dur$group_label))))
    names(res_frq_prop2) <- c("name", paste0("p_", seq(1, length(test_meta_exp_dur$group_label))))
  }

  test_dig0dat <- test_dig0$tbl |>
    filter(!name %in% c("Participants in population", "Mean", "SD", "SE", "Median", "Q1 to Q3", "Range", "Min", "Max")) |>
    select(c("name", starts_with("p_")))


  # Filter out empty line with NA
  test_dig0dat <- na.omit(test_dig0dat)
  # Remove the na.action attribute from the object to avoid inequality comparsion at below expect_equal" step
  attr(test_dig0dat, "na.action") <- NULL

  res_frq_prop0_tst <- res_frq_prop0 |>
    filter(!name %in% c("Participants in population", "Mean", "SD", "SE", "Median", "Q1 to Q3", "Range", "Min", "Max"))
  # Filter out empty line with (NA)
  res_frq_prop0_tst <- na.omit(res_frq_prop0_tst)
  # Remove the na.action attribute from the object to avoid inequality comparsion at below expect_equal" step
  attr(res_frq_prop0_tst, "na.action") <- NULL

  expect_equal(
    test_dig0dat,
    res_frq_prop0_tst
  )


  test_dig2_tst <- test_dig2$tbl |>
    filter(!name %in% c("Participants in population", "Mean", "SD", "SE", "Median", "Q1 to Q3", "Range", "Min", "Max")) |>
    select(c("name", starts_with("p_")))

  # Filter out empty line with NA
  test_dig2_tst <- na.omit(test_dig2_tst)
  # Remove the na.action attribute from the object to avoid inequality comparsion at below expect_equal" step
  attr(test_dig2_tst, "na.action") <- NULL


  res_frq_prop2_tst <- res_frq_prop2 |>
    filter(!name %in% c("Participants in population", "Mean", "SD", "SE", "Median", "Q1 to Q3", "Range", "Min", "Max"))

  # Filter out empty line with NA
  res_frq_prop2_tst <- na.omit(res_frq_prop2_tst)
  # Remove the na.action attribute from the object to avoid inequality comparsion at below expect_equal" step
  attr(res_frq_prop2_tst, "na.action") <- NULL


  expect_equal(
    test_dig2_tst,
    res_frq_prop2_tst
  )
})

# 3
test_that("When display_stat contains mean then Mean row is included", {
  hold <- c("SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range")

  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = c("n", "prop", "total"),
    display_stat = c("mean")
  )

  test_nm3 <- test$tbl[["name"]][!as.vector(test$tbl[["name"]]) %in% hold]

  expect_equal(
    as.vector(c(
      "Participants in population", "not treated",
      exdurgr_value,
      "Mean"
    )),
    test_nm3[!is.na(test_nm3)]
  )
})

# 4
test_that("When display_stat contains sd then SD row is included", {
  hold <- c("Mean", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range")

  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = c("n", "prop", "total"),
    display_stat = c("sd")
  )

  test_nm4 <- test$tbl[["name"]][!as.vector(test$tbl[["name"]]) %in% hold]

  expect_equal(
    as.vector(c(
      "Participants in population", "not treated",
      exdurgr_value,
      "SD"
    )),
    test_nm4[!is.na(test_nm4)]
  )
})

# 5
test_that("When display_stat contains se then SE row is included", {
  hold <- c("Mean", "SD", "Median", "Min", "Max", "Q1 to Q3", "Range")

  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = c("n", "prop", "total"),
    display_stat = c("se")
  )

  test_nm4 <- test$tbl[["name"]][!as.vector(test$tbl[["name"]]) %in% hold]

  expect_equal(
    as.vector(c(
      "Participants in population", "not treated",
      exdurgr_value,
      "SE"
    )),
    test_nm4[!is.na(test_nm4)]
  )
})

# 6
test_that("When display_stat contains median then Median row is included", {
  hold <- c("Mean", "SD", "SE", "Min", "Max", "Q1 to Q3", "Range")

  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = c("n", "prop", "total"),
    display_stat = c("median")
  )

  test_nm6 <- test$tbl[["name"]][!as.vector(test$tbl[["name"]]) %in% hold]

  expect_equal(
    as.vector(c(
      "Participants in population", "not treated",
      exdurgr_value,
      "Median"
    )),
    test_nm6[!is.na(test_nm6)]
  )
})

# 7

test_that("When display_stat contains q1 to q3 then q1 to q3 row is included", {
  hold <- c("Mean", "SD", "SE", "Min", "Max", "Median", "Range")

  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = c("n", "prop", "total"),
    display_stat = c("q1 to q3")
  )

  test_nm7 <- test$tbl[["name"]][!as.vector(test$tbl[["name"]]) %in% hold]

  expect_equal(
    as.vector(c(
      "Participants in population", "not treated",
      exdurgr_value,
      "Q1 to Q3"
    )),
    test_nm7[!is.na(test_nm7)]
  )
})

# 8

test_that("When display_stat contains range then Range row is included", {
  hold <- c("Mean", "SD", "SE", "Min", "Max", "Median", "Q1 to Q3")

  test <- format_exp_duration(
    test_meta_exp_dur,
    display_col = c("n", "prop", "total"),
    display_stat = c("range")
  )

  test_nm8 <- test$tbl[["name"]][!as.vector(test$tbl[["name"]]) %in% hold]

  expect_equal(
    as.vector(c(
      "Participants in population", "not treated",
      exdurgr_value,
      "Range"
    )),
    test_nm8[!is.na(test_nm8)]
  )
})

library(metalite)
library(metalite.ae)
library(dplyr)
library(tidyr)

# Read data
adsl <- r2rtf::r2rtf_adsl
adsl$TRT01A <- factor(
  adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

# Create test metadata
test_meta_base_char <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(
    plan = plan(
      analysis = "base_char",
      population = "apat",
      observation = "apat",
      parameter = "age;agen;race;gender"
    )
  ) |>
  define_population(
    name = "apat",
    group = "TRT01A",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRT01A", "SAFFL", "AGEGR1", "AGE", "SEX", "RACE")
  ) |>
  define_observation(
    name = "apat",
    group = "TRT01A",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRT01A", "SAFFL", "AGEGR1", "AGE", "SEX", "RACE")
  ) |>
  define_parameter(
    name = "age",
    var = "AGEGR1",
    label = "Age (years)"
  ) |>
  define_parameter(
    name = "agen",
    var = "AGE",
    label = "Age (years)"
  ) |>
  define_parameter(
    name = "gender",
    var = "SEX",
    label = "Gender"
  ) |>
  define_parameter(
    name = "race",
    var = "RACE",
    label = "Race"
  ) |>
  define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group",
    var_name = c("AGEGR1", "AGE", "RACE", "SEX")
  ) |>
  prepare_sl_summary(
    population = "apat",
    analysis = "base_char",
    parameter = "age;agen;gender;race"
  )

# Append total
adsl_tot <- adsl |> mutate(TRT01AN = 9999)
adsl_tot <- rbind(adsl, adsl_tot)

# Prepare check value for character variables
adsl_tot$AGEGR1 <- factor(adsl_tot$AGEGR1)
adsl_tot$SEX <- factor(adsl_tot$SEX)
adsl_tot$RACE <- factor(adsl_tot$RACE)

agegr1_value <- as.character(sort(unique(adsl_tot$AGEGR1)))
sex_value <- as.character(sort(unique(adsl_tot$SEX)))
race_value <- as.character(sort(unique(adsl_tot$RACE)))

# Testing
test_that("When display_col contains n and prop then the total column disappears", {
  dis <- c("n", "prop")
  test <- format_base_char(
    test_meta_base_char,
    display_col = dis
  )

  display_total <- "total" %in% dis

  if ("n" %in% dis) {
    if (display_total) {
      n_col <- test$char_n[[1]]
      names(n_col) <- c("name", paste0("n_", seq(1, 3)), "n_9999", "var_label")
    } else {
      n_col <- test$char_n[[1]] |> select(-c("Total"))
      names(n_col) <- c("name", paste0("n_", seq(1, 3)), "var_label")
    }
    n_col_names <- names(n_col)
  }

  if ("prop" %in% dis) {
    if (display_total) {
      prop_col <- test$char_prop[[1]]
      names(prop_col) <- c("name", paste0("p_", seq(1, 3)), "p_9999", "var_label")
    } else {
      prop_col <- test$char_n[[1]] |> select(-c("Total"))
      names(prop_col) <- c("name", paste0("p_", seq(1, 3)), "var_label")
    }
    prop_col_names <- names(prop_col)
  }

  expect_col_names <- sort(unique(c(n_col_names, prop_col_names)))

  format_tbl_col_names <- sort(names(test$tbl))

  expect_equal(format_tbl_col_names, expect_col_names)
})

test_that("When digits_prop is specified then the proportions are rounded to the decimal place", {
  dis <- c("n", "prop", "total")

  test_dig0 <- format_base_char(
    test_meta_base_char,
    display_col = dis,
    digits_prop = 0
  )

  test_dig2 <- format_base_char(
    test_meta_base_char,
    display_col = dis,
    digits_prop = 2
  )

  test_meta_base_char$char_prop
  test_meta_prop_char <- NULL
  for (i in (1:length(test_meta_base_char$char_var))) {
    if (test_meta_base_char$var_type[[i]] == "character") {
      test_meta_prop_char <-
        rbind(
          test_meta_prop_char,
          tibble(test_meta_base_char$char_prop[[i]])
        )
    }
  }

  test_meta_prop_char_val <-
    test_meta_prop_char |> select(-c("name", "var_label"))

  res_frq_prop0 <-
    data.frame(
      test_meta_prop_char$name,
      apply(
        test_meta_prop_char_val,
        2,
        \(x) formatC(paste0("(", formatC(x, digits = 0, format = "f"), ")"), format = "f")
      )
    )

  res_frq_prop2 <-
    data.frame(
      test_meta_prop_char$name,
      apply(
        test_meta_prop_char_val,
        2,
        \(x) formatC(paste0("(", formatC(x, digits = 2, format = "f"), ")"), format = "f")
      )
    )

  if ("total" %in% dis) {
    names(res_frq_prop0) <- c("name", paste0("p_", seq(1, length(test_meta_base_char$group_label))), "p_9999")
    names(res_frq_prop2) <- c("name", paste0("p_", seq(1, length(test_meta_base_char$group_label))), "p_9999")
  } else {
    names(res_frq_prop0) <- c("name", paste0("p_", seq(1, length(test_meta_base_char$group_label))))
    names(res_frq_prop2) <- c("name", paste0("p_", seq(1, length(test_meta_base_char$group_label))))
  }

  expect_equal(
    test_dig0$tbl |>
      filter(!name %in% c("Participants in population", "Mean", "SD", "SE", "Median", "Q1 to Q3", "Range")) |>
      select(c("name", starts_with("p_"))),
    res_frq_prop0
  )

  expect_equal(
    test_dig2$tbl |>
      filter(!name %in% c("Participants in population", "Mean", "SD", "SE", "Median", "Q1 to Q3", "Range")) |>
      select(c("name", starts_with("p_"))),
    res_frq_prop2
  )
})

test_that("When display_stat contains mean then Mean row is included", {
  test <- format_base_char(
    test_meta_base_char,
    display_col = c("n", "prop", "total"),
    display_stat = c("mean")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      "Mean",
      sex_value,
      race_value
    ),
    test$tbl[["name"]]
  )
})

test_that("When display_stat contains sd then SD row is included", {
  test <- format_base_char(
    test_meta_base_char,
    display_col = c("n", "prop", "total"),
    display_stat = c("sd")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      "SD",
      sex_value,
      race_value
    ),
    test$tbl[["name"]]
  )
})

test_that("When display_stat contains se then SE row is included", {
  test <- format_base_char(
    test_meta_base_char,
    display_col = c("n", "prop", "total"),
    display_stat = c("se")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      "SE",
      sex_value,
      race_value
    ),
    test$tbl[["name"]]
  )
})

test_that("When display_stat contains median then Median row is included", {
  test <- format_base_char(
    test_meta_base_char,
    display_col = c("n", "prop", "total"),
    display_stat = c("median")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      "Median",
      sex_value,
      race_value
    ),
    test$tbl[["name"]]
  )
})

test_that("When display_stat contains q1 to q3 then q1 to q3 row is included", {
  test <- format_base_char(
    test_meta_base_char,
    display_col = c("n", "prop", "total"),
    display_stat = c("q1 to q3")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      "Q1 to Q3",
      sex_value,
      race_value
    ),
    test$tbl[["name"]]
  )
})

test_that("When display_stat contains range then Range row is included", {
  test <- format_base_char(
    test_meta_base_char,
    display_col = c("n", "prop", "total"),
    display_stat = c("range")
  )

  expect_equal(
    c(
      "Participants in population",
      agegr1_value,
      "Range",
      sex_value,
      race_value
    ),
    test$tbl[["name"]]
  )
})

expect_rtf_snapshot <- function(rtf_obj, name) {
  path_rtf <- file.path(tempdir(), paste0(name, ".rtf"))
  path_rdata <- tempfile(fileext = ".Rdata")

  if (inherits(rtf_obj, "list") && !is.null(rtf_obj$path_outtable)) {
    rtf_obj$path_outtable <- path_rtf
  }
  if (inherits(rtf_obj, "list") && !is.null(rtf_obj$path_outdata)) {
    rtf_obj$path_outdata <- path_rdata
  }

  if (file.exists(path_rtf)) {
    rtf_content <- readLines(path_rtf, warn = FALSE)

    rtf_snapshot_dir <- file.path("rtf")
    dir.create(rtf_snapshot_dir, showWarnings = FALSE, recursive = TRUE)
    file.copy(path_rtf, file.path(rtf_snapshot_dir, paste0(name, ".rtf")), overwrite = TRUE)

    testthat::expect_snapshot(
      writeLines(rtf_content)
    )
  } else {
    stop("RTF file was not generated at: ", path_rtf)
  }

  invisible(rtf_obj)
}

library(metalite)

adsl <- r2rtf::r2rtf_adsl

set.seed(123)

meta <- meta_sl_test()
outdata <- prepare_disposition(meta,
  analysis = "disp",
  population = "apat",
  parameter = "disposition;medical-disposition"
)

#### Test 1 ######
test_that("rtf output: n, prop, total", {
  tbl <- outdata |>
    format_disposition(
      display_stat = c("mean", "sd", "median", "range"),
      display_col = c("n", "prop", "total")
    ) |>
    rtf_disposition(
      orientation = "landscape",
      col_rel_width = c(4, rep(1, 9)),
      "Source: [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "disposition1.rtf")
    )

  expect_rtf_snapshot(tbl, "disposition1")
})

#### Test 2 ######
test_that("rtf output: n, prop, total (no display_stat)", {
  tbl <- outdata |>
    format_disposition(
      display_stat = c(),
      display_col = c("n", "prop", "total")
    ) |>
    rtf_disposition(
      orientation = "landscape",
      col_rel_width = c(4, rep(1, 9)),
      "Source: [CDISCpilot: adam-adsl]",
      path_outdata = tempfile(fileext = ".Rdata"),
      path_outtable = file.path(tempdir(), "disposition2.rtf")
    )

  expect_rtf_snapshot(tbl, "disposition2")
})

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Add cumulative count and summary stats for categories for exposure duration analysis
#'
#' @param outdata An `outdata` object created by [prepare_exp_duration()].
#' @param category_section_label A character value of section label.
#'  If `NULL`, the parameter label is used with "(cumulative)".
#' @param duration_category_list A list of duration category ranges.
#'   Must be real numbers and may overlap or be mutually exclusive.
#'   A list should be in the form of `list(c(low1, high1), c(low2, high2), ...)`.
#'   If `NA` is included in the range, it is treated as `-Inf` or `Inf`.
#'   The range is defined as `low <= x < high` for each.
#' @param duration_category_labels A character vector of internal labels.
#'   Labels to be displayed for the duration_category_list values.
#'   Must be the same length as duration_category_list.
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adexsum,
#'   observation = metalite_sl_adexsum
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "exp_dur", population = "apat",
#'     observation = "apat", parameter = "expdur"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
#'   ) |>
#'   metalite::define_parameter(
#'     name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
#'     label = "Exposure Duration (Days)", vargroup = "EXDURGR"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "exp_dur", title = "Summary of Exposure Duration",
#'     label = "exposure duration table"
#'   ) |>
#'   metalite::meta_build()
#'
#' outdata <- meta |> prepare_exp_duration()
#' outdata |>
#'   extend_exp_duration(
#'     duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
#'     duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
#'   )
extend_exp_duration <- function(outdata,
                                category_section_label = paste0(metalite::collect_adam_mapping(outdata$meta, outdata$parameter)$label, " (extend)"),
                                duration_category_list = extract_duration_category_ranges(duration_category_labels),
                                duration_category_labels = levels(outdata$meta$data_population[[metalite::collect_adam_mapping(outdata$meta, outdata$parameter)$vargroup]])) {
  res <- outdata
  meta <- res$meta
  analysis <- res$analysis
  population <- res$population
  parameter <- res$parameter

  # Input check
  if (!length(unlist(strsplit(parameter, ";"))) == 1) {
    stop("Only one parameter is allowed with `duration_category_list`.")
  }
  if (!is.null(duration_category_list)) {
    if (!length(duration_category_list) == length(duration_category_labels)) {
      stop("Length of `duration_category_list` and `duration_category_labels` should be the same.")
    }
    if (!is.list(duration_category_list)) {
      stop("`duration_category_list` should be a list of range vectors.")
    }
    if (!all(sapply(duration_category_list, function(x) {
      length(x) == 2
    }))) {
      stop("Each element of `duration_category_list` should be a vector of length 2 (low, high).")
    }
    if (!all(sapply(duration_category_list, function(x) {
      class(x) %in% c("numeric", "integer")
    }))) {
      stop("Each element of `duration_category_list` allows `NA`, numeric or integer.")
    }
  }

  char_n <- res$char_n[[1]]
  observation <- meta$plan[meta$plan$analysis == analysis, ]$observation

  # obtain variables
  pop_var <- metalite::collect_adam_mapping(meta, population)$var
  obs_var <- metalite::collect_adam_mapping(meta, observation)$var
  par_var <- metalite::collect_adam_mapping(meta, parameter)$var
  par_var_group <- metalite::collect_adam_mapping(meta, parameter)$vargroup

  pop_group <- metalite::collect_adam_mapping(meta, population)$group
  obs_group <- metalite::collect_adam_mapping(meta, observation)$group

  pop_id <- metalite::collect_adam_mapping(meta, population)$id
  obs_id <- metalite::collect_adam_mapping(meta, observation)$id

  # variable check
  if (!res$var_type[[1]] %in% c("numeric", "integer")) {
    stop("The variable type of the parameter should be continuous to apply `extend_exp_duration`.")
  }

  # obtain data
  pop <- metalite::collect_population_record(meta, population, var = c(par_var))

  # obtain group names
  group <- unique(pop[[pop_group]])

  # count the number of subjects in each arms
  n_pop <- metalite::n_subject(id = pop[[pop_id]], group = pop[[pop_group]])
  names(n_pop) <- do.call(
    c,
    lapply(
      factor(names(n_pop), levels = levels(pop[[pop_group]])) |> as.numeric(),
      function(x) {
        paste0("n_", x)
      }
    )
  )
  n_pop$n_9999 <- sum(n_pop[1, ])
  n_pop$name <- "Participants in population"
  n_pop <- n_pop[, c(length(group) + 2, 1:(length(group) + 1))]

  # create category

  data_population <- meta$data_population

  # `var_group` is specified with numeric variable `par_var`
  if (!is.null(par_var_group) & !is.null(par_var)) {
    if (!is.factor(data_population[[par_var_group]])) {
      data_population[[par_var_group]] <- factor(data_population[[par_var_group]], levels = levels(unique(data_population[[par_var_group]])))
    }
    category_conditions <- paste0("==", "'", levels(unique(data_population[[par_var_group]])), "'")
    category_labels <- levels(unique(data_population[[par_var_group]]))
    char_stat_groups <- list()

    # calculate for each category
    for (i in seq_along(category_conditions)) {
      condition <- category_conditions[i]
      label <- category_labels[i]

      # Create subgroup
      if (!par_var_group == "TRTDURGR") {
        data_population$TRTDURGR <- data_population[[par_var_group]]
      }
      data_population$TRTDURGR <- factor(data_population[[par_var_group]], levels = label)
      # Create metadata for subgroup
      pop_subset <- metalite::collect_adam_mapping(meta, population)$subset
      pop_subset <- rlang::quo(TRTDURGR == !!label & !!pop_subset)

      meta_group <- meta_sl(
        data_population,
        dataset_observation = NULL,
        population_term = population,
        observation_term = NULL,
        parameter_term = paste0(parameter, "_group"),
        parameter_var = par_var,
        parameter_labels = metalite::collect_adam_mapping(meta, parameter)$label,
        analysis_term = paste0(analysis, "_group"),
        analysis_title = metalite::collect_adam_mapping(meta, analysis)$title,
        population_subset = !!rlang::enquo(pop_subset),
        observation_subset = NULL,
        population_label = metalite::collect_adam_mapping(meta, population)$label,
        treatment_group = metalite::collect_adam_mapping(meta, population)$group
      )

      if (nrow(metalite::collect_population_record(meta_group, population)) > 0) {
        char_stat_group <- collect_baseline(meta_group, population, paste0(names(meta$parameter), "_group"))[[2]]
        sum <- char_stat_group
        sum[names(char_n)[!names(char_n) %in% names(sum)]] <- NA
        sum <- sum[, names(char_n)]
        char_stat_groups[[label]] <- sum
        outdata$char_stat_groups <- char_stat_groups
      }
    }
  }
  # Duration category is specified
  if (!is.null(duration_category_list) & !is.null(par_var)) {
    data_population$TRTDURGR <- NA
    char_stat_cums <- list()
    count_cum <- data.frame()
    # calculate for each category
    for (i in seq_along(duration_category_list)) {
      condition <- duration_category_list[[i]]
      low <- ifelse(is.na(condition[1]), -Inf, condition[1])
      high <- ifelse(is.na(condition[2]), Inf, condition[2])
      if (high <= low) {
        warning("The upper limit of the range should be greater than the lower limit.")
      }
      label <- duration_category_labels[i]
      filter <- paste(low, "<=", "data_population[par_var] & data_population[par_var]", "<", high)
      data_population$TRTDURGR[eval(parse(text = filter))] <- label

      # Create subgroup
      # Create metadata for subgroup
      pop_subset <- metalite::collect_adam_mapping(meta, population)$subset
      pop_subset <- rlang::quo(TRTDURGR == !!label & !!pop_subset)

      meta_cum <- meta_sl(
        data_population,
        dataset_observation = NULL,
        population_term = population,
        observation_term = NULL,
        parameter_term = paste0(parameter, "_cum"),
        parameter_var = paste0(par_var, "^TRTDURGR"),
        parameter_labels = category_section_label,
        analysis_term = paste0(analysis, "_cum"),
        analysis_title = metalite::collect_adam_mapping(meta, analysis)$title,
        population_subset = !!rlang::enquo(pop_subset),
        observation_subset = NULL,
        population_label = metalite::collect_adam_mapping(meta, population)$label,
        treatment_group = metalite::collect_adam_mapping(meta, population)$group
      )
      if (nrow(metalite::collect_population_record(meta_cum, population)) > 0) {
        char_stat_cum <- collect_baseline(meta_cum, population, paste0(names(meta$parameter), "_cum"))[[2]]

        count <- char_stat_cum[1:(which(is.na(char_stat_cum$name)) - 1), ]
        count[names(char_n)[!names(char_n) %in% names(count)]] <- 0
        count <- count[, names(char_n)]

        sum <- char_stat_cum[(which(is.na(char_stat_cum$name)) + 1):nrow(char_stat_cum), ]
        sum[names(char_n)[!names(char_n) %in% names(sum)]] <- NA
        sum <- sum[, names(char_n)]

        count_cum <- rbind(count_cum, count)
        char_stat_cums[[label]] <- sum
      } else {
        count <- cbind("name" = label, "var_label" = category_section_label) |> data.frame()
        count[names(char_n)[!names(char_n) %in% names(count)]] <- 0
        count <- count[, names(char_n)]
        count_cum <- rbind(count_cum, count)
      }
    }
    char_prop_cum <- sapply(names(count_cum), function(x) {
      if (x %in% c(levels(group), "Total")) {
        i <- which(names(count_cum) == x)
        (as.numeric(count_cum[[i]]) / n_pop[[i]]) * 100
      } else {
        count_cum[[x]]
      }
    }) |> as.data.frame()

    outdata$char_n_cum <- count_cum |> list()
    outdata$char_prop_cum <- char_prop_cum |> list()
    outdata$char_stat_cums <- char_stat_cums
  }

  outdata$extend_call <- c(outdata$extend_call, match.call())

  return(outdata)
}

# Prepare data
meta <- meta_sl_exposure_test()

outdata <- meta |> prepare_exp_duration()


outdata_plot <- outdata |>
  extend_exp_duration(
    duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
    duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
  )

# Testing the plotly_exp_duration function - run multiple plots
test_that("Interactive plot is created successfully", {
  interactive_plot <- outdata_plot |>
    plotly_exp_duration(
      standard_histogram_label = "Histogram",
      stacked_histogram_label = "Stacked histogram",
      horizontal_histogram_label = "Horizontal histogram"
    )

  html <- gsub(
    "id=\"htmlwidget-[A-Za-z0-9]+\"",
    "id=\"htmlwidget-123456\"",
    as.character(interactive_plot)
  )

  html <- gsub(
    "for=\"htmlwidget-[A-Za-z0-9]+\"",
    "for=\"new_htmlwidget-123456\"",
    html
  )

  # Use gsub to replace 'id=\histogram_dropdown_' with something else, for example, 'dropdown'
  html <- gsub(
    "id=\"histogram_dropdown_[^\"]*\"",
    "id=\"dropdown-123456\"",
    html
  )

  # Use gsub to replace 'for=\histogram_dropdown_' with something else, for example, 'new_dropdown_'
  html <- gsub(
    "for=\"histogram_dropdown_[^\"]*\"",
    "for=\"new_dropdown_123456\"", # Replace with your desired value
    html
  )

  # Use gsub to replace 'id=\"histogram_type_' with something else, for example, 'type'
  html <- gsub(
    "id=\"histogram_type_[^\"]*\"",
    "id=\"type_123456\"", # Replace with your desired value
    html
  )

  # Use gsub to replace 'value=\"histogram_type_' with something else, for example, 'new_type'
  html <- gsub(
    "value=\"histogram_type_[^\"]*\"",
    "value=\"new_type_123456\"", # Replace with your desired value
    html
  )

  # Use gsub to replace the dynamic part after attrs":{\" with a fixed value
  html <- gsub(
    "attrs\":\\{\"[^\"]*\"",
    "attrs\":\"{attrs_value\"", # Replace with your desired new value
    html
  )

  # Use gsub to replace the dynamic part after cur_data\":\"10943968042c77\" with a fixed value, for example, 'new_cur_data'
  html <- gsub(
    "cur_data\":\"[^\"]*\"",
    "cur_data\":\"new_cur_data\"", # Replace with your desired new value
    html
  )

  # Use gsub to replace the dynamic part after "visdat\":{\"10d5f4785112cf\" with a fixed value, for example, 'new_visdat'
  html <- gsub(
    "visdat\":\\{\"[^\"]*\"",
    "visdat\":{\"new_visdat\"", # Replace with your desired new value
    html
  )

  expect_snapshot(html)
})

# Load  metadata example for exposure
meta <- meta_sl_exposure_test()

# Prepare the exposure duration data
outdata <- prepare_exp_duration(meta,
  analysis = "exp_dur",
  population = "apat",
  parameter = "expdur"
)


outdata_prod_pop <- outdata$meta$data_population
outdata_prod_obs <- outdata$meta$data_observation


# Test1
#### Test for Extended Exposure Duration_population ######
test_that("Extended exposure duration population data is as expected", {
  # Extend the exposure duration
  extended_data <- outdata |>
    extend_exp_duration(
      duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
      duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
    )

  # Define expected output data for comparison
  expected_extended_data_pop <- extended_data$meta$data_population

  # Use expect_equal to compare the two dataframes
  testthat::expect_equal(
    outdata_prod_pop,
    expected_extended_data_pop
  )
})

# Test2

#### Test for Extended Exposure Duration_observation ######
test_that("Extended exposure duration observation data is as expected", {
  # Extend the exposure duration
  extended_data <- outdata |>
    extend_exp_duration(
      duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
      duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
    )

  # Define  expected output data for comparison
  expected_extended_data_obs <- extended_data$meta$data_observation

  # Use expect_equal to compare the two dataframes
  testthat::expect_equal(
    outdata_prod_obs,
    expected_extended_data_obs
  )
})

# Test 3 N for cumulative category
test_that("Extended exposure duration char_n_cum ", {
  # Extend the exposure duration
  extended_data <- outdata |>
    extend_exp_duration(
      duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
      duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
    )

  # Input observation data and exposure cumulative category
  expected_extended_data_obs <- extended_data$meta$data_observation
  duration_category_list <- list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA))
  duration_category_labels <- c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
  template <- data.frame(name = duration_category_labels, var_label = "Exposure Duration (Days) (extend)", ord = seq_along(duration_category_labels))

  # Create data for cumulative category
  for (i in seq_along(duration_category_list)) {
    low <- ifelse(is.na(duration_category_list[[i]][1]), -Inf, duration_category_list[[i]][1])
    high <- ifelse(is.na(duration_category_list[[i]][2]), Inf, duration_category_list[[i]][2])

    adexsum0 <- expected_extended_data_obs[which(expected_extended_data_obs$AVAL >= low & expected_extended_data_obs$AVAL < high), ]
    if (nrow(adexsum0) > 0) {
      adexsum0$EXDURGR <- NA
      adexsum0$EXDURGR <- duration_category_labels[i]
      adexsum0$EXDURGRN <- i

      if (i == 1) {
        adexsum <- adexsum0
      } else if (i > 1) {
        adexsum <- rbind(adexsum, adexsum0)
      }
    }
  }
  adexsumtot <- adexsum
  adexsumtot$TRTA <- NA
  adexsumtot$TRTA <- "Total"
  adexsum <- rbind(adexsum, adexsumtot)

  # Calculate Freq N to test char_n_cum
  counts <- reshape(as.data.frame(table(adexsum$EXDURGR, adexsum$TRTA)), idvar = "Var1", timevar = "Var2", direction = "wide")
  # Rename column name
  names(counts) <- gsub("Freq.", "", names(counts))
  colnames(counts)[1] <- "name"

  # Post processing test output data
  test_char_n_cum <- merge(x = counts, y = template, by = "name", all.y = TRUE)
  test_char_n_cum[is.na(test_char_n_cum)] <- 0
  # Convert int to char
  for (j in seq(1, ncol(test_char_n_cum) - 1, 1)) {
    test_char_n_cum[, j] <- as.character(test_char_n_cum[, j])
  }
  # Sorting Order
  test_char_n_cum <- test_char_n_cum[order(test_char_n_cum$ord), ]
  test_extended_data_n_cum <- list(test_char_n_cum[, !(names(test_char_n_cum) %in% "ord")])

  # Define expected output data for comparison
  expected_extended_data_n_cum <- extended_data$char_n_cum

  # Test n
  expect_equal(
    test_extended_data_n_cum,
    expected_extended_data_n_cum,
    ignore_attr = TRUE
  )
})

# Test 4 Prop for cumulative category
test_that("Extended exposure duration char_prop_cum ", {
  # Extend the exposure duration
  extended_data <- outdata |>
    extend_exp_duration(
      duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
      duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
    )

  # Input observation data and exposure cumulative category
  expected_extended_data_obs <- extended_data$meta$data_observation
  duration_category_list <- list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA))
  duration_category_labels <- c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
  template <- data.frame(name = duration_category_labels, var_label = "Exposure Duration (Days) (extend)", ord = seq_along(duration_category_labels))

  # Create data for cumulative category
  for (i in seq_along(duration_category_list)) {
    low <- ifelse(is.na(duration_category_list[[i]][1]), -Inf, duration_category_list[[i]][1])
    high <- ifelse(is.na(duration_category_list[[i]][2]), Inf, duration_category_list[[i]][2])

    adexsum0 <- expected_extended_data_obs[which(expected_extended_data_obs$AVAL >= low & expected_extended_data_obs$AVAL < high), ]
    if (nrow(adexsum0) > 0) {
      adexsum0$EXDURGR <- NA
      adexsum0$EXDURGR <- duration_category_labels[i]
      adexsum0$EXDURGRN <- i

      if (i == 1) {
        adexsum <- adexsum0
      } else if (i > 1) {
        adexsum <- rbind(adexsum, adexsum0)
      }
    }
  }
  adexsumtot <- adexsum
  adexsumtot$TRTA <- NA
  adexsumtot$TRTA <- "Total"
  adexsum <- rbind(adexsum, adexsumtot)

  # Calculate Freq N to test char_n_cum
  counts <- reshape(as.data.frame(table(adexsum$EXDURGR, adexsum$TRTA)), idvar = "Var1", timevar = "Var2", direction = "wide")
  # Rename column name
  names(counts) <- gsub("Freq.", "", names(counts))
  colnames(counts)[1] <- "name"

  # Bign
  bign <- extended_data$n
  counts[, 2] <- as.character(round(counts[, 2] * 100 / bign$n_1, digits = 5))
  counts[, 3] <- as.character(round(counts[, 3] * 100 / bign$n_2, digits = 5))
  counts[, 4] <- as.character(round(counts[, 4] * 100 / bign$n_3, digits = 5))
  counts$Total <- as.character(round(counts$Total * 100 / bign$n_9999, digits = 5))

  # Post processing test output data
  test_char_prop_cum <- merge(x = counts, y = template, by = "name", all.y = TRUE)
  test_char_prop_cum[is.na(test_char_prop_cum)] <- 0
  # Convert int to char
  for (j in seq(1, ncol(test_char_prop_cum) - 1, 1)) {
    test_char_prop_cum[, j] <- as.character(test_char_prop_cum[, j])
  }
  # Sorting Order
  test_char_prop_cum <- test_char_prop_cum[order(test_char_prop_cum$ord), ]
  test_extended_data_prop_cum <- list(test_char_prop_cum[, !(names(test_char_prop_cum) %in% "ord")])

  # Define expected output data for comparison
  expected_extended_data_prop_cum0 <- extended_data$char_prop_cum[[1]]
  cols_to_convert <- c(as.character(levels(extended_data$group_label)), "Total")
  expected_extended_data_prop_cum0[cols_to_convert] <- lapply(expected_extended_data_prop_cum0[cols_to_convert], as.numeric)
  expected_extended_data_prop_cum0[cols_to_convert] <- round(expected_extended_data_prop_cum0[cols_to_convert], digits = 5)
  expected_extended_data_prop_cum0[cols_to_convert] <- lapply(expected_extended_data_prop_cum0[cols_to_convert], as.character)
  expected_extended_data_prop_cum <- list(expected_extended_data_prop_cum0)

  # Test prop
  expect_equal(
    test_extended_data_prop_cum,
    expected_extended_data_prop_cum,
    ignore_attr = TRUE
  )
})

# Test 5 Stat for cumulative category
test_that("Extended exposure duration char_stat_cum ", {
  # Extend the exposure duration
  extended_data <- outdata |>
    extend_exp_duration(
      duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
      duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
    )

  # Input observation data and exposure cumulative category
  expected_extended_data_obs <- extended_data$meta$data_observation
  duration_category_list <- list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA))
  duration_category_labels <- c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")

  # Create data for cumulative category
  for (i in seq_along(duration_category_list)) {
    low <- ifelse(is.na(duration_category_list[[i]][1]), -Inf, duration_category_list[[i]][1])
    high <- ifelse(is.na(duration_category_list[[i]][2]), Inf, duration_category_list[[i]][2])

    adexsum0 <- expected_extended_data_obs[which(expected_extended_data_obs$AVAL >= low & expected_extended_data_obs$AVAL < high), ]
    if (nrow(adexsum0) > 0) {
      adexsum0$EXDURGR <- NA
      adexsum0$EXDURGR <- duration_category_labels[i]
      adexsum0$EXDURGRN <- i

      if (i == 1) {
        adexsum <- adexsum0
      } else if (i > 1) {
        adexsum <- rbind(adexsum, adexsum0)
      }
    }
  }

  adexsumtot <- adexsum
  adexsumtot$TRTA <- NA
  adexsumtot$TRTA <- "Total"
  adexsum <- rbind(adexsum, adexsumtot)

  test_extended_data_stat_cum <- list()
  for (j in seq_along(unique(adexsum$EXDURGR))) {
    sub <- adexsum[which(adexsum$EXDURGR == unique(adexsum$EXDURGR)[j]), ]
    stat <- tapply(sub$AVAL, sub$TRTA, function(x) {
      value <- c(
        Mean = mean(x, na.rm = TRUE),
        SD = stats::sd(x, na.rm = TRUE),
        SE = stats::sd(x, na.rm = TRUE) / sqrt(sum(!is.na(x))),
        Median = stats::median(x, na.rm = TRUE),
        Min = min(x, na.rm = TRUE),
        Max = max(x, na.rm = TRUE)
      )
      value <- formatC(value, format = "f", digits = 1)

      value <- c(value,
        `Q1 to Q3` = paste0(
          stats::quantile(x, probs = 0.25, na.rm = TRUE, names = FALSE), " to ",
          stats::quantile(x, probs = 0.75, na.rm = TRUE, names = FALSE)
        ),
        Range = paste0(min(x, na.rm = TRUE), " to ", max(x, na.rm = TRUE))
      )

      value
    })
    stat <- t(do.call(rbind, stat))
    stat <- data.frame(
      name = row.names(stat),
      stat
    )
    # combine results
    names(stat) <- names(stat)
    row.names(stat) <- NULL
    stat$var_label <- "Exposure Duration (Days) (extend)"
    names(stat) <- sub("\\.", " ", names(stat))

    # missing TRTA
    col <- setdiff(extended_data$group_label, sub$TRTA)
    for (k in seq_along(col)) {
      trt <- as.character(col[k])
      stat[[trt]] <- NA
    }

    reference <- c("name", as.character(levels(extended_data$group_label)), "Total", "var_label")
    stat_sorted <- stat[, match(reference, names(stat))]
    test_extended_data_stat_cum[[j]] <- stat_sorted
  }
  names(test_extended_data_stat_cum) <- unique(adexsum$EXDURGR)

  # Define expected output data for comparison
  expected_extended_data_stat_cum <- extended_data$char_stat_cums

  # Test stat
  expect_equal(
    test_extended_data_stat_cum,
    expected_extended_data_stat_cum,
    ignore_attr = TRUE
  )
})

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Count number of subjects
#'
#' @param meta A metadata object created by metalite.
#' @param population A character value of population term name.
#'   The term name is used as key to link information.
#' @param parameter A character value of parameter term name.
#'   The term name is used as key to link information.
#' @param type A character value to control title name,
#'   e.g., Subjects or Records.
#' @param use_na A character value for whether to include `NA` values
#' in the table. See the `useNA` argument in [base::table()] for more details.
#' @param display_total A logical value to display total column.
#' @return A list containing number of subjects
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "age"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat",
#'     group = "TRTA",
#'     subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age",
#'     var = "AGE",
#'     label = "Age (years)",
#'     vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |> collect_baseline(
#'   population = "apat",
#'   parameter = "age"
#' )
collect_baseline <- function(
  meta,
  population,
  parameter,
  type = "Subjects",
  use_na = c("ifany", "no", "always"),
  display_total = TRUE
) {
  use_na <- match.arg(use_na)

  title <- c(
    all = glue::glue("Number of {type}"),
    with_data = glue::glue("{type} with Data"),
    missing = "Missing"
  )

  if (display_total) {
    meta <- metalite::meta_add_total(meta)
  }

  # Obtain variables
  par_var <- metalite::collect_adam_mapping(meta, parameter)$var
  par_var_group <- metalite::collect_adam_mapping(meta, parameter)$vargroup
  par_var_lower <- metalite::collect_adam_mapping(meta, parameter)$var_lower

  # Obtain Data
  pop <- metalite::collect_population_record(meta, population, var = c(par_var, par_var_group, par_var_lower))

  # Obtain ID
  pop_id <- metalite::collect_adam_mapping(meta, population)$id

  # Obtain Group
  pop_group <- metalite::collect_adam_mapping(meta, population)$group

  # Define analysis dataset
  uid <- pop[[pop_id]]
  id <- seq(uid)
  group <- pop[[pop_group]]
  var <- pop[[par_var]]

  class_var <- class(var)

  # Check ID duplication
  if (any(duplicated(uid[!group %in% "Total"]))) {
    warning(pop_id, " is not a unique ID")
  }

  # Obtain variable label
  label <- metalite::collect_adam_mapping(meta, parameter)$label
  if (is.null(label)) {
    label <- metalite::collect_adam_mapping(meta, parameter)$var
  }

  # standardize group variable
  stopifnot(inherits(group, c("factor", "character")))
  group <- factor(group, exclude = NULL)
  levels(group)[is.na(levels(group))] <- "Missing"

  # standardize continuous variables
  stopifnot(inherits(var, c("numeric", "integer", "factor", "character", "logical")))

  # summary of population
  all <- rep(title["all"], length(var))
  pop_all <- metalite::n_subject(id, group, par = all)

  var_n <- factor(is.na(var), c(FALSE, TRUE), title[c("with_data", "missing")])

  # Obtain Number of Subjects
  pop_n <- metalite::n_subject(id, group, par = var_n)

  # Transfer logical value
  if ("logical" %in% class_var) {
    class_var <- "character"
    var <- factor(var, c(TRUE, FALSE), c("Yes", "No"))
  }

  if (any(c("numeric", "integer") %in% class_var)) {
    # calculate summary statistics
    pop_num <- tapply(var, group, function(x) {
      value <- c(
        Mean = mean(x, na.rm = TRUE),
        SD = stats::sd(x, na.rm = TRUE),
        SE = stats::sd(x, na.rm = TRUE) / sqrt(sum(!is.na(x))),
        Median = stats::median(x, na.rm = TRUE),
        Min = min(x, na.rm = TRUE),
        Max = max(x, na.rm = TRUE)
      )
      value <- formatC(value, format = "f", digits = 1)

      value <- c(value,
        `Q1 to Q3` = paste0(
          stats::quantile(x, probs = 0.25, na.rm = TRUE, names = FALSE), " to ",
          stats::quantile(x, probs = 0.75, na.rm = TRUE, names = FALSE)
        ),
        Range = paste0(min(x, na.rm = TRUE), " to ", max(x, na.rm = TRUE))
      )

      value
    })
    pop_num <- t(do.call(rbind, pop_num))
    pop_num <- data.frame(
      name = row.names(pop_num),
      pop_num
    )
    # combine results
    names(pop_num) <- names(pop_n)
    row.names(pop_num) <- NULL
    # add percentage
    pop_prop <- pop_num
    for (i in 2:ncol(pop_prop)) {
      pop_prop[, i] <- NA
    }
  }

  # standardize categorical variables
  if (any(c("factor", "character") %in% class_var)) {
    if (any(c("character") %in% class_var)) {
      var <- factor(var, exclude = NULL)
    }

    if (all(is.na(var))) {
      levels(var) <- c(levels(var), title["missing"])
    } else {
      levels(var)[is.na(levels(var))] <- title["missing"]
    }

    # Obtain Number of Subjects
    pop_num <- metalite::n_subject(id, group, par = var)

    pop_prop <- pop_num
    for (i in seq(names(pop_prop))) {
      if ("integer" %in% class(pop_prop[[i]])) {
        pct <- pop_prop[[i]] / pop_all[[i]] * 100
        pop_prop[[i]] <- pct
      }
    }
  }

  # variable group
  if (!is.null(par_var_group)) {
    vargroup <- pop[[par_var_group]]
    stopifnot(inherits(vargroup, c("factor", "character")))
    if (any(c("character") %in% class_var)) {
      vargroup <- factor(vargroup, exclude = NULL)
    }

    if (all(is.na(vargroup))) {
      levels(vargroup) <- c(levels(vargroup), title["missing"])
    } else {
      levels(vargroup)[is.na(levels(vargroup))] <- title["missing"]
    }

    # Obtain Number of Subjects
    pop_num_group <- metalite::n_subject(id, group, par = vargroup)

    pop_prop_group <- pop_num_group
    for (i in seq(names(pop_prop_group))) {
      if ("integer" %in% class(pop_prop_group[[i]])) {
        pct <- pop_prop_group[[i]] / pop_all[[i]] * 100
        pop_prop_group[[i]] <- pct
      }
    }

    pop_num <- rbind(pop_num_group, rep(NA, ncol(pop_num)), pop_num)
    pop_prop <- rbind(pop_prop_group, rep(NA, ncol(pop_num)), pop_prop)
  }

  # variable lower level
  if (!is.null(par_var_lower)) {
    # Obtain number of subjects
    pop_num_lower <- apply(pop_num, 1, function(x) {
      pop_lower <- pop[pop[[par_var]] == x[["name"]] & !is.na(pop[[par_var_lower]]), ]
      id_lower <- seq(pop_lower[[pop_id]])
      group_lower <- pop_lower[[pop_group]]
      varlower <- pop_lower[[par_var_lower]]
      stopifnot(inherits(varlower, c("factor", "character")))
      if (any(c("character") %in% class_var)) {
        varlower <- factor(varlower, exclude = NULL)
      }

      if (length(varlower) > 0) {
        lower <- metalite::n_subject(id_lower, group_lower, par = varlower)
        max_length <- sapply(pop_num, function(x) max(nchar(x)))
        for (i in 2:length(max_length)) {
          lower[[i]] <- formatC(lower[[i]], width = max_length[[i]])
        }

        lower$name <- paste("   ", lower$name)
        rbind(x, lower)
      } else {
        as.data.frame(t(x))
      }
    })
    pop_num <- do.call(rbind, pop_num_lower)

    # Obtain proportion
    pop_prop_lower <- apply(pop_prop, 1, function(x) {
      pop_lower <- pop[pop[[par_var]] == x[["name"]] & !is.na(pop[[par_var_lower]]), ]
      id_lower <- seq(pop_lower[[pop_id]])
      group_lower <- pop_lower[[pop_group]]
      varlower <- pop_lower[[par_var_lower]]
      stopifnot(inherits(varlower, c("factor", "character")))
      varlower <- factor(varlower, exclude = NULL)

      if (length(varlower) > 0) {
        lower <- metalite::n_subject(id_lower, group_lower, par = varlower)
        for (i in seq(names(lower))) {
          if ("integer" %in% class(lower[[i]])) {
            pct <- lower[[i]] / pop_all[[i]] * 100
            lower[[i]] <- pct
          }
        }
        lower$name <- paste("   ", lower$name)
        rbind(x, lower)
      } else {
        as.data.frame(t(x))
      }
    })
    pop_prop <- do.call(rbind, pop_prop_lower)
  }

  pop_n["var_label"] <- label
  pop_num["var_label"] <- label
  pop_prop["var_label"] <- label

  list(n = pop_n, stat = pop_num, pop = pop_prop, var_type = class_var)
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' A subject level demographic dataset
#'
#' A dataset containing the demographic information of a clinical trial
#' following the CDISC ADaM standard.
#'
#' Definition of each variable can be found at
#' <https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc>.
#'
#' @format A data frame with 254 rows and 54 variables.
#'
#' @source <https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc>
"metalite_sl_adsl"

#' An adverse event dataset
#'
#' A dataset containing the adverse event information of a clinical trial
#' following the CDISC ADaM standard.
#'
#' Definition of each variable can be found at
#' <https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc>.
#'
#' @format A data frame with 1191 rows and 60 variables.
#'
#' @source <https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc>
"metalite_sl_adae"

#' ADEXSUM dataset
#'
#' A dataset containing exposure details in Basic Data Structure (BDS).
#'
#' @format A data frame with 508 rows and 50 variables.
#'
#' @return An analysis data frame.
#'
#' @source \url{https://github.com/phuse-org/phuse-scripts/tree/master/data/sdtm/cdiscpilot01}
"metalite_sl_adexsum"

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Prepare data for baseline characteristic table
#'
#' @param outdata A metadata object created by [prepare_sl_summary()].
#' @param display_col Column wants to display on the table.
#'   The term could be selected from `c("n", "prop", "total")`.
#' @param digits_prop Number of digits for proportion columns.
#' @param display_stat A vector of statistics term name.
#'   The term name could be selected from
#'   `c("mean", "sd", "se", "median", "q1 to q3", "range", "q1", "q3", "min", "max")`.
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char", population = "apat",
#'     observation = "apat", parameter = "age;gender"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_sl_summary(population = "apat", analysis = "base_char", parameter = "age;gender") |>
#'   format_sl_summary()
format_sl_summary <- function(
  outdata,
  display_col = c("n", "prop", "total"),
  digits_prop = 1,
  display_stat = c("mean", "sd", "se", "median", "q1 to q3", "range")
) {
  n_group <- length(outdata$group_label)


  # Check if the "tbl" element exists in the "outdata" object
  if ("tbl" %in% names(outdata)) {
    # If the element exists, delete it
    outdata$tbl <- NULL
  }

  # Select statistics want to display
  for (i in 1:length(outdata$var_type)) {
    if (("integer" %in% outdata$var_type[[i]]) || ("numeric" %in% outdata$var_type[[i]])) {
      n_num <- outdata$char_n[[i]]
      n_num_group <- n_num[which(!tolower(n_num$name)
      %in% c(
          "mean", "sd", "se", "median", "q1 to q3",
          "range", "q1", "q3", "min", "max"
        )), ]
      n_num_stat <- n_num[which(tolower(n_num$name) %in% display_stat), ]
      n_num <- rbind(n_num_group, n_num_stat)
      outdata$char_n[[i]] <- n_num
      outdata$char_prop[[i]] <- outdata$char_prop[[i]][which(outdata$char_prop[[i]]$name %in% n_num$name), ]
    }
  }

  # Create output
  tbl <- list()

  if ("n" %in% display_col) {
    n <- do.call(rbind, outdata$char_n)
    if ("total" %in% display_col) {
      names(n) <- c("name", paste0("n_", seq(1, n_group)), "n_9999", "var_label")
    } else {
      n <- n[, -(2 + n_group)]
      names(n) <- c("name", paste0("n_", seq(1, n_group)), "var_label")
    }

    tbl[["n"]] <- n
  }

  tbl$n <- rbind(outdata$n[, names(outdata$n) %in% names(tbl$n)], tbl$n)

  if ("prop" %in% display_col) {
    prop <- do.call(rbind, outdata$char_prop)
    name <- prop$name
    label <- prop$var_label
    value <- data.frame(apply(prop[2:(ncol(prop) - 1)], 2, function(x) as.numeric(as.character(x))))
    prop <- apply(value, 2, metalite.ae::fmt_pct, digits = digits_prop, pre = "(", post = ")") |> as.data.frame()
    prop <- data.frame(name = name, prop, var_label = label)
    if ("total" %in% display_col) {
      names(prop) <- c("name", paste0("p_", seq(1, n_group)), "p_9999", "var_label")
    } else {
      prop <- prop[, -(2 + n_group)]
      names(prop) <- c("name", paste0("p_", seq(1, n_group)), "var_label")
    }
    tbl[["prop"]] <- prop
  }
  tbl$prop <- rbind(c(tbl$n[1, 1], rep(NA, ifelse("total" %in% display_col, n_group + 1, n_group)), tbl$n[1, ncol(tbl$n)]), tbl$prop)

  # Arrange Within Group information
  within_var <- names(tbl)[names(tbl) %in% c("n", "prop")]
  within_tbl <- tbl[within_var]

  names(within_tbl) <- NULL
  n_within <- length(within_tbl)
  n_row <- ncol(tbl[["n"]])
  within_tbl <- do.call(cbind, within_tbl)

  within_tbl <- within_tbl[, !duplicated(names(within_tbl))]
  within_tbl <- within_tbl[, c(
    1, do.call(c, lapply(
      2:(1 + n_group + ifelse("total" %in% display_col, 1, 0)),
      function(x) {
        c(x, x + n_group + ifelse("total" %in% display_col, 1, 0) + 1)
      }
    )),
    (1 + n_group + ifelse("total" %in% display_col, 1, 0) + 1)
  )]

  rownames(within_tbl) <- NULL
  outdata$tbl <- within_tbl
  outdata$display_col <- display_col
  outdata$display_stat <- display_stat

  return(outdata)
}

#' Format Baseline Characteristics Analysis
#'
#' @inheritParams format_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char", population = "apat",
#'     observation = "apat", parameter = "age;gender"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'   metalite::define_analysis(
#'     name = "base_char",
#'     title = "Participant Baseline Characteristics by Treatment Group"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_base_char(population = "apat", parameter = "age;gender") |>
#'   format_base_char()
format_base_char <- format_sl_summary

#' Format Treatment Compliance Analysis
#'
#' @inheritParams format_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "trt_compliance", population = "apat",
#'     observation = "apat", parameter = "comp8;comp16"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "comp8", var = "COMP8FL", label = "Compliance (Week 8)"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "comp16", var = "COMP16FL", label = "Compliance (Week 16)"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "trt_compliance", title = "Summary of Treatment Compliance"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_trt_compliance(parameter = "comp8;comp16") |>
#'   format_trt_compliance()
format_trt_compliance <- format_sl_summary

#' Format Treatment Compliance Analysis
#'
#' @inheritParams format_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "trt_compliance", population = "apat",
#'     observation = "apat", parameter = "comp8;comp16"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "comp8", var = "COMP8FL", label = "Compliance (Week 8)"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "comp16", var = "COMP16FL", label = "Compliance (Week 16)"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "trt_compliance", title = "Summary of Treatment Compliance"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_trt_compliance(population = "apat", parameter = "comp8;comp16") |>
#'   format_trt_compliance()
format_trt_compliance <- format_sl_summary


#' Format Disposition Analysis
#'
#' @inheritParams format_sl_summary
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "disp", population = "apat",
#'     observation = "apat", parameter = "disposition;medical-disposition"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "disposition", var = "EOSSTT", label = "Trial Disposition",
#'     var_lower = "DCSREAS"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "medical-disposition", var = "EOTSTT",
#'     label = "Participant Study Medication Disposition", var_lower = "DCTREAS"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "disp", title = "Disposition of Participant"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_disposition(population = "apat", parameter = "disposition;medical-disposition") |>
#'   format_disposition()
format_disposition <- format_sl_summary

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Prepare data for treatment compliance table
#'
#' @param meta A metadata object created by metalite.
#' @param population A character value of population term name.
#'   The term name is used as key to link information.
#' @param analysis  A character value of analysis term name.
#'   The term name is used as key to link information.
#' @param parameter A character value of parameter term name.
#'   The term name is used as key to link information.
#' @param subgroup_var A character value of subgroup variable name in
#'   observation data saved in `meta$data_observation`.
#' @param subgroup_header A character vector for column header hierarchy.
#'   The first element will be the first level header and the second element
#'   will be second level header.
#'
#' @return A list of analysis raw datasets.
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adsl,
#'   observation = metalite_sl_adsl
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "base_char_subgroup",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "age"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat",
#'     group = "TRTA",
#'     subset = SAFFL == "Y"
#'   ) |>
#'   metalite::define_parameter(
#'     name = "age",
#'     var = "AGE",
#'     label = "Age (years)",
#'     vargroup = "AGEGR1"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "base_char_subgroup",
#'     title = "Participant by Age Category and Sex"
#'   ) |>
#'   metalite::meta_build()
#'
#' outdata <- prepare_base_char_subgroup(
#'   meta,
#'   population = "apat",
#'   parameter = "age",
#'   subgroup_var = "TRTA",
#'   subgroup_header = c("SEX", "TRTA")
#' )
prepare_base_char_subgroup <- function(
  meta,
  population,
  analysis = "base_char_subgroup",
  parameter,
  subgroup_var,
  subgroup_header = c(meta$population[[population]]$group, subgroup_var)
) {
  meta_original <- meta

  observation <- meta$plan[meta$plan$analysis == analysis, ]$observation

  # Factor Level 1 Subgroup
  meta$data_population[[subgroup_header[1]]] <- factor(
    as.character(meta$data_population[[subgroup_header[1]]]),
    levels = sort(unique(meta$data_population[[subgroup_header[1]]]))
  )
  meta$data_observation[[subgroup_header[1]]] <- factor(
    as.character(meta$data_observation[[subgroup_header[1]]]),
    levels = sort(unique(meta$data_observation[[subgroup_header[1]]]))
  )

  # Factor Level 2 Subgroup
  meta$data_population[[subgroup_header[2]]] <- factor(
    as.character(meta$data_population[[subgroup_header[2]]]),
    levels = sort(unique(meta$data_population[[subgroup_header[2]]]))
  )
  meta$data_observation[[subgroup_header[2]]] <- factor(
    as.character(meta$data_observation[[subgroup_header[2]]]),
    levels = sort(unique(meta$data_observation[[subgroup_header[2]]]))
  )

  meta$observation[[observation]]$group <- subgroup_header[1]
  meta$population[[population]]$group <- subgroup_header[1]

  # Obtain variables
  par_var <- metalite::collect_adam_mapping(meta, parameter)$var

  meta_subgroup <- metalite::meta_split(meta, subgroup_header[2])

  outdata_all <- prepare_sl_summary(
    meta,
    analysis = analysis,
    population = meta$plan[meta$plan$analysis == analysis, ]$population,
    parameter = parameter
  )

  outdata_subgroup <- lapply(
    meta_subgroup,
    prepare_sl_summary,
    analysis = analysis,
    population = meta$plan[meta$plan$analysis == analysis, ]$population,
    parameter = parameter
  )

  out_all <- outdata_subgroup
  out_all$Total <- outdata_all

  group <- levels(outdata_subgroup[[1]]$group_label)
  group <- group[!group %in% "Total"]

  outdata <- list(
    group = group,
    subgroup = tools::toTitleCase(tolower(names(outdata_subgroup))),
    meta = meta_original,
    population = population,
    observation = observation,
    parameter = parameter,
    out_all = out_all
  )
}

library(dplyr)
library(tidyr)

meta <- meta_sl_test()
data_population <- meta$data_population
data_population$SEX <- factor(
  data_population$SEX,
  levels = c("F", "M"),
  labels = c("Female", "Male")
)
data_population$AGEGR1 <- factor(
  data_population$AGEGR1,
  levels = c("<65", "65-80", ">80"),
  labels = c("<65", "65-80", ">80")
)
meta$data_population <- data_population

outdata <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "age",
  subgroup_var = "SEX",
  subgroup_header = c("SEX", "TRTA")
)

# Testing
test_that("Group matching", {
  expect_equal(
    outdata$group,
    c("Female", "Male")
  )
})

test_that("Subgroup matching", {
  expect_equal(
    outdata$subgroup,
    c("Placebo", "Low Dose", "High Dose")
  )
})

test_that("Participants in population", {
  adsl_tot <- data_population |>
    dplyr::mutate(
      TRTA = "Total"
    )
  adsl_tot <- rbind(data_population, adsl_tot)
  adsl_tot$SEX <- as.numeric(adsl_tot$SEX)

  res_tot <- adsl_tot |>
    dplyr::summarise(
      n = n_distinct(USUBJID),
      .by = c(TRTA, SAFFL, SEX)
    )

  res <-
    res_tot |>
    dplyr::mutate(
      x = paste0("n_", SEX)
    )

  pop_cnt <- res |>
    dplyr::filter(SAFFL == "Y") |>
    tidyr::pivot_wider(
      id_cols = "TRTA",
      names_from = "x",
      values_from = n,
      values_fill = list(n = 0)
    )
  pop_cnt$n_9999 <-
    apply(pop_cnt[, grepl("n_", colnames(pop_cnt))], 1, sum)
  pop_cnt <- pop_cnt[order(pop_cnt$TRTA), ]

  for (i in length(outdata$out_all)) {
    expect_equal(
      outdata$out_all[[i]]$n |> select(starts_with("n_")) |> tibble(),
      tibble(pop_cnt[i, ]) |> select(-c(TRTA))
    )
    expect_equal(outdata$out_all[[i]]$n[["name"]], "Participants in population")
    expect_equal(outdata$out_all[[i]]$n[["var_label"]], "-----")
  }
})

test_that("Character variables count", {
  adsl_tot <- data_population |>
    dplyr::mutate(
      TRTA = "Total"
    )
  adsl_tot <- rbind(data_population, adsl_tot)
  adsl_tot_sex <- adsl_tot |>
    dplyr::mutate(
      SEX = "Total"
    )
  adsl_tot <- rbind(adsl_tot, adsl_tot_sex)

  res_tot <- adsl_tot |>
    dplyr::summarise(
      n = n_distinct(USUBJID),
      .by = c(TRTA, SAFFL, SEX)
    )

  res_frq <-
    adsl_tot |>
    dplyr::summarise(
      n = n_distinct(USUBJID),
      .by = c(TRTA, SAFFL, SEX, AGEGR1)
    ) |>
    dplyr::arrange(TRTA, AGEGR1) |>
    dplyr::rename(name = AGEGR1) |>
    dplyr::full_join(
      res_tot |> rename(z = n),
      by = c("SAFFL", "TRTA", "SEX"),
      multiple = "all"
    ) |>
    data.frame() |>
    dplyr::mutate(
      pct = 100 * n / z,
    )

  res_frq_n <- res_frq |>
    dplyr::filter(SAFFL == "Y") |>
    tidyr::pivot_wider(
      id_cols = c("TRTA", "name"),
      names_from = "SEX",
      values_from = n,
      values_fill = c(n = 0)
    ) |>
    dplyr::arrange(TRTA, name) |>
    dplyr::mutate(
      var_label = "Age (years)"
    )

  res_frq_prop <- res_frq |>
    dplyr::filter(SAFFL == "Y") |>
    tidyr::pivot_wider(
      id_cols = c("TRTA", "name"),
      names_from = "SEX",
      values_from = pct,
      values_fill = c(pct = 0)
    ) |>
    dplyr::arrange(TRTA, name) |>
    dplyr::mutate(
      var_label = "Age (years)"
    )

  res_frq_n$name <- as.character(res_frq_n$name)
  res_frq_prop$name <- as.character(res_frq_prop$name)

  res_frq_n[!names(res_frq_n) %in% c("TRTA", "name", "var_label")] <-
    apply(res_frq_n[!names(res_frq_n) %in% c("TRTA", "name", "var_label")], 2, function(x) {
      gsub(" ", "", as.character(x))
    }) |>
    data.frame()
  res_frq_prop <- res_frq_prop |> data.frame()

  for (i in length(outdata$out_all)) {
    out <- outdata$out_all[[i]]
    res_n <- split(res_frq_n, factor(res_frq_n$TRTA, levels = unique(res_frq_n$TRTA)))[[i]] |>
      data.frame() |>
      select(-c(TRTA))
    rownames(res_n) <- NULL
    res_prop <- split(res_frq_prop, factor(res_frq_prop$TRTA, levels = unique(res_frq_prop$TRTA)))[[i]] |>
      data.frame() |>
      select(-c(TRTA))
    rownames(res_prop) <- NULL
    # Test n
    expect_equal(
      out$char_n[[1]][!out$char_n[[1]]$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range", NA), ],
      res_n
    )
    # Test proportion
    expect_equal(
      out$char_prop[[1]][!out$char_prop[[1]]$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range", NA), ],
      res_prop
    )
  }
})

test_that("Numeric variables summary", {
  adsl_tot <- data_population |>
    dplyr::mutate(
      TRTA = "Total"
    )
  adsl_tot <- rbind(data_population, adsl_tot)
  adsl_tot_sex <- adsl_tot |>
    dplyr::mutate(
      SEX = "Total"
    )
  adsl_tot <- rbind(adsl_tot, adsl_tot_sex)

  res_stat <-
    adsl_tot |>
    dplyr::summarise(
      n = n_distinct(USUBJID, na.rm = TRUE),
      Mean = mean(AGE, na.rm = TRUE),
      SD = sd(AGE, na.rm = TRUE),
      SE = SD / sqrt(n),
      Median = median(AGE, na.rm = TRUE),
      Min = min(AGE, na.rm = TRUE),
      Max = max(AGE, na.rm = TRUE),
      Q1 = quantile(AGE, probs = 0.25, na.rm = TRUE),
      Q3 = quantile(AGE, probs = 0.75, na.rm = TRUE),
      .by = c(TRTA, SAFFL, SEX)
    ) |>
    dplyr::mutate(
      Q1_to_Q3 = paste0(Q1, " to ", Q3),
      Range = paste0(Min, " to ", Max)
    ) |>
    dplyr::arrange(TRTA, SEX)

  res_stat[c("n", "Mean", "SD", "SE", "Median", "Min", "Max")] <-
    lapply(
      res_stat[c("n", "Mean", "SD", "SE", "Median", "Min", "Max")],
      function(x) {
        formatC(x, format = "f", digits = 1)
      }
    )

  res_stat_n <- res_stat |>
    dplyr::filter(SAFFL == "Y") |>
    dplyr::select(-Q1, -Q3) |>
    dplyr::select(-c(SAFFL, n)) |>
    tidyr::pivot_longer(
      cols = -c("TRTA", "SEX"),
      names_to = "name",
      values_to = "stat"
    ) |>
    tidyr::pivot_wider(
      id_cols = c("TRTA", "name"),
      names_from = "SEX",
      values_from = stat,
      values_fill = c(stat = "0")
    ) |>
    dplyr::mutate(name = gsub("_", " ", name)) |>
    dplyr::mutate(var_label = "Age (years)") |>
    data.frame()

  res_stat_n$name <- factor(
    res_stat_n$name,
    levels = c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range")
  )
  res_stat_n$name <- as.character(res_stat_n$name)


  for (i in length(outdata$out_all)) {
    out <- outdata$out_all[[i]]
    res_n <- split(res_stat_n, factor(res_stat_n$TRTA, levels = unique(res_stat_n$TRTA)))[[i]] |>
      select(-c(TRTA)) |>
      tibble()
    rownames(res_n) <- NULL
    res_stat_prop <- res_n
    res_stat_prop[!names(res_stat_prop) %in% c("name", "var_label")] <- as.double(NA)
    # Test n
    expect_equal(
      out$char_n[[1]][out$char_n[[1]]$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range"), ] |> tibble(),
      res_n
    )
    # Test proportion
    expect_equal(
      out$char_prop[[1]][out$char_prop[[1]]$name %in% c("Mean", "SD", "SE", "Median", "Min", "Max", "Q1 to Q3", "Range"), ] |> tibble(),
      res_stat_prop
    )
  }
})

test_that("Population matching", {
  expect_equal(outdata$population, "apat")
})

test_that("Observation matching", {
  expect_equal(outdata$observation, "apat")
})

test_that("Parameter matching", {
  expect_equal(outdata$parameter, "age")
})

test_that("Output from prepare_base_char_subgroup is a list", {
  expect_true("list" %in% class(outdata))
})

#' Format Exposure Duration Analysis
#'
#' @inheritParams format_sl_summary
#' @param display_col Column wants to display on the table.
#'   "n_cum", "prop_cum" can additionally be selected.
#'   - `n_cum`: Number of subjects created by `extend_exp_duration()`.
#'   - `prop_cum`: Proportion of subjects created by `extend_exp_duration()`.
#'
#' @return A list of analysis raw datasets.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adexsum,
#'   observation = metalite_sl_adexsum
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "exp_dur", population = "apat",
#'     observation = "apat", parameter = "expdur"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
#'   ) |>
#'   metalite::define_parameter(
#'     name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
#'     label = "Exposure Duration (Days)", vargroup = "EXDURGR"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "exp_dur", title = "Summary of Exposure Duration",
#'     label = "exposure duration table"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_exp_duration(population = "apat", parameter = "expdur") |>
#'   format_exp_duration(display_col = c("n", "prop", "total"))
format_exp_duration <- function(
  outdata,
  display_col = c("n", "prop", "n_cum", "prop_cum", "total"),
  digits_prop = 1,
  display_stat = c("mean", "sd", "se", "median", "q1 to q3", "range")
) {
  n_group <- length(outdata$group_label)

  display_col <- match.arg(
    display_col,
    c("n", "prop", "total", "n_cum", "prop_cum"),
    several.ok = TRUE
  )

  # Check if the "tbl" element exists in the "outdata" object
  if ("tbl" %in% names(outdata)) {
    # If the element exists, delete it
    outdata$tbl <- NULL
  }

  # Select statistics want to display
  for (i in 1:length(outdata$var_type)) {
    if (("integer" %in% outdata$var_type[[i]]) || ("numeric" %in% outdata$var_type[[i]])) {
      n_num <- outdata$char_n[[i]]
      n_num_group <- n_num[which(!tolower(n_num$name)
      %in% c(
          "mean", "sd", "se", "median", "q1 to q3",
          "range", "q1", "q3", "min", "max"
        )), ]
      n_num_stat <- n_num[which(tolower(n_num$name) %in% display_stat), ]
      n_num <- rbind(n_num_group, n_num_stat)
      outdata$char_n[[i]] <- n_num
      outdata$char_prop[[i]] <- outdata$char_prop[[i]][which(outdata$char_prop[[i]]$name %in% n_num$name), ]
    }
  }

  # Create output
  tbl <- list()

  if ("n" %in% display_col) {
    n <- do.call(rbind, outdata$char_n)
    if ("total" %in% display_col) {
      names(n) <- c("name", paste0("n_", seq(1, n_group)), "n_9999", "var_label")
    } else {
      n <- n[, -(2 + n_group)]
      names(n) <- c("name", paste0("n_", seq(1, n_group)), "var_label")
    }

    tbl[["n"]] <- n
  }

  if ("prop" %in% display_col) {
    prop <- do.call(rbind, outdata$char_prop)
    name <- prop$name
    label <- prop$var_label
    value <- data.frame(apply(prop[2:(ncol(prop) - 1)], 2, function(x) as.numeric(as.character(x))))
    prop <- apply(value, 2, metalite.ae::fmt_pct, digits = digits_prop, pre = "(", post = ")") |> as.data.frame()
    prop <- data.frame(name = name, prop, var_label = label)
    if ("total" %in% display_col) {
      names(prop) <- c("name", paste0("p_", seq(1, n_group)), "p_9999", "var_label")
    } else {
      prop <- prop[, -(2 + n_group)]
      names(prop) <- c("name", paste0("p_", seq(1, n_group)), "var_label")
    }
    tbl[["prop"]] <- prop
  }

  if ("n_cum" %in% display_col) {
    if (is.null(outdata$char_n_cum)) {
      stop(
        "Please use `extend_exp_duration()` with `duration_category_list` and `duration_category_labels` to get n for a defined category.",
        call. = FALSE
      )
    }

    n_cum <- do.call(rbind, outdata$char_n_cum)
    if ("total" %in% display_col) {
      names(n_cum) <- c("name", paste0("n_", seq(1, n_group)), "n_9999", "var_label")
    } else {
      n_cum <- n_cum[, -(2 + n_group)]
      names(n_cum) <- c("name", paste0("n_", seq(1, n_group)), "var_label")
    }

    tbl[["n"]] <- rbind(n_cum, tbl[["n"]])
  }
  tbl$n <- rbind(outdata$n[, names(outdata$n) %in% names(tbl$n)], tbl$n)

  if ("prop_cum" %in% display_col) {
    if (is.null(outdata$char_prop_cum)) {
      stop(
        "Please use `extend_exp_duration()` with `duration_category_list` and `duration_category_labels` to get proportion for a defined category.",
        call. = FALSE
      )
    }

    prop_cum <- do.call(rbind, outdata$char_prop_cum)
    name_cum <- prop_cum$name
    label_cum <- prop_cum$var_label
    value_cum <- data.frame(apply(prop_cum[2:(ncol(prop_cum) - 1)], 2, function(x) as.numeric(as.character(x))))
    prop_cum <- apply(value_cum, 2, metalite.ae::fmt_pct, digits = digits_prop, pre = "(", post = ")") |> as.data.frame()
    prop_cum <- data.frame(name = name_cum, prop_cum, var_label = label_cum)
    if ("total" %in% display_col) {
      names(prop_cum) <- c("name", paste0("p_", seq(1, n_group)), "p_9999", "var_label")
    } else {
      prop_cum <- prop_cum[, -(2 + n_group)]
      names(prop_cum) <- c("name", paste0("p_", seq(1, n_group)), "var_label")
    }
    tbl[["prop"]] <- rbind(prop_cum, tbl[["prop"]])
  }
  tbl$prop <- rbind(c(tbl$n[1, 1], rep(NA, ifelse("total" %in% display_col, n_group + 1, n_group)), tbl$n[1, ncol(tbl$n)]), tbl$prop)

  # Arrange Within Group information
  within_var <- names(tbl)[names(tbl) %in% c("n", "prop")]
  within_tbl <- tbl[within_var]

  names(within_tbl) <- NULL
  n_within <- length(within_tbl)
  n_row <- ncol(tbl[["n"]])
  within_tbl <- do.call(cbind, within_tbl)

  within_tbl <- within_tbl[, !duplicated(names(within_tbl))]
  within_tbl <- within_tbl[, c(
    1, do.call(c, lapply(
      2:(1 + n_group + ifelse("total" %in% display_col, 1, 0)),
      function(x) {
        c(x, x + n_group + ifelse("total" %in% display_col, 1, 0) + 1)
      }
    )),
    (1 + n_group + ifelse("total" %in% display_col, 1, 0) + 1)
  )]

  rownames(within_tbl) <- NULL
  outdata$tbl <- within_tbl
  outdata$display_col <- display_col
  outdata$display_stat <- display_stat
  outdata$extend_call <- c(outdata$extend_call, match.call())

  return(outdata)
}

meta_sl_test <- function() {
  adsl <- r2rtf::r2rtf_adsl
  adsl$TRTA <- factor(
    adsl$TRT01A,
    levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
    labels = c("Placebo", "Low Dose", "High Dose")
  )

  adae <- r2rtf::r2rtf_adae
  adaedisc <- subset(
    adae[adae$AEACN == "DRUG WITHDRAWN", ],
    select = c(USUBJID, AEACN)
  )
  adaedisc <- adaedisc[!duplicated(adaedisc), ]

  adsl <- merge(adsl, adaedisc, by = "USUBJID", all.x = TRUE)
  adsl$EOTSTT <- ifelse(adsl$AEACN == "DRUG WITHDRAWN", "Discontinued", NA)
  adsl$DCTREAS <- ifelse(adsl$EOTSTT == "Discontinued", "Adverse Event", NA)
  adsl$EOTSTT[is.na(adsl$EOTSTT)] <- "temp"
  adsl$DCTREAS[is.na(adsl$DCTREAS)] <- "temp"

  adsl[adsl$EOTSTT != "Discontinued", "EOTSTT"] <- sample(
    x = c("Complete", "Discontinued", "Participants Ongoing"),
    size = sum(adsl$EOTSTT != "Discontinued"),
    prob = c(0.6, 0.2, 0.2),
    replace = TRUE
  )
  adsl[
    adsl$EOTSTT == "Discontinued" & adsl$DCTREAS != "Adverse Event",
    "DCTREAS"
  ] <- sample(
    x = c("Withdrawal By Subject", "Lack of Efficacy", "Lost to Follow-Up"),
    size = sum(adsl$EOTSTT == "Discontinued" & adsl$DCTREAS != "Adverse Event"),
    prob = c(0.3, 0.4, 0.3),
    replace = TRUE
  )
  adsl[adsl$EOTSTT != "Discontinued", "DCTREAS"] <- NA
  adsl$EOSSTT <- adsl$EOTSTT
  adsl$DCSREAS <- ifelse(adsl$DCTREAS == "Adverse Event", "Other", adsl$DCTREAS)

  analysis_plan <- metalite::plan(
    analysis = "base_char",
    population = "apat",
    observation = "apat",
    parameter = "age;gender;race"
  ) |>
    metalite::add_plan(
      analysis = "trt_compliance",
      population = "apat",
      observation = "apat",
      parameter = "comp8;comp16;comp24"
    ) |>
    metalite::add_plan(
      analysis = "disp",
      population = "apat",
      observation = "apat",
      parameter = "disposition;medical-disposition"
    ) |>
    metalite::add_plan(
      analysis = "base_char_subgroup",
      population = "apat",
      observation = "apat",
      parameter = "age"
    )

  metalite::meta_adam(population = adsl, observation = adsl) |>
    metalite::define_plan(analysis_plan) |>
    metalite::define_population(
      name = "apat",
      group = "TRTA",
      subset = SAFFL == "Y"
    ) |>
    metalite::define_parameter(
      name = "age",
      var = "AGE",
      label = "Age (years)",
      vargroup = "AGEGR1"
    ) |>
    metalite::define_parameter(
      name = "gender",
      var = "SEX",
      label = "Gender"
    ) |>
    metalite::define_parameter(
      name = "race",
      var = "RACE",
      label = "Race"
    ) |>
    metalite::define_parameter(
      name = "disposition",
      var = "EOSSTT",
      label = "Trial Disposition",
      var_lower = "DCSREAS"
    ) |>
    metalite::define_parameter(
      name = "medical-disposition",
      var = "EOTSTT",
      label = "Participant Study Medication Disposition",
      var_lower = "DCTREAS"
    ) |>
    metalite::define_parameter(
      name = "comp8",
      var = "COMP8FL",
      label = "Compliance (Week 8)"
    ) |>
    metalite::define_parameter(
      name = "comp16",
      var = "COMP16FL",
      label = "Compliance (Week 16)"
    ) |>
    metalite::define_parameter(
      name = "comp24",
      var = "COMP24FL",
      label = "Compliance (Week 24)"
    ) |>
    metalite::define_analysis(
      name = "base_char",
      title = "Participant Baseline Characteristics by Treatment Group",
      label = "baseline characteristic table"
    ) |>
    metalite::define_analysis(
      name = "trt_compliance",
      title = "Summary of Treatment Compliance",
      label = "treatment compliance table"
    ) |>
    metalite::define_analysis(
      name = "disp",
      title = "Disposition of Participant",
      label = "disposition table"
    ) |>
    metalite::define_analysis(
      name = "base_char_subgroup",
      title = "Participant by Age Category and Sex",
      label = "baseline characteristic sub group table"
    ) |>
    metalite::meta_build()
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Create an interactive plot for exposure duration
#'
#' @param outdata An `outdata` object created from `prepare_exp_duration()`.
#'   `extend_exp_duration()` can also be applied.
#' @param color Color for a histogram.
#' @param display A character vector of display type.
#'   `n` or `prop` can be selected.
#' @param display_total A logical value to display total.
#' @param display_standard_histogram A logical value if the standard histogram
#'   is displayed.
#' @param standard_histogram_label A character value of label for
#'   the standard histogram.
#' @param display_stacked_histogram A logical value if the stacked histogram
#'   is displayed.
#' @param stacked_histogram_label  A character value of label for
#'   the stacked histogram.
#' @param display_horizontal_histogram A logical value if the horizontal histogram
#'   is displayed.
#' @param horizontal_histogram_label  A character value of label for
#' @param plot_group_label A label for grouping.
#' @param plot_category_label A label for category.
#' @param hover_summary_var A character vector of statistics to be displayed
#'   on hover label of bar.
#' @param width Width of the plot.
#' @param height Height of the plot.
#'
#' @return Interactive plot for exposure duration.
#'
#' @importFrom plotly plot_ly layout
#' @importFrom stats reshape
#'
#' @export
#'
#' @examples
#' # Only run this example in interactive R sessions
#' if (interactive()) {
#'   meta <- metalite::meta_adam(
#'     population = metalite_sl_adexsum,
#'     observation = metalite_sl_adexsum
#'   ) |>
#'     metalite::define_plan(metalite::plan(
#'       analysis = "exp_dur", population = "apat",
#'       observation = "apat", parameter = "expdur"
#'     )) |>
#'     metalite::define_population(
#'       name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
#'     ) |>
#'     metalite::define_parameter(
#'       name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
#'       label = "Exposure Duration (Days)", vargroup = "EXDURGR"
#'     ) |>
#'     metalite::define_analysis(
#'       name = "exp_dur", title = "Summary of Exposure Duration",
#'       label = "exposure duration table"
#'     ) |>
#'     metalite::meta_build()
#'
#'   outdata <- meta |>
#'     prepare_exp_duration() |>
#'     extend_exp_duration(
#'       duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
#'       duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
#'     )
#'
#'   outdata |> plotly_exp_duration()
#' }
plotly_exp_duration <- function(outdata,
                                color = NULL,
                                display = c("n", "prop"),
                                display_total = TRUE,
                                display_standard_histogram = TRUE,
                                standard_histogram_label = "Comparison of Exposure Duration (> = x days) by Treatment Groups",
                                display_stacked_histogram = TRUE,
                                stacked_histogram_label = "Comparison of Exposure Duration (> = x days and < y days) by Treatment Groups",
                                display_horizontal_histogram = TRUE,
                                horizontal_histogram_label = "Comparison by Exposure Duration (> = x days)",
                                plot_group_label = "Treatment group",
                                plot_category_label = "Exposure duration",
                                hover_summary_var = c("n", "median", "sd", "se", "median", "min", "max", "q1 to q3", "range"),
                                width = 1000,
                                height = 400) {
  # input check
  display <- tolower(display)
  display <- match.arg(
    display,
    c("n", "prop")
  )
  hover_summary_var <- tolower(hover_summary_var)

  group_label <- outdata$group_label
  n_group <- length(outdata$group_label)
  if (display_total) {
    n_group <- n_group + 1
  }
  parameter <- outdata$parameter
  if (!length(unlist(strsplit(parameter, ";"))) == 1) {
    stop("Only one parameter is allowed for `plotly_exp_duration()`.")
  }
  par_var_group <- metalite::collect_adam_mapping(outdata$meta, parameter)$vargroup
  var_type <- outdata$var_type[[1]]
  p <- list()

  # Color palette
  color_pal <- c("#00857C", "#6ECEB2", "#BFED33", "#FFF063", "#0C2340", "#5450E4")

  # Exclusive counting
  if (!is.null(par_var_group) | var_type %in% c("character", "factor")) {
    tbl <- outdata$char_n[[1]]
    if (!is.null(par_var_group)) {
      tbl <- tbl[1:(which(is.na(tbl$name)) - 1), ]
    }
    prop <- outdata$char_prop[[1]]
    stats <- outdata$char_stat_groups

    res <- tbl
    res <- stats::reshape(
      res,
      varying = names(res)[!names(res) %in% c("name", "var_label")],
      v.names = "n",
      timevar = "group",
      times = names(res)[!names(res) %in% c("name", "var_label")],
      idvar = "name",
      new.row.names = NULL,
      direction = "long"
    )
    rownames(res) <- NULL

    if (display == "n") {
      plot_count_label <- "Number of participants"
      res$res <- as.numeric(res$n)
    } else {
      plot_count_label <- "Percentage of participants"
      res_prop <- prop[1:(which(is.na(prop$name)) - 1), ]
      res_prop <- stats::reshape(
        res_prop,
        varying = names(res_prop)[!names(res_prop) %in% c("name", "var_label")],
        v.names = "prop",
        timevar = "group",
        times = names(res_prop)[!names(res_prop) %in% c("name", "var_label")],
        idvar = "name",
        new.row.names = NULL,
        direction = "long"
      )
      rownames(res_prop) <- NULL
      res <- merge(res, res_prop, by = c("name", "var_label", "group"))
      res$res <- as.numeric(res$prop)
    }

    if (is.null(stats) & any(!hover_summary_var %in% "n")) {
      message("Only n is available for hover information. Please use `extend_exp_duration()` to add summary statistics for each category.")
    }

    res$text <- mapply(
      function(x, y) {
        stat <- stats[[x]][tolower(stats[[x]][["name"]]) %in% hover_summary_var, ]
        paste(paste(stat[["name"]], stat[[y]], sep = ": "), collapse = "\n")
      },
      res$name,
      res$group,
      SIMPLIFY = TRUE,
      USE.NAMES = FALSE
    )
    if ("n" %in% hover_summary_var) {
      res$text <- paste(paste0("N: ", res$n), res$text, sep = "\n")
    }
    if (display_total == TRUE) {
      res$group <- factor(res$group, levels = c(levels(group_label), "Total"))
    } else {
      res <- res[!res$group == "Total", ]
      res$group <- factor(res$group, levels = c(levels(group_label)))
    }
    res$name <- factor(res$name, levels = unique(tbl$name))

    # implement color
    if (is.null(color)) {
      color2 <- c("#66203A", rep(color_pal, length.out = length(unique(tbl$name)) - 1))
    } else {
      color2 <- rep(color, length.out = length(unique(tbl$name)))
    }

    plot_type2 <- res |>
      plotly::plot_ly(
        x = ~group,
        y = ~res,
        color = ~name,
        type = "bar",
        hoverinfo = "text",
        text = ~text,
        textposition = "none",
        colors = color2,
        width = width,
        height = height
      ) |>
      plotly::layout(
        xaxis = list(
          title = list(text = plot_group_label, standoff = 20), titlefont = list(size = 12),
          ticks = "outside", tickwidth = 1, tickfont = list(size = 9),
          showline = TRUE, linewidth = 2, linecolor = "#cccccc", mirror = TRUE
        ),
        yaxis = list(
          title = list(text = plot_count_label, standoff = 20), titlefont = list(size = 12),
          ticks = "outside", tickwidth = 1, tickfont = list(size = 9),
          showline = TRUE, linewidth = 2, linecolor = "#cccccc", mirror = TRUE
        ),
        legend = list(
          title = list(text = plot_category_label),
          x = 1.05,
          titlefont = list(size = 12),
          font = list(size = 9)
        ),
        barmode = "stack",
        autosize = FALSE
      )
    if (display_stacked_histogram) {
      p[[stacked_histogram_label]] <- plot_type2
    }
  }
  if (!is.null(outdata$char_n_cum)) {
    tbl_cum <- outdata$char_n_cum[[1]]
    prop_cum <- outdata$char_prop_cum[[1]]
    res_cum <- tbl_cum
    stats_cum <- outdata$char_stat_cums

    res_cum <- stats::reshape(
      res_cum,
      varying = names(res_cum)[!names(res_cum) %in% c("name", "var_label")],
      v.names = "n",
      timevar = "group",
      times = names(res_cum)[!names(res_cum) %in% c("name", "var_label")],
      idvar = "name",
      new.row.names = NULL,
      direction = "long"
    )
    rownames(res_cum) <- NULL

    if (display == "n") {
      plot_count_label <- "Number of participants"
      res_cum$res <- as.numeric(res_cum$n)
    } else {
      plot_count_label <- "Percentage of participants"
      res_cum_prop <- prop_cum[1:(which(is.na(prop$name)) - 1), ]
      res_cum_prop <- stats::reshape(
        res_cum_prop,
        varying = names(res_cum_prop)[!names(res_cum_prop) %in% c("name", "var_label")],
        v.names = "prop",
        timevar = "group",
        times = names(res_cum_prop)[!names(res_cum_prop) %in% c("name", "var_label")],
        idvar = "name",
        new.row.names = NULL,
        direction = "long"
      )
      rownames(res_cum_prop) <- NULL
      res_cum <- merge(res_cum, res_cum_prop, by = c("name", "var_label", "group"))
      res_cum$res <- as.numeric(res_cum$prop)
    }

    res_cum$text <- mapply(
      function(x, y) {
        stat_cum <- stats_cum[[x]][tolower(stats_cum[[x]][["name"]]) %in% hover_summary_var, ]
        paste(paste(stat_cum[["name"]], stat_cum[[y]], sep = ": "), collapse = "\n")
      },
      res_cum$name,
      res_cum$group,
      SIMPLIFY = TRUE,
      USE.NAMES = FALSE
    )
    if ("n" %in% hover_summary_var) {
      res_cum$text <- paste(paste0("N: ", res_cum$n), res_cum$text, sep = "\n")
    }
    if (display_total == TRUE) {
      res_cum$group <- factor(res_cum$group, levels = c(levels(group_label), "Total"))
    } else {
      res_cum <- res_cum[!res_cum$group == "Total", ]
      res_cum$group <- factor(res_cum$group, levels = c(levels(group_label)))
    }
    res_cum$name <- factor(res_cum$name, levels = unique(tbl_cum$name))

    # implement color
    if (is.null(color)) {
      color1 <- c("#66203A", rep(color_pal, length.out = length(unique(tbl_cum$name)) - 1))
    } else {
      color1 <- rep(color, length.out = length(unique(tbl_cum$name)))
    }

    plot_type1 <- res_cum |>
      plotly::plot_ly(
        x = ~group,
        y = ~res,
        color = ~name,
        colors = color1,
        type = "bar",
        hoverinfo = "text",
        text = ~text,
        textposition = "none",
        width = width,
        height = height
      ) |>
      plotly::layout(
        xaxis = list(
          title = list(text = plot_group_label, standoff = 20), titlefont = list(size = 12),
          ticks = "outside", tickwidth = 1, tickfont = list(size = 9),
          showline = TRUE, linewidth = 2, linecolor = "#cccccc", mirror = TRUE
        ),
        yaxis = list(
          title = list(text = plot_count_label, standoff = 20), titlefont = list(size = 12),
          ticks = "outside", tickwidth = 1, tickfont = list(size = 9),
          showline = TRUE, linewidth = 2, linecolor = "#cccccc", mirror = TRUE
        ),
        legend = list(
          title = list(text = plot_category_label),
          x = 1.05,
          titlefont = list(size = 12),
          font = list(size = 9)
        ),
        autosize = FALSE
      )

    # implement color
    if (is.null(color)) {
      color3 <- c("#66203A", rep(color_pal, length.out = n_group - 1))
    } else {
      color3 <- rep(color, length.out = n_group)
    }

    plot_type3 <- res_cum |>
      plotly::plot_ly(
        x = ~res,
        y = ~name,
        color = ~group,
        colors = color3,
        type = "bar",
        orientation = "h",
        hoverinfo = "text",
        text = ~text,
        textposition = "none",
        width = width,
        height = height
      ) |>
      plotly::layout(
        xaxis = list(
          title = list(text = plot_count_label, standoff = 20), titlefont = list(size = 12),
          ticks = "outside", tickwidth = 1, tickfont = list(size = 9),
          showline = TRUE, linewidth = 2, linecolor = "#cccccc", mirror = TRUE
        ),
        yaxis = list(
          title = list(text = plot_category_label, standoff = 20), titlefont = list(size = 12),
          ticks = "outside", tickwidth = 1, tickfont = list(size = 9),
          showline = TRUE, linewidth = 2, linecolor = "#cccccc", mirror = TRUE
        ),
        legend = list(
          title = list(text = plot_group_label),
          x = 1.05,
          titlefont = list(size = 12),
          font = list(size = 9)
        ),
        autosize = FALSE
      )

    if (display_standard_histogram) {
      p[[standard_histogram_label]] <- plot_type1
    }
    if (display_horizontal_histogram) {
      p[[horizontal_histogram_label]] <- plot_type3
    }
  }

  # Stop if there is no plot
  if (length(p) == 0) {
    stop("No plot is available. Please check the input data.")
  }

  histograms <- c(standard_histogram_label, stacked_histogram_label, horizontal_histogram_label)
  histograms <- histograms[c(display_standard_histogram, display_stacked_histogram, display_horizontal_histogram)]
  histograms_ids <- paste0("histogram_type_", uuid::UUIDgenerate(), "|", histograms)
  plot_divs <- lapply(histograms_ids, function(x) {
    element <- unlist(strsplit(x, "\\|"))[2]
    htmltools::div(
      id = x,
      style = "width: 100%; height: 100%; display: none;",
      plotly::as_widget(p[[element]])
    )
  })
  # Show the first plot by default
  plot_divs[[1]]$attribs$style <- "width: 100%; height: 100%; display: block;"

  # JavaScript to handle drop down selection
  brew::brew(
    system.file("js/dropdownController.js", package = "metalite.sl"),
    output = file.path(tempdir(), "dropdownController.js")
  )
  paste(readLines(file.path(tempdir(), "dropdownController.js")), collapse = "\n")

  # Create the drop down menu
  dropdown_id <- paste0("histogram_dropdown_", uuid::UUIDgenerate())
  dropdown <- htmltools::tags$div(
    id = dropdown_id,
    htmltools::tags$label(
      class = "dropdown-label",
      `for` = dropdown_id,
      "Histogram type",
      style = "margin-bottom: 0; font-weight: 400; font-family: sans-serif; font-size: 12px;"
    ),
    htmltools::tags$div(
      htmltools::tags$select(
        onchange = "dropdownController(this.value)",
        style = paste(
          "width:", paste0(width, "px;"), "margin-bottom: 15px; cursor: pointer;",
          "font-weight: 400; font-family: sans-serif; font-size: 12px;",
          "padding: 1px 3px; border: 1px solid #cccccc;",
          "border-radius: 4px;"
        ),
        lapply(histograms_ids, function(x) {
          htmltools::tags$option(unlist(strsplit(x, "\\|"))[2], value = x)
        })
      )
    )
  )

  htmltools::browsable(
    htmltools::tagList(
      htmltools::htmlDependency(
        "dropdownController.js",
        "0.1.0",
        src = tempdir(),
        script = "dropdownController.js",
        all_files = FALSE
      ),
      htmltools::div(
        dropdown,
        do.call(htmltools::tags$div, plot_divs)
      )
    )
  )
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Display interactive baseline characteristic tables with AE subgroup analysis
#'
#' @param metadata_sl A metadata created by metalite,
#'   which builds the baseline characteristic table
#' @param metadata_ae A metadata created by metalite,
#'   which builds the AE subgroup specific table
#' @param population A character value of population term name.
#'   The term name is used as key to link information.
#' @param observation A character value of observation term name.
#'   The term name is used as key to link information.
#' @param display_total Display total column or not.
#' @param sl_parameter A character value of parameter term name for
#'   the baseline characteristic table.
#'   The term name is used as key to link information.
#' @param ae_subgroup A vector of strubf to specify the subgroups
#'   in the AE subgroup specific table.
#' @param ae_specific A string specifying the AE specific category.
#' @param ae_analysis A character value of analysis term name for
#'   the AE specific table.
#' @param col_title A character value of column title for the AE specific table.
#' @param width A numeric value of width of the table in pixels.
#'
#' @return An reactable combing both baseline characteristic table
#'   and AE subgroup specific tables.
#'
#' @export
#'
#' @examples
#' if (interactive()) {
#'   sl_plan <- metalite::plan(
#'     analysis = "base_char",
#'     population = "apat",
#'     observation = "apat",
#'     parameter = "age;gender;race"
#'   )
#'
#'   metadata_sl <- metalite::meta_adam(
#'     observation = metalite_sl_adsl,
#'     population = metalite_sl_adsl
#'   ) |>
#'     metalite::define_plan(sl_plan) |>
#'     metalite::define_population(
#'       name = "apat",
#'       group = "TRTA",
#'       subset = SAFFL == "Y"
#'     ) |>
#'     metalite::define_parameter(
#'       name = "age",
#'       var = "AGE",
#'       label = "Age (years)",
#'       vargroup = "AGEGR1"
#'     ) |>
#'     metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
#'     metalite::define_parameter(name = "race", var = "RACE", label = "Race") |>
#'     metalite::define_analysis(
#'       name = "base_char",
#'       title = "Participant Baseline Characteristics by Treatment Group"
#'     ) |>
#'     metalite::meta_build()
#'
#'   analysis_plan <- metalite::plan(
#'     analysis = "ae_specific",
#'     population = "apat",
#'     observation = "wk12",
#'     parameter = "rel"
#'   )
#'
#'   metadata_ae <- metalite::meta_adam(
#'     observation = metalite_sl_adae,
#'     population = metalite_sl_adsl
#'   ) |>
#'     metalite::define_plan(analysis_plan) |>
#'     metalite::define_population(
#'       name = "apat",
#'       group = "TRTA",
#'       subset = SAFFL == "Y",
#'       label = "All Participants as Treated"
#'     ) |>
#'     metalite::define_observation(
#'       name = "wk12",
#'       group = "TRTA",
#'       subset = SAFFL == "Y",
#'       label = "Weeks 0 to 12"
#'     ) |>
#'     metalite::define_parameter(
#'       name = "rel",
#'       term1 = "Drug-Related",
#'       term2 = "",
#'       subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
#'       var = "AEDECOD",
#'       soc = "AEBODSYS",
#'       label = "Drug-related AEs"
#'     ) |>
#'     metalite::define_analysis(
#'       name = "ae_specific",
#'       title = "Participants With Drug-Related Adverse Events"
#'     ) |>
#'     metalite::meta_build()
#'
#'   react_base_char(
#'     metadata_sl = metadata_sl,
#'     metadata_ae = metadata_ae,
#'     population = "apat",
#'     observation = "wk12",
#'     display_total = TRUE,
#'     sl_parameter = "age;gender;race",
#'     ae_subgroup = c("age", "race", "gender"),
#'     ae_specific = "rel",
#'     width = 1200
#'   )
#' }
react_base_char <- function(
  metadata_sl,
  metadata_ae,
  population = "apat",
  observation = "wk12",
  display_total = TRUE,
  sl_parameter = "age;gender;race",
  ae_subgroup = c("gender", "race"),
  ae_specific = "rel",
  ae_analysis = "ae_specific",
  col_title = metalite::collect_title(
    metadata_ae,
    population,
    observation,
    ae_specific,
    ae_analysis,
    "analysis"
  ),
  width = 1200
) {
  # ----------------------------------------- #
  #   total setting                           #
  # ----------------------------------------- #

  if (display_total == TRUE) {
    display_sl <- c("n", "prop", "total")
  } else {
    display_sl <- c("n", "prop")
  }

  # ----------------------------------------- #
  #   prepare the baseline char table numbers #
  # ----------------------------------------- #
  x_sl <- metadata_sl |>
    prepare_sl_summary(
      population = population,
      analysis = metadata_sl$plan$analysis,
      parameter = sl_parameter
    ) |>
    format_base_char(display_col = display_sl, digits_prop = 2)

  tbl_sl <- x_sl$tbl
  tbl_sl$var_label[tbl_sl$name == "Participants in population"] <- "Participants in population"

  # ----------------------------------------- #
  #   prepare the AE subgroup table numbers   #
  # ----------------------------------------- #
  # get the variable name of the subgroup
  ae_subgrp_var <- NULL
  ae_subgrp_label <- NULL
  for (x_subgrp in ae_subgroup) {
    if (length(metalite::collect_adam_mapping(metadata_sl, x_subgrp)$vargroup) > 0) {
      ae_subgrp_var <- c(ae_subgrp_var, metalite::collect_adam_mapping(metadata_sl, x_subgrp)$vargroup)
    } else {
      ae_subgrp_var <- c(ae_subgrp_var, metalite::collect_adam_mapping(metadata_sl, x_subgrp)$var)
    }
    ae_subgrp_label <- c(ae_subgrp_label, metalite::collect_adam_mapping(metadata_sl, x_subgrp)$label)
  }

  # get the AE subgroup tables
  tbl_ae <- list()
  group_ae <- list()

  # define the space character
  space_char <- "\u2003\u2003"

  for (y_subgrp in ae_subgrp_var) {
    sl_pop_subgrp <- metalite::collect_population_record(metadata_sl, population, var = y_subgrp)[[y_subgrp]]
    ae_pop_subgrp <- metalite::collect_population_record(metadata_ae, population, var = y_subgrp)[[y_subgrp]]
    if (is.factor(sl_pop_subgrp)) {
      sl_pop_subgrp <- tolower(unique(levels(sl_pop_subgrp)))
    } else {
      sl_pop_subgrp <- tolower(unique(sl_pop_subgrp))
    }
    ae_pop_subgrp <- tolower(unique(as.character(ae_pop_subgrp)))
    if (!identical(all.equal(sl_pop_subgrp, ae_pop_subgrp), TRUE)) {
      stop(paste0(
        "For ", y_subgrp, " variable in lowcase, ",
        "the values or factor levels in `data_population` for sl should be identical to the values in `data_population` for ae. ",
        "sl: ", paste0(sl_pop_subgrp, collapse = ", "), "; ",
        "ae: ", paste0(ae_pop_subgrp, collapse = ", ")
      ))
    }

    tbl_ae_temp <- metalite.ae::prepare_ae_specific_subgroup(
      metadata_ae,
      population = population,
      observation = observation,
      parameter = ae_specific,
      subgroup_var = y_subgrp,
      display_subgroup_total = FALSE # total display for subgroup is not needed
    ) |>
      metalite.ae::format_ae_specific_subgroup()

    # modify the name elements in tbl_ae_temp$tbl: add spaces in name other than the value of "Participants in population"
    tbl_ae_temp$tbl$name <- sapply(tbl_ae_temp$tbl$name, function(x) {
      if (trimws(x) == "Participants in population") {
        return(x) # return the original value without modification
      } else {
        # Pad with spaces to a fixed width (e.g., 10 characters)
        return(paste0(space_char, x)) # Prepend spaces
      }
    })

    tbl_ae <- c(tbl_ae, list(tbl_ae_temp$tbl))
    # get group labels for AE analysis
    group_ae <- c(group_ae, list(tbl_ae_temp$group))
    # Note: Need to confirm whether treatment total can be displayed in ae subgroup
    # if (display_total == TRUE){
    #   group_ae <- c(group_ae, list(tbl_ae_temp$group))
    # } else {
    #   group_ae <- c(group_ae, list(tbl_ae_temp$group[!(tbl_ae_temp$group %in% "total")]))
    # }
  }

  # get the AE specific
  ae_specific_outdata <- metalite.ae::prepare_ae_specific(
    metadata_ae,
    population = population,
    observation = observation,
    parameter = ae_specific
  ) |>
    metalite.ae::format_ae_specific(display = display_sl)

  # if (is.null(col_title)) {
  #   col_title <- metalite::collect_title(ae_specific_outdata$meta,
  #                                        ae_specific_outdata$population,
  #                                        ae_specific_outdata$observation,
  #                                        ae_specific_outdata$parameter,
  #                                        analysis = ae_analysis,
  #                                        title_order = "analysis"
  #   )
  # }

  # modify the name elements in ae_specific_outdata$tbl$name: add spaces in name other than the value of "Participants in population"
  ae_specific_outdata$tbl$name <- sapply(ae_specific_outdata$tbl$name, function(x) {
    if (trimws(x) == "Participants in population" || is.na(x)) {
      return(x) # return the original value without modification
    } else {
      return(paste0(space_char, x)) # Prepend spaces
    }
  })

  # Define Column and Column Group for AE specific
  col_defs_ae <- list()
  col_group_defs_ae <- list()
  col_defs_ae[["name"]] <- reactable::colDef(name = col_title)
  for (i in 1:length(ae_specific_outdata$group)) {
    col_defs_ae[[paste0("n_", i)]] <- reactable::colDef(name = "n")
    col_defs_ae[[paste0("prop_", i)]] <- reactable::colDef(name = "(%)")

    col_group_defs_ae <- append(
      col_group_defs_ae,
      list(reactable::colGroup(
        name = ae_specific_outdata$group[i],
        columns = c(paste0("n_", i), paste0("prop_", i))
      ))
    )
  }


  # ----------------------------------------- #
  #   build interactive baseline char table   #
  # ----------------------------------------- #
  # Define Column
  col_defs <- list()
  for (sl_name in names(tbl_sl)) {
    if (startsWith(sl_name, "n_")) {
      col_defs[[sl_name]] <- reactable::colDef(name = "n")
    } else if (startsWith(sl_name, "p_")) {
      col_defs[[sl_name]] <- reactable::colDef(name = "(%)")
    } else {
      col_defs[[sl_name]] <- reactable::colDef(name = " ")
    }
  }
  col_defs[["var_label"]] <-
    reactable::colDef(
      name = " ",
      grouped = htmlwidgets::JS("
          function(cellInfo) {
            if (cellInfo.value === 'Participants in population') {
              return cellInfo.value;
            }
            return cellInfo.value + ' (' + cellInfo.subRows.length + ')';
          }
        ")
    )

  # Define Column Group
  col_group_defs <- list()
  for (i in 1:length(x_sl$group_label)) {
    group <- levels(x_sl$group_label)[i]
    col_group_defs <- append(
      col_group_defs,
      list(reactable::colGroup(
        name = group,
        columns = c(paste0("n_", i), paste0("p_", i))
      ))
    )
  }
  if (display_total == TRUE) {
    col_group_defs <- append(
      col_group_defs,
      list(reactable::colGroup(
        name = "Total",
        columns = c("n_9999", "p_9999")
      ))
    )
  }

  reactable::reactable(
    tbl_sl,
    resizable = TRUE, # allow users adjust table column width
    groupBy = "var_label",
    width = width,
    columns = col_defs,
    columnGroups = col_group_defs,
    defaultColDef = reactable::colDef(
      aggregated = htmlwidgets::JS("
        function (cellInfo, state) {
          var sub = cellInfo && cellInfo.subRows ? cellInfo.subRows : [];
          if (!Array.isArray(sub) || sub.length === 0) return null;

          var first = sub[0];
          var var_label =
            (first && first.values && first.values.var_label != null)
              ? first.values.var_label
              : (first && first.var_label != null)
                ? first.var_label
                : null;

          if (var_label !== 'Participants in population') return null;

          var colId = (cellInfo && cellInfo.column && cellInfo.column.id) || null;
          if (!colId || colId === 'name') return null;

          var vals = [];
          for (var i = 0; i < sub.length; i++) {
            var r = sub[i];
            var v =
              (r && r[colId] != null) ? r[colId]
                : (r && r.values && r.values[colId] != null) ? r.values[colId]
                : null;
            if (v != null) vals.push(v);
          }
          return vals;
        }
      ")
    ),
    rowStyle = htmlwidgets::JS("
      function(rowInfo) {
        if (
          rowInfo &&
          rowInfo.level === 1 &&
          rowInfo.values && rowInfo.values.name === 'Participants in population' &&
          !rowInfo.expanded &&
          typeof rowInfo.toggleRowExpanded === 'function'
        ) {
          rowInfo.toggleRowExpanded();
        }

        var isChild = !!(rowInfo && typeof rowInfo.depth === 'number' && rowInfo.depth > 0);

        var name =
          (rowInfo && rowInfo.values && rowInfo.values.name != null) ? rowInfo.values.name
            : (rowInfo && rowInfo.row && rowInfo.row.name != null) ? rowInfo.row.name
            : (rowInfo && rowInfo.original && rowInfo.original.name != null) ? rowInfo.original.name
            : null;

        if (isChild && name === 'Participants in population') {
          return { display: 'none' };
        }
        return {};
      }
    "),
    details = function(index) {
      if (index > 1 &
        !(tolower(tbl_sl$name[index]) %in% c("mean", "sd", "median", "min", "max", "se", "q1", "q3", "q1 to q3", "range")) &
        tbl_sl$var_label[index] %in% ae_subgrp_label & !is.na(tbl_sl$name[index])
      ) {
        # get the index of the AE subgroup variable by the index in the baseline char table
        idx_ae_subgroup <- which(tbl_sl$var_label[index] == ae_subgrp_label)

        # get the table for this AE subgroup variable
        tbl_ae[[idx_ae_subgroup]] |>
          react_subgroup_table(
            group = group_ae[[idx_ae_subgroup]],
            subgroup_name = tbl_sl$name[index],
            col_title = col_title
          )
      } else if (index == 1) {
        ae_specific_outdata$tbl |>
          reactable::reactable(
            # allow users adjust table column width
            resizable = TRUE,
            width = width,
            columns = col_defs_ae,
            columnGroups = col_group_defs_ae,
          )
      }
    }
  )
}

# Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
# All rights reserved.
#
# This file is part of the metalite.sl program.
#
# metalite.sl is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

#' Exposure duration table
#'
#' @param outdata An `outdata` object created by [prepare_sl_summary()].
#' @param source A character value of the data source.
#' @inheritParams r2rtf::rtf_page
#' @inheritParams r2rtf::rtf_body
#' @param footnotes A character vector of table footnotes.
#' @param title Term "analysis", "observation" and "population") for collecting title from metadata or a character vector of table titles.
#' @param path_outdata A character string of the outdata path.
#' @param path_outtable A character string of the outtable path.
#'
#' @return RTF file and source dataset for baseline characteristic table.
#'
#' @export
#'
#' @examples
#' meta <- metalite::meta_adam(
#'   population = metalite_sl_adexsum,
#'   observation = metalite_sl_adexsum
#' ) |>
#'   metalite::define_plan(metalite::plan(
#'     analysis = "exp_dur", population = "apat",
#'     observation = "apat", parameter = "expdur"
#'   )) |>
#'   metalite::define_population(
#'     name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
#'   ) |>
#'   metalite::define_parameter(
#'     name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
#'     label = "Exposure Duration (Days)", vargroup = "EXDURGR"
#'   ) |>
#'   metalite::define_analysis(
#'     name = "exp_dur", title = "Summary of Exposure Duration",
#'     label = "exposure duration table"
#'   ) |>
#'   metalite::meta_build()
#'
#' meta |>
#'   prepare_exp_duration(population = "apat", parameter = "expdur") |>
#'   format_exp_duration(display_col = c("n", "prop", "total")) |>
#'   rtf_exp_duration(
#'     source = "Source: [CDISCpilot: adam-adsl; adex]",
#'     path_outdata = tempfile(fileext = ".Rdata"),
#'     path_outtable = tempfile(fileext = ".rtf")
#'   )
rtf_exp_duration <- function(outdata,
                             source = "Source: [CDISCpilot: adam-adsl; adex]",
                             col_rel_width = NULL,
                             text_font_size = 9,
                             orientation = "portrait",
                             footnotes = c(
                               "Each participant is counted once on each applicable duration category row.",
                               "Duration of Exposure is the time from the first dose date to the last dose date."
                             ),
                             title = NULL,
                             path_outdata = NULL,
                             path_outtable = NULL) {
  return(
    rtf_sl_summary(
      outdata,
      source,
      col_rel_width = col_rel_width,
      text_font_size = text_font_size,
      orientation = orientation,
      footnotes = footnotes,
      title = title,
      path_outdata = path_outdata,
      path_outtable = path_outtable
    )
  )
}

meta_sl_exposure_test <- function() {
  adsl <- r2rtf::r2rtf_adsl

  set.seed(123)

  adexsum <- data.frame(USUBJID = adsl$USUBJID)
  adexsum$TRTA <- factor(
    adsl$TRT01A,
    levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
    labels = c("Placebo", "Low Dose", "High Dose")
  )
  adexsum$APERIODC <- "Base"
  adexsum$APERIOD <- 1
  adexsum$AVAL <- sample(
    x = seq_len(24 * 7),
    size = length(adexsum$USUBJID),
    replace = TRUE
  )
  adexsum$EXDURGR[adexsum$AVAL >= 1] <- ">=1 day and <7 days"
  adexsum$EXDURGR[adexsum$AVAL >= 7] <- ">=7 days and <28 days"
  adexsum$EXDURGR[adexsum$AVAL >= 28] <- ">=28 days and <12 weeks"
  adexsum$EXDURGR[adexsum$AVAL >= 12 * 7] <- ">=12 weeks and <24 weeks"
  adexsum$EXDURGR[adexsum$AVAL >= 24 * 7] <- ">=24 weeks"
  adexsum$EXDURGR <- factor(
    adexsum$EXDURGR,
    levels = c(
      ">=1 day and <7 days", ">=7 days and <28 days",
      ">=28 days and <12 weeks", ">=12 weeks and <24 weeks", ">=24 weeks"
    )
  )

  analysis_plan <- metalite::plan(
    analysis = "exp_dur",
    population = "apat",
    observation = "apat",
    parameter = "expdur"
  )

  metalite::meta_adam(population = adexsum, observation = adexsum) |>
    metalite::define_plan(analysis_plan) |>
    metalite::define_population(
      name = "apat",
      group = "TRTA",
      subset = APERIOD == 1 & AVAL > 0
    ) |>
    metalite::define_parameter(
      name = "expdur",
      var = "AVAL",
      label = "Exposure Duration (Days)",
      vargroup = "EXDURGR"
    ) |>
    metalite::define_analysis(
      name = "exp_dur",
      title = "Summary of Exposure Duration",
      label = "exposure duration table"
    ) |>
    metalite::meta_build()
}

---
title: "Baseline Characteristics Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Baseline Characteristics Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r}
library(metalite)
library(metalite.sl)
```

# Create Baseline Characteristic Table

The baseline characteristic analysis aims to provide tables to summarize details of participants.
The development of baseline characteristic analysis involves functions:

- `prepare_base_char`: prepare analysis raw datasets.
- `format_base_char`: prepare analysis outdata with proper format.
- `rtf_base_char`: transfer output dataset to RTF table.

## Build a metadata

```{r}
adsl <- r2rtf::r2rtf_adsl
adsl$TRTA <- adsl$TRT01A
adsl$TRTA <- factor(
  adsl$TRTA,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)
```

```{r}
meta <- meta_sl(
  dataset_population = adsl,
  population_term = "apat",
  parameter_term = "age;gender;race",
  parameter_var = "AGE^AGEGR1;SEX;RACE",
  treatment_group = "TRTA"
)
```

<details>
<summary>Click to show the output</summary>
```{r}
meta
```
</details>

## Analysis preparation

The input of the function `prepare_base_char()` is a `meta` object created by the metalite package.

```{r}
outdata <- meta |>
  prepare_base_char(parameter = "age;gender;race")

outdata
```


<details>
<summary>Click to show the output</summary>
```{r}
outdata$n
outdata$char_n
outdata$char_var
outdata$char_prop
```
</details>


## Format the numbers

`format_base_char` to prepare analysis dataset before generate RTF output

```{r}
outdata <-
  outdata |> format_base_char(
    display_col = c("n", "prop", "total"),
    digits_prop = 2
  )
```

<details>
<summary>Click to show the output</summary>
```{r}
outdata$tbl
```
</details>

## Output as RTF

`rtf_base_char` to generate RTF output

```{r}
outdata |> rtf_base_char(
  source = "Source: [CDISCpilot: adam-adsl]",
  path_outdata = tempfile(fileext = ".Rdata"),
  path_outtable = "outtable/base0char.rtf"
)
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/base0char.pdf")
```

# Create Baseline Characteristic Table for Subgroup Analysis 

The baseline characteristic subgroup analysis aims to provide tables to summarize details of participants by subgroup.
The development of baseline characteristic subgroup analysis involves functions:

- `prepare_base_char_subgroup()`: prepare analysis raw datasets.
- `format_base_char_subgroup()`: prepare analysis outdata with proper format.
- `rtf_base_char_subgroup()`: transfer output dataset to RTF table.

## Build a metadata

```{r}
adsl <- r2rtf::r2rtf_adsl
adsl$TRTA <- adsl$TRT01A
adsl$TRTA <- factor(
  adsl$TRTA,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)
```

```{r}
plan <- plan(
  analysis = "base_char_subgroup",
  population = "apat",
  observation = "apat",
  parameter = "age;gender;race"
)
```

```{r}
meta <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRTA", "SAFFL", "AGEGR1", "SEX", "RACE")
  ) |>
  define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  define_parameter(
    name = "race",
    var = "RACE",
    label = "Race"
  ) |>
  define_analysis(
    name = "base_char_subgroup",
    title = "Participant by Age Category and Sex",
    label = "baseline characteristic sub group table"
  ) |>
  meta_build()
```

<details>
<summary>Click to show the output</summary>
```{r}
meta
```
</details>

## Analysis preparation

The input of the function `prepare_base_char_subgroup()` is a `meta` object created by the metalite package.

The output of the function is an `outdata` object containing a list of analysis
raw datasets. Key arguments are:

- `subgroup_var`: a character value of subgroup variable name in observation data saved in meta$data_observation.
- `subgroup_header`: a character vector for column header hierarchy. The first element will be the first level header and the second element will be second level header.

```{r}
outdata <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "age;race",
  subgroup_var = "TRTA",
  subgroup_header = c("SEX", "TRTA")
)
```

<details>
<summary>Click to show the output</summary>
The output dataset contains commonly used statistics within each `subgroup_var`.

```{r}
outdata$out_all$`Placebo`
outdata$out_all$`High Dose`
outdata$out_all$`Low Dose`
```

The information about subgroup saved with `outdata$group` and `outdata$subgroup`.

```{r}
outdata$group
outdata$subgroup
```

`n_pop`: participants in population within each `subgroup_var`.

```{r}
outdata$out_all$`Placebo`$n
outdata$out_all$`High Dose`$n
outdata$out_all$`Low Dose`$n
```
</details>

## Format output

`format_base_char_subgroup` to prepare analysis dataset before generate RTF output

```{r}
outdata <- format_base_char_subgroup(outdata)
```

<details>
<summary>Click to show the output</summary>
```{r}
outdata$tbl
```
</details>

## Output as RTF

`rtf_base_char_subgroup` to generate RTF output

```{r, warning=FALSE}
outdata |>
  rtf_base_char_subgroup(
    source = "Source:  [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = "outtable/base0charsubgroup.rtf"
  )
```


```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/base0charsubgroup.pdf")
```

---
title: "Disposition Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Disposition Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150
)
```

```{r setup, message=FALSE}
library(metalite.sl)
library(metalite)
library(dplyr)
```



# Create Disposition Table

The objective of this tutorial is to generate a production-ready Disposition table specification analyses.

This report produces a table that contains counts and percentage of disposition for the participants in population for overall study.
To accomplish this using metalite.sl, four essential functions are required:

- `prepare_disposition ()`:subset data for disposition analysis.

- `format_disposition()`: prepare analysis outdata with proper format.

- `rtf_disposition ()`: transfer output dataset to RTF table.

An example output:

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/disposition.pdf")
```


## Example data

Within metalite.sl, we utilized the ADSL datasets from the metalite
package to create an illustrative dataset.
The metadata structure remains consistent across all analysis examples
within metalite.sl.
Additional information can be accessed on the
[metalite package website](https://merck.github.io/metalite/articles/metalite.html).

## Build a metadata


```{r}
adsl <- metalite_sl_adsl
head(adsl)
```

```{r}
plan <- plan(
  analysis = "disp", population = "apat",
  observation = "apat", parameter = "disposition;medical-disposition"
)
```


```{r}
meta <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y")
  ) |>
  define_parameter(
    name = "disposition",
    var = "EOSSTT",
    label = "Trial Disposition",
    var_lower = "DCSREAS"
  ) |>
  define_parameter(
    name = "medical-disposition",
    var = "EOTSTT",
    label = "Participant Study Medication Disposition",
    var_lower = "DCTREAS"
  ) |>
  define_analysis(
    name = "disp",
    title = "Disposition of Participant",
    label = "disposition table"
  ) |>
  meta_build()
```

<details>
<summary>Click to show the output</summary>
```{r}
meta
```
</details>

## Analysis preparation

The function `prepare_disposition()` is written to prepare data for subject disposition analysis.The function takes four arguments:

Meta is metadata object created by metalite and it contains data from ADSL.
Analysis, Population, and Parameter arguments are used to subset and process the meta data. They have default values, which rely on the meta data object.

The function assign default value Analysis to `prepare_disposition`, Population to the population value associated with the `prepare_disposition` analysis in meta plan, and parameter to the parameter(s) associated with the `prepare_disposition` analysis in meta$plan.

However, the user can also manually specify the analysis, population, and parameter values when calling the function, if they want to override the default values.

In the body of the function, it calls another function `prepare_sl_summary` with the same meta, analysis, population, and parameter arguments.
`prepare_sl_summary` takes the meta data, subsets it based on the analysis, population, and parameter values, and then calculates and returns a summary of the relevant data.

The result of `prepare_sl_summary` is then returned as the result of `prepare_disposition`.

The resulting output of the function `prepare_disposition()` comprises
a collection of raw datasets for analysis and reporting.

```{r}
outdata <- prepare_disposition(meta)
```

<details>
<summary>Click to show the output</summary>
```{r}
outdata
```
- `parameter`: parameter name

```{r}
outdata$parameter
```
- `n`: number of participants in population

```{r}
outdata$n
```

The resulting dataset contains frequently used statistics,
with variables indexed according to the order specified in `outdata$group`.

```{r}
outdata$group
```

- `char_n`: number of participants completed vs not completed in each parameter

```{r}
outdata$char_n
```

- `char_var` : name of parameter

```{r}
outdata$char_var
```

- `char_prop` : proportion of subject with disposition

```{r}
outdata$char_prop
```
</details>

## Format output

Once the raw analysis results are obtained,
the `format_disposition()` function can be employed to prepare the outdata,ensuring its compatibility with production-ready RTF tables.

```{r}
outdata <- outdata |> format_disposition()
```

<details>
<summary>Click to show the output</summary>
```{r}
outdata$tbl
```
</details>


## RTF tables

The last step is to prepare the RTF table using `rtf_trt_compliance`.

```{r}
outdata$tbl <- outdata$tbl %>%
  mutate(name = ifelse(trimws(name) == "Status Not Recorded", "    Status Not Recorded", name))

outdata |>
  rtf_disposition(
    "Source: [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = "outtable/disposition.rtf"
  )
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/disposition.pdf")
```

---
title: "Interactive exposure duration histogram"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{exposure-duration-histogram}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup, message=FALSE, warning=FALSE}
library(metalite.sl)
library(dplyr)
```

# Create Exposure Duration Histogram

The plotly_exp_duration() function provides an interactive visualization of subject-level exposure duration in clinical trials. This histogram helps assess how long participants remained on treatment, with configurable duration categories such as "≥1 day", "≥7 days", "≥28 days", and so on.

Using pre-processed output from prepare_exp_duration() (and optionally extend_exp_duration()), plotly_exp_duration() generates an intuitive, browser-based plot built with Plotly. Users can customize the display type (e.g., counts or proportions), color, tooltip summary statistics, and axis labels.

-  `prepare_exp_duration`: process subject-level exposure data to calculate treatment duration and prepare it for further analysis.

-  `extend_exp_duration`: categorize duration into user-defined time windows (e.g., ≥7 days, ≥12 weeks) and add group-level summaries.

-  `plotly_exp_duration`: generate an interactive histogram plot to visualize exposure duration distribution across subjects or treatment arms.

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/exposure0histogram.pdf")
```

## 1. Build metadata

There are two steps to build the metadata (`meta` object): load the ADaM dataset and save metadata for analysis and reporting.

Step1: Load up existing ADEXSUM, the ADaM dataset for Drug Exposrue Summary Data, that contains:

- Duration summed up by STUDYID SITENUM USUBJID SUBJID APERIOD EXTRT ADOSEFRM PARAMCD.
- The exposure data subset by `upcase(trim(left(paramcd))) = "TRTDURD"`.
- The exposure duration `adexsum$AVAL` for all participants.
- Duration category assigned with `adexsum$EXDURGR` i.e.">=1 day", ">=7 days",">=28 days", ">=12 weeks" and ">=24 weeks".
```{r}
data("metalite_sl_adexsum")
adexsum <- metalite_sl_adexsum
```
Step2: Save analysis plan and metadata(parameter and analysis) information, then build meta object.

```{r}
plan <- metalite::plan(
  analysis = "exp_dur", population = "apat",
  observation = "apat", parameter = "expdur"
)

meta <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    subset = PARAMCD == "TRTDURD",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()
```


## 2. Analysis preparation
## prepare_exp_duration()

The input of the function `prepare_exp_duration()` is a `meta` object created by the metalite package. The resulting output comprises a collection of raw datasets for analysis and reporting.

This function takes raw data (e.g., participant-level data with exposure durations and treatment groups).
It calculates summary statistics (counts, proportions, medians, etc.) grouped by treatment group.
It also creates exposure duration categories (e.g., >=1 day, >=7 days, etc.) by binning or categorizing the raw exposure duration variable.
The output is a structured dataset (outdata) that contains:
Counts and proportions of participants in each treatment group.
Summary statistics for the exposure duration variable within each treatment group.
However, at this stage, the statistics are grouped only by treatment group, not yet broken down by exposure duration categories.

```{r}
outdata <- prepare_exp_duration(meta)
outdata
```

Number of participants in population

```{r}
outdata$n[, 1:5]
```

Number of participants in each duration category

```{r}
charn <- data.frame(outdata$char_n[1])
head(charn[, 1:5], 6)
```

Proportion of participants in each duration category

```{r}
charp <- data.frame(outdata$char_prop[1])
head(charp[, 1:5], 6)
```

Statistical summary of exposure duration for each treatment

```{r}
chars <- data.frame(outdata$char_n[1])
tail(chars[, 1:5], 8)
```
## extend_exp_duration()
This function takes the output of prepare_exp_duration() and further processes the data to create exposure duration categories explicitly.
It applies the specified duration category cutoffs (e.g., >=1 day, >=7 days, etc.) to the exposure duration variable.
It calculates counts, proportions, and summary statistics for each exposure duration category within each treatment group.
This means now we have a two-dimensional grouping:
By treatment group (e.g., Placebo, Low Dose and High Dose).
By exposure duration category (e.g., >=1 day, >=7 days).
The output outdata now contains tables like:
char_n: counts by exposure duration category and treatment group.
char_prop: proportions by exposure duration category and treatment group.
char_stat_groups: summary statistics by exposure duration category and treatment group.


```{r}
outdata <- meta |>
  prepare_exp_duration() |>
  extend_exp_duration(
    duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
    duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
  )
outdata
```

```{r}
all_stats <- bind_rows(outdata$char_stat_groups, .id = "duration_category")

all_stats
```

## plotly_exp_duration()
The function takes the fully prepared outdata from the above steps to simply visualizes these pre-calculated statistics in an interactive way.
It reshapes the counts and proportions tables from wide to long format, so each row corresponds to a specific combination of:
Exposure duration category (e.g., >=7 days).
Treatment group (e.g., Placebo).
It uses these reshaped tables to create stacked bar charts or grouped bar charts that show:
The number or proportion of participants in each exposure duration category for each treatment group.
It also uses the summary statistics (char_stat_groups) to create hover text that shows detailed statistics for each bar (i.e., for each treatment group × exposure duration category).
The interactive dropdown lets you switch between different views (e.g., cumulative exposure duration, exclusive categories, horizontal bars).

```{r, out.width = "100%", out.height = "400px", echo = TRUE, fig.align = "center"}
outdata |>
  plotly_exp_duration(
    color = NULL,
    display = "n",
    display_total = TRUE,
    plot_group_label = "Treatment Group",
    plot_category_label = "Exposure Duration",
    hover_summary_var = c("mean", "min", "max"),
    width = 800,
    height = 400
  )
```

---
title: "Exposure Duration Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Exposure Duration Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r}
library(metalite)
library(metalite.sl)
```

# Create Exposure Duration Table

The exposure duration analysis aims to provide table to summarize by each identified duration category.
The development of exposure duration analysis involves functions:

- `metalite::meta_adam`: build the metadata (`meta` object) for analysis.
- `prepare_exp_duration`: prepare analysis raw datasets.
- `format_exp_duration`: prepare analysis outdata with proper format.
- `rtf_exp_duration`: transfer (mock) output dataset to RTF table.

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/exp0duration.pdf")
```

## Build a metadata

There are two steps to build the metadata (`meta` object): process the ADaM dataset and save metadata for analysis and reporting.

Step1: ADEXSUM, the ADaM dataset for Drug Exposrue Summary Data, is utilized to:

- Sum up duration by STUDYID SITENUM USUBJID SUBJID APERIOD EXTRT ADOSEFRM PARAMCD.
- Subset the exposure data by `upcase(trim(left(paramcd))) = "TRTDUR"`.
- Get the exposure duration `adexsum$AVAL` for all participants.
- Assign duration category `adexsum$EXDURGR` i.e.">=1 day", ">=7 days",">=28 days", ">=12 weeks" and ">=24 weeks".

```{r}
adsl <- r2rtf::r2rtf_adsl
adexsum <- data.frame(USUBJID = adsl$USUBJID)
adexsum$TRTA <- factor(adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

adexsum$APERIODC <- "Base"
adexsum$APERIOD <- 1

set.seed(123) # Set a seed for reproducibility
adexsum$AVAL <- sample(x = 0:(24 * 7), size = length(adexsum$USUBJID), replace = TRUE)
adexsum$EXDURGR <- "not treated"
adexsum$EXDURGR[adexsum$AVAL >= 1] <- ">=1 day"
adexsum$EXDURGR[adexsum$AVAL >= 7] <- ">=7 days"
adexsum$EXDURGR[adexsum$AVAL >= 28] <- ">=28 days"
adexsum$EXDURGR[adexsum$AVAL >= 12 * 7] <- ">=12 weeks"
adexsum$EXDURGR[adexsum$AVAL >= 24 * 7] <- ">=24 weeks"

adexsum$EXDURGR <- factor(adexsum$EXDURGR,
  levels = c("not treated", ">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
)
unique(adexsum$EXDURGR)
```

Step2: Save analysis plan and metadata(parameter and analysis) information, then build meta object.

```{r}
plan <- metalite::plan(
  analysis = "exp_dur", population = "apat",
  observation = "apat", parameter = "expdur"
)

meta <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()
```

## Analysis preparation

The input of the function `prepare_exp_duration()` is a `meta` object created by the metalite package. The resulting output comprises a collection of raw datasets for analysis and reporting.

```{r}
outdata <- prepare_exp_duration(meta)
outdata
```

Number of participants in population

```{r}
outdata$n[, 1:5]
```

Number of participants in each duration category

```{r}
charn <- data.frame(outdata$char_n[1])
head(charn[, 1:5], 6)
```

Proportion of participants in each duration category

```{r}
charp <- data.frame(outdata$char_prop[1])
head(charp[, 1:5], 6)
```

Statistical summary of exposure duration for each treatment

```{r}
chars <- data.frame(outdata$char_n[1])
tail(chars[, 1:5], 8)
```

## Format output

`format_exp_duration` to prepare analysis dataset before generate RTF output

```{r}
tbl <- format_exp_duration(outdata, display_col = c("n", "prop", "total"))
head(tbl$tbl)
```


## Output as RTF

`rtf_exp_duration` to generate RTF output

```{r, warning=FALSE}
outdata <- format_exp_duration(outdata, display_col = c("n", "prop", "total")) |>
  rtf_exp_duration(
    source = "Source:  [CDISCpilot: adam-adexsum]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = "outtable/exp0duration.rtf"
  )
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/exp0duration.pdf")
```

---
title: "Exposure Duration Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Exposure Duration Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r}
library(metalite)
library(metalite.sl)
```

# Create Exposure Duration Table

The exposure duration analysis aims to provide table to summarize by each identified duration category.
The development of exposure duration analysis involves functions:

- `meta_sl_exposure_example`: build the metadata (`meta` object) for analysis.
- `prepare_exp_duration`: prepare analysis raw datasets.
- `format_exp_duration`: prepare analysis outdata with proper format.
- `rtf_exp_duration`: transfer (mock) output dataset to RTF table.

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/exp0duration.pdf")
```

## Build a metadata

There are two steps in `meta_sl_exposure_example` function in order to build the metadata (`meta` object): processing the ADaM dataset and save meta information for A&R reporting.

Step1: ADEXSUM, the ADaM dataset for Drug Exposrue Summary Data, is utilized to:

- Sum up duration by STUDYID SITENUM USUBJID SUBJID APERIOD EXTRT ADOSEFRM PARAMCD.
- Subset the exposure data by `upcase(trim(left(paramcd))) = "TRTDUR"`.
- Get the exposure duration `adexsum$AVAL` for all participants.
- Assign duration category `adexsum$EXDURGR` i.e.">=1 day", ">=7 days",">=28 days", ">=12 weeks" and ">=24 weeks".

```{r}
adsl <- r2rtf::r2rtf_adsl
adexsum <- data.frame(USUBJID = adsl$USUBJID)
adexsum$TRTA <- factor(adsl$TRT01A,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

adexsum$APERIODC <- "Base"
adexsum$APERIOD <- 1

set.seed(123) # Set a seed for reproducibility
adexsum$AVAL <- sample(x = 0:(24 * 7), size = length(adexsum$USUBJID), replace = TRUE)
adexsum$EXDURGR <- "not treated"
adexsum$EXDURGR[adexsum$AVAL >= 1] <- ">=1 day"
adexsum$EXDURGR[adexsum$AVAL >= 7] <- ">=7 days"
adexsum$EXDURGR[adexsum$AVAL >= 28] <- ">=28 days"
adexsum$EXDURGR[adexsum$AVAL >= 12 * 7] <- ">=12 weeks"
adexsum$EXDURGR[adexsum$AVAL >= 24 * 7] <- ">=24 weeks"

adexsum$EXDURGR <- factor(adexsum$EXDURGR,
  levels = c("not treated", ">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
)
unique(adexsum$EXDURGR)
```

Step2: Save analysis plan and metadata(parameter and analysis) information, then build meta object.

```{r}
plan <- metalite::plan(
  analysis = "exp_dur", population = "apat",
  observation = "apat", parameter = "expdur"
)

meta <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()
```

## Analysis preparation

The input of the function `prepare_exp_duration()` is a `meta` object created by the metalite package. The resulting output comprises a collection of raw datasets for analysis and reporting.

```{r}
outdata <- prepare_exp_duration(meta)
outdata
```

Number of participants in population

```{r}
outdata$n[, 1:5]
```

Number of participants in each duration category

```{r}
charn <- data.frame(outdata$char_n[1])
head(charn[, 1:5], 6)
```

Proportion of participants in each duration category

```{r}
charp <- data.frame(outdata$char_prop[1])
head(charp[, 1:5], 6)
```

Statistical summary of exposure duration for each treatment

```{r}
chars <- data.frame(outdata$char_n[1])
tail(chars[, 1:5], 8)
```

## Format output

`format_exp_duration` to prepare analysis dataset before generate RTF output

```{r}
tbl <- format_exp_duration(outdata, display_col = c("n", "prop", "total"))
head(tbl$tbl)
```


## Output as RTF

`rtf_exp_duration` to generate RTF output

```{r, warning=FALSE}
outdata <- format_exp_duration(outdata, display_col = c("n", "prop", "total")) |>
  rtf_exp_duration(
    source = "Source:  [CDISCpilot: adam-adexsum]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = "outtable/exp0duration.rtf"
  )
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/exp0duration.pdf")
```

---
title: "Interactive Disposition Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Interactive Disposition Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150
)
```

```{r setup, message=FALSE}
library(metalite.sl)
library(metalite.ae)
library(metalite)
library(dplyr)
```


## Build a metadata


```{r}
adsl <- metalite_sl_adsl
metadata_ae <- metalite.ae::meta_ae_example()
metadata_ae$data_observation <- metalite_sl_adae
head(adsl)
```

```{r}
plan <- plan(
  analysis = "disp", population = "apat",
  observation = "apat", parameter = "disposition;medical-disposition"
)
```

```{r}
meta <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y")
  ) |>
  define_parameter(
    name = "disposition",
    var = "EOSSTT",
    label = "Trial Disposition",
    var_lower = "DCSREAS"
  ) |>
  define_parameter(
    name = "medical-disposition",
    var = "EOTSTT",
    label = "Participant Study Medication Disposition",
    var_lower = "DCTREAS"
  ) |>
  define_analysis(
    name = "disp",
    title = "Disposition of Participant",
    label = "disposition table"
  ) |>
  meta_build()
```

## Interactive Disposition
```{r}
react_disposition(
  metadata_sl = meta,
  metadata_ae = metadata_ae,
  width = 1200
)
```

---
title: "Interactive exposure duration histogram"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{exposure-duration-histogram}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup, message=FALSE, warning=FALSE}
library(metalite.sl)
library(dplyr)
```

# Create Exposure Duration Histogram

The plotly_exp_duration() function provides an interactive visualization of subject-level exposure duration in clinical trials. This histogram helps assess how long participants remained on treatment, with configurable duration categories such as "≥1 day", "≥7 days", "≥28 days", and so on.

Using pre-processed output from prepare_exp_duration() (and optionally extend_exp_duration()), plotly_exp_duration() generates an intuitive, browser-based plot built with Plotly. Users can customize the display type (e.g., counts or proportions), color, tooltip summary statistics, and axis labels.

-  `meta_sl_exposure_example`: create example exposure metadata (`meta` object) for demonstration or testing purposes.

-  `prepare_exp_duration`: process subject-level exposure data to calculate treatment duration and prepare it for further analysis.

-  `extend_exp_duration`: categorize duration into user-defined time windows (e.g., ≥7 days, ≥12 weeks) and add group-level summaries.

-  `plotly_exp_duration`: generate an interactive histogram plot to visualize exposure duration distribution across subjects or treatment arms.

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/exposure0histogram.pdf")
```

## 1. Load up a metadata
## meta_sl_exposure_example()
There are two steps in `meta_sl_exposure_example` function in order to build the metadata (`meta` object): processing the ADaM dataset and save meta information for A&R reporting.

Step1: Load up existing ADEXSUM, the ADaM dataset for Drug Exposrue Summary Data, that contains:

- Duration summed up by STUDYID SITENUM USUBJID SUBJID APERIOD EXTRT ADOSEFRM PARAMCD.
- The exposure data subset by `upcase(trim(left(paramcd))) = "TRTDURD"`.
- The exposure duration `adexsum$AVAL` for all participants.
- Duration category assigned with `adexsum$EXDURGR` i.e.">=1 day", ">=7 days",">=28 days", ">=12 weeks" and ">=24 weeks".
```{r}
data("metalite_sl_adexsum")
adexsum <- metalite_sl_adexsum
```
Step2: Save analysis plan and metadata(parameter and analysis) information, then build meta object.

```{r}
plan <- metalite::plan(
  analysis = "exp_dur", population = "apat",
  observation = "apat", parameter = "expdur"
)

meta <- metalite::meta_adam(
  population = adexsum,
  observation = adexsum
) |>
  metalite::define_plan(plan) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(APERIOD == 1 & AVAL > 0)
  ) |>
  metalite::define_parameter(
    name = "expdur",
    subset = PARAMCD == "TRTDURD",
    var = "AVAL",
    label = "Exposure Duration (Days)",
    vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur",
    title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()
```


## 2. Analysis preparation
## prepare_exp_duration()

The input of the function `prepare_exp_duration()` is a `meta` object created by the metalite package. The resulting output comprises a collection of raw datasets for analysis and reporting.

This function takes raw data (e.g., participant-level data with exposure durations and treatment groups).
It calculates summary statistics (counts, proportions, medians, etc.) grouped by treatment group.
It also creates exposure duration categories (e.g., >=1 day, >=7 days, etc.) by binning or categorizing the raw exposure duration variable.
The output is a structured dataset (outdata) that contains:
Counts and proportions of participants in each treatment group.
Summary statistics for the exposure duration variable within each treatment group.
However, at this stage, the statistics are grouped only by treatment group, not yet broken down by exposure duration categories.

```{r}
outdata <- prepare_exp_duration(meta)
outdata
```

Number of participants in population

```{r}
outdata$n[, 1:5]
```

Number of participants in each duration category

```{r}
charn <- data.frame(outdata$char_n[1])
head(charn[, 1:5], 6)
```

Proportion of participants in each duration category

```{r}
charp <- data.frame(outdata$char_prop[1])
head(charp[, 1:5], 6)
```

Statistical summary of exposure duration for each treatment

```{r}
chars <- data.frame(outdata$char_n[1])
tail(chars[, 1:5], 8)
```
## extend_exp_duration()
This function takes the output of prepare_exp_duration() and further processes the data to create exposure duration categories explicitly.
It applies the specified duration category cutoffs (e.g., >=1 day, >=7 days, etc.) to the exposure duration variable.
It calculates counts, proportions, and summary statistics for each exposure duration category within each treatment group.
This means now we have a two-dimensional grouping:
By treatment group (e.g., Placebo, Low Dose and High Dose).
By exposure duration category (e.g., >=1 day, >=7 days).
The output outdata now contains tables like:
char_n: counts by exposure duration category and treatment group.
char_prop: proportions by exposure duration category and treatment group.
char_stat_groups: summary statistics by exposure duration category and treatment group.


```{r}
outdata <- meta |>
  prepare_exp_duration() |>
  extend_exp_duration(
    duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
    duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
  )
outdata
```

```{r}
all_stats <- bind_rows(outdata$char_stat_groups, .id = "duration_category")

all_stats
```

## plotly_exp_duration()
The function takes the fully prepared outdata from the above steps to simply visualizes these pre-calculated statistics in an interactive way.
It reshapes the counts and proportions tables from wide to long format, so each row corresponds to a specific combination of:
Exposure duration category (e.g., >=7 days).
Treatment group (e.g., Placebo).
It uses these reshaped tables to create stacked bar charts or grouped bar charts that show:
The number or proportion of participants in each exposure duration category for each treatment group.
It also uses the summary statistics (char_stat_groups) to create hover text that shows detailed statistics for each bar (i.e., for each treatment group × exposure duration category).
The interactive dropdown lets you switch between different views (e.g., cumulative exposure duration, exclusive categories, horizontal bars).

```{r, out.width = "100%", out.height = "400px", echo = TRUE, fig.align = "center"}
outdata |>
  plotly_exp_duration(
    color = NULL,
    display = "n",
    display_total = TRUE,
    plot_group_label = "Treatment Group",
    plot_category_label = "Exposure Duration",
    hover_summary_var = c("mean", "min", "max"),
    width = 800,
    height = 400
  )
```

---
title: "Build an Interactive Baseline Characteristic Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Build an Interactive Baseline Characteristic Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, message=FALSE}
library(r2rtf)
library(metalite)
library(metalite.ae)
library(metalite.sl)
```

There are 2 key metadata types:

- metadata for the baseline characteristic table
- metadata for the AE subgroup specific table

# Build metadata {.tabset}

## Metadata for baseline characteristic table

The code below is the same as `meta_sl_example()`.

```{r}
adsl <- r2rtf::r2rtf_adsl
adsl$TRTA <- adsl$TRT01A
adsl$TRTA <- factor(adsl$TRTA,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

meta_sl <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan(
    analysis = "base_char", population = "apat",
    observation = "apat", parameter = "age;gender;race"
  )) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRTA", "SAFFL", "AGEGR1", "SEX", "RACE")
  ) |>
  define_observation(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRTA", "SAFFL", "AGEGR1", "SEX", "RACE")
  ) |>
  define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  define_parameter(
    name = "gender",
    var = "SEX",
    label = "Gender"
  ) |>
  define_parameter(
    name = "race",
    var = "RACE",
    label = "Race"
  ) |>
  define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group",
    label = "baseline characteristic table"
  ) |>
  meta_build()
```

## A metadata of the AE subgroup specific analysis

In this vignette, we will directly use the metadata built by `meta_ae_example()`.

```{r}
meta_ae <- meta_ae_example()
```

## Customization (Optional)

If you want to capitalize only the first letter of "RACE" (e.g., Black or african american) or any other character variable, 
you can customize the `react_base_char` function at the beginning of the code.


```{r}
# function to capitalize the first letter of a string that has multiple words
capitalize_words <- function(x) {
  sapply(x, function(word) {
    paste0(toupper(substr(word, 1, 1)), tolower(substr(word, 2, nchar(word))))
  })
}
```

```{r}
# 1) In "data_population": extract the RACE values as a character vector
race_values_pop <- meta_sl[["data_population"]]$RACE # Use $ to get a vector

# Capitalize the race values
meta_sl[["data_population"]]$RACE <- capitalize_words(race_values_pop) # Assign back as a vector

# 2) In "data_observation": extract the RACE values as a character vector
race_values_obs <- meta_sl[["data_observation"]]$RACE # Use $ to get a vector

# Capitalize the race values
meta_sl[["data_observation"]]$RACE <- capitalize_words(race_values_obs) # Assign back as a vector
```

# Build a reactable {.tabset}

## Baseline characteristic table + Participants With Drug-Related AE

```{r, eval = TRUE}
react_base_char(
  metadata_sl = meta_sl,
  metadata_ae = meta_ae,
  ae_subgroup = c("age", "race", "gender"),
  ae_specific = "rel",
  width = 1200
)
```

## Baseline characteristic table + Participants With Serious AE

```{r, eval=TRUE}
react_base_char(
  metadata_sl = meta_sl,
  metadata_ae = meta_ae,
  ae_subgroup = c("age", "race", "gender"),
  ae_specific = "ser",
  width = 1200
)
```

---
title: "Introduction to metalite.sl"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to metalite.sl}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
resource_files:
   - fig/*.png
   - pdf/*.pdf
---

```{r, include=FALSE}
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150,
  eval = TRUE
)
```

```{r}
library(metalite)
library(metalite.sl)
```

# Overview

metalite.sl R package designed for the analysis & reporting of subject-level analysis in clinical trials.
It operates on ADaM datasets and adheres to the metalite structure.
The package encompasses the following components:

<details>
<summary>Baseline Characteristics.</summary>
<img src="https://merck.github.io/metalite.sl/articles/fig/base0char.png" width="100%">
</details>

This R package offers a comprehensive software development lifecycle (SDLC)
solution, encompassing activities such as definition, development,
validation, and finalization of the analysis.

# Highlighted features

- Avoid duplicated input by using metadata structure.
  - For example, define analysis population once to use
    in all subject level analysis.
- Consistent input and output in standard functions.
- Provide workflow to add interactive features to subject-level analysis table.

# Workflow

The overall workflow includes the following steps:

1. Define metadata information using metalite R package.
1. Prepare outdata using `prepare_*()` functions.
1. Extend outdata using `extend_*()` functions (optional).
1. Format outdata using `format_*()` functions.
1. Create TLFs using `tlf_*()` functions.

For instance, we can illustrate the creation of a straightforward
Baseline characteristic table as shown below.

```{r}
sl_plan <- plan(
  analysis = "base_char",
  population = "apat",
  observation = "apat",
  parameter = "age;gender;race"
)

metadata_sl <- meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  define_plan(sl_plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  define_parameter(name = "gender", var = "SEX", label = "Gender") |>
  define_parameter(name = "race", var = "RACE", label = "Race") |>
  define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group"
  ) |>
  meta_build()
```

```{r, eval = FALSE}
metadata_sl |>
  prepare_base_char(
    population = "apat",
    analysis = "base_char",
    parameter = "age;gender"
  ) |>
  format_base_char() |>
  rtf_base_char(
    source = "Source: [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = tempfile(fileext = ".rtf")
  )
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/base0char.pdf")
```

An example for interactive baseline characteristic table:

```{r}
analysis_plan <- plan(
  analysis = "ae_specific",
  population = "apat",
  observation = "wk12",
  parameter = "rel"
)

metadata_ae <- meta_adam(
  observation = metalite_sl_adae,
  population = metalite_sl_adsl
) |>
  define_plan(analysis_plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "All Participants as Treated"
  ) |>
  define_observation(
    name = "wk12",
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "Weeks 0 to 12"
  ) |>
  define_parameter(
    name = "rel",
    term1 = "Drug-Related",
    term2 = "",
    subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
    var = "AEDECOD",
    soc = "AEBODSYS",
    label = "Drug-related AEs"
  ) |>
  define_analysis(
    name = "ae_specific",
    title = "Participants With Drug-Related Adverse Events"
  ) |>
  meta_build()

react_base_char(
  metadata_sl = metadata_sl,
  metadata_ae = metadata_ae,
  population = "apat",
  observation = "wk12",
  display_total = TRUE,
  sl_parameter = "age;race",
  ae_subgroup = c("age", "race"),
  ae_specific = "rel",
  width = 1200
)
```

Additional examples and tutorials can be found on the
[package website](https://merck.github.io/metalite.sl/articles/),
offering further guidance and illustrations.

## Input

To implement the workflow in metalite.sl, it is necessary to establish
a metadata structure using the metalite R package.
For detailed instructions, please consult the
[metalite tutorial](https://merck.github.io/metalite/articles/metalite.html).

---
title: "Introduction to metalite.sl"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to metalite.sl}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
resource_files:
   - fig/*.png
   - pdf/*.pdf
---

```{r, include=FALSE}
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150,
  eval = TRUE
)
```

```{r}
library(metalite)
library(metalite.sl)
```

# Overview

metalite.sl R package designed for the analysis & reporting of subject-level analysis in clinical trials.
It operates on ADaM datasets and adheres to the metalite structure.
The package encompasses the following components:

<details>
<summary>Baseline Characteristics.</summary>
<img src="https://merck.github.io/metalite.sl/articles/fig/base0char.png" width="100%">
</details>

This R package offers a comprehensive software development lifecycle (SDLC)
solution, encompassing activities such as definition, development,
validation, and finalization of the analysis.

# Highlighted features

- Avoid duplicated input by using metadata structure.
  - For example, define analysis population once to use
    in all subject level analysis.
- Consistent input and output in standard functions.
- Provide workflow to add interactive features to subject-level analysis table.

# Workflow

The overall workflow includes the following steps:

1. Define metadata information using metalite R package.
1. Prepare outdata using `prepare_*()` functions.
1. Extend outdata using `extend_*()` functions (optional).
1. Format outdata using `format_*()` functions.
1. Create TLFs using `tlf_*()` functions.

For instance, we can illustrate the creation of a straightforward
Baseline characteristic table as shown below.

```{r, eval = FALSE}
meta_sl_example() |>
  prepare_base_char(
    population = "apat",
    analysis = "base_char",
    parameter = "age;gender"
  ) |>
  format_base_char() |>
  rtf_base_char(
    source = "Source: [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = tempfile(fileext = ".rtf")
  )
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/base0char.pdf")
```

An example for interactive baseline characteristic table:

```{r}
react_base_char(
  metadata_sl = meta_sl_example(),
  metadata_ae = metalite.ae::meta_ae_example(),
  population = "apat",
  observation = "wk12",
  display_total = TRUE,
  sl_parameter = "age;race",
  ae_subgroup = c("age", "race"),
  ae_specific = "rel",
  width = 1200
)
```

Additional examples and tutorials can be found on the
[package website](https://merck.github.io/metalite.sl/articles/),
offering further guidance and illustrations.

## Input

To implement the workflow in metalite.sl, it is necessary to establish
a metadata structure using the metalite R package.
For detailed instructions, please consult the
[metalite tutorial](https://merck.github.io/metalite/articles/metalite.html)
and refer to the source code of the function
[`meta_sl_example()`](https://github.com/Merck/metalite.sl/blob/main/R/meta_sl_example.R).

---
title: "Treatment Compliance Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Treatment Compliance Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  comment = "#>",
  collapse = TRUE,
  out.width = "100%",
  dpi = 150
)
```

```{r setup, message=FALSE}
library(metalite)
library(metalite.sl)
library(dplyr)
```



# Create Treatment Compliance Table

The objective of this tutorial is to generate a production-ready Treatment Compliance specification analyses.

This report produces a table that contains a summary of treatment compliance information. The report consists of a treatment compliance category section and a treatment compliance statistics section. 
To accomplish this using metalite.sl, three essential functions are required:

- `prepare_trt_compliance ()`:this function is a wrapper function of `prepare_sl_summary ()` which prepares data for treatment compliance analysis.

- `format_trt_compliance()`: prepare analysis outdata with proper format.

- `rtf_trt_compliance()`: transfer output dataset to RTF table.

An example output:

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/treatment0compliance.pdf")
```

## Example data

Within metalite.sl, we utilized the ADSL datasets from the metalite
package to create an illustrative dataset.
The metadata structure remains consistent across all analysis examples
within metalite.sl.
To calculate treatment compliance percent and treatment compliance range, we utilized adex dataset.
Additional information can be accessed on the
[metalite package website](https://merck.github.io/metalite/articles/metalite.html).

## Build a metadata

```{r}
adsl <- r2rtf::r2rtf_adsl

adex <- metalite.ae::metalite_ae_adex

adex1 <- adex |>
  filter(EXNUMDOS > 0 & !(is.na(AENDY))) |>
  group_by(USUBJID) |>
  slice(n()) |>
  select(USUBJID, AENDY) |>
  rename(ADURN = AENDY)

adsl <- merge(adsl, adex1, by = "USUBJID")

adsl <- adsl |>
  mutate(
    TRTDUR = as.numeric(TRTDUR),
    ADURN = as.numeric(ADURN),
    CMPLPCT = round((ADURN / TRTDUR) * 100, 2)
  )

adsl <- adsl |>
  mutate(
    CMPLRNG = case_when(
      CMPLPCT >= 0 & CMPLPCT <= 20 ~ "0% to <=20%",
      CMPLPCT > 20 & CMPLPCT <= 40 ~ ">20% to <=40%",
      CMPLPCT > 40 & CMPLPCT <= 60 ~ ">40% to <=60%",
      CMPLPCT > 60 & CMPLPCT <= 80 ~ ">60% to <=80%",
      CMPLPCT > 80 ~ ">80%"
    ),
    CMPLRNGN = case_when(
      CMPLPCT >= 0 & CMPLPCT <= 20 ~ 1,
      CMPLPCT > 20 & CMPLPCT <= 40 ~ 2,
      CMPLPCT > 40 & CMPLPCT <= 60 ~ 3,
      CMPLPCT > 60 & CMPLPCT <= 80 ~ 4,
      CMPLPCT > 80 ~ 5
    )
  )

head(adsl)
```

```{r}
adsl$TRTA <- adsl$TRT01A
adsl$TRTA <- factor(adsl$TRTA,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)
```

```{r}
plan <- plan(
  analysis = "trt_compliance", population = "apat",
  observation = "apat", parameter = "CMPLRNG;CMPLPCT"
)
```

```{r}
meta <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRTA", "SAFFL", "CMPLPCT", "CMPLRNG")
  ) |>
  metalite::define_parameter(
    name = "CMPLPCT",
    var = "CMPLPCT",
    label = "Treatment Compliance Percent",
  ) |>
  metalite::define_parameter(
    name = "CMPLRNG",
    var = "CMPLRNG",
    label = "Treatment Compliance Range",
  ) |>
  define_analysis(
    name = "trt_compliance",
    title = "Summary of Treatment Compliance",
    label = "treatment compliance table"
  ) |>
  meta_build()
```

<details>
<summary>Click to show the output</summary>
```{r}
meta
```
</details>

## Analysis preparation

The function `prepare_trt_compliance()` is written to prepare data for treatment compliance analysis.The function takes four arguments:

meta is metadata object created by metalite and it contains data from ADSL.
Analysis, Population, and Parameter arguments are used to subset and process the meta data. They have default values, which rely on the meta data object.

The function assign default value Analysis to `trt_compliance`, Population to the population value associated with the `trt_compliance` analysis in meta plan, and parameter to the parameter(s) associated with the `trt_compliance` analysis in meta$plan.

However, the user can also manually specify the analysis, population, and parameter values when calling the function, if they want to override the default values.

In the body of the function, it calls another function prepare_sl_summary with the same meta, analysis, population, and parameter arguments.
`prepare_sl_summary` takes the meta data, subsets it based on the analysis, population, and parameter values, and then calculates and returns a summary of the relevant data.

The result of prepare_sl_summary is then returned as the result of prepare_trt_compliance.

The resulting output of the function `prepare_trt_compliance()` comprises
a collection of raw datasets for analysis and reporting.

```{r}
outdata <- prepare_trt_compliance(meta)
```

<details>
<summary>Click to show the output</summary>
```{r}
outdata
```
- `parameter`: parameter name
```{r}
outdata$parameter
```
- `n`: number of participants in population
```{r}
outdata$n
```

The resulting dataset contains frequently used statistics,
with variables indexed according to the order specified in `outdata$group`.

```{r}
outdata$group
```
- `char_n`: number of participants completed vs not completed in each parameter
```{r}
outdata$char_n
```
- `char_var` : name of parameter

```{r}
outdata$char_var
```
- `char_prop` : proportion of subject with treatment compliance


```{r}
outdata$char_prop
```
</details>

## Format output

Once the raw analysis results are obtained,
the `format_trt_compliance()` function can be employed to prepare the outdata,ensuring its compatibility with production-ready RTF tables.

```{r}
outdata <- outdata |> format_trt_compliance()
```

<details>
<summary>Click to show the output</summary>
```{r}
outdata$tbl
```
</details>

## Additional statistics

By using the `display` argument,
we can choose specific statistics to include.

```{r}
tbl <- outdata |> format_trt_compliance(display_stat = c("mean", "sd", "median", "range"), display_col = c("n", "prop", "total"))
```

<details>
<summary>Click to show the output</summary>
```{r}
tbl$tbl
```
</details>

## RTF tables

The last step is to prepare the RTF table using `rtf_trt_compliance`.

```{r}
outdata |>
  format_trt_compliance() |>
  rtf_trt_compliance(
    "Source: [CDISCpilot: adam-adsl]",
    path_outtable = "outtable/treatment0compliance.rtf"
  )
```

```{r, out.width = "100%", out.height = "400px", echo = FALSE, fig.align = "center"}
knitr::include_graphics("pdf/treatment0compliance.pdf")
```

---
title: "Build an Interactive Baseline Characteristic Table"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Build an Interactive Baseline Characteristic Table}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, message=FALSE}
library(r2rtf)
library(metalite)
library(metalite.ae)
library(metalite.sl)
```

There are 2 key metadata types:

- metadata for the baseline characteristic table
- metadata for the AE subgroup specific table

# Build metadata {.tabset}

## Metadata for baseline characteristic table

The code below builds the subject-level metadata directly from the example dataset.

```{r}
adsl <- r2rtf::r2rtf_adsl
adsl$TRTA <- adsl$TRT01A
adsl$TRTA <- factor(adsl$TRTA,
  levels = c("Placebo", "Xanomeline Low Dose", "Xanomeline High Dose"),
  labels = c("Placebo", "Low Dose", "High Dose")
)

meta_sl <- meta_adam(
  population = adsl,
  observation = adsl
) |>
  define_plan(plan = plan(
    analysis = "base_char", population = "apat",
    observation = "apat", parameter = "age;gender;race"
  )) |>
  define_population(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRTA", "SAFFL", "AGEGR1", "SEX", "RACE")
  ) |>
  define_observation(
    name = "apat",
    group = "TRTA",
    subset = quote(SAFFL == "Y"),
    var = c("USUBJID", "TRTA", "SAFFL", "AGEGR1", "SEX", "RACE")
  ) |>
  define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  define_parameter(
    name = "gender",
    var = "SEX",
    label = "Gender"
  ) |>
  define_parameter(
    name = "race",
    var = "RACE",
    label = "Race"
  ) |>
  define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group",
    label = "baseline characteristic table"
  ) |>
  meta_build()
```

## A metadata of the AE subgroup specific analysis

The AE metadata is built directly from the example subject-level and adverse event datasets.

```{r}
adsl_ae <- metalite_sl_adsl
adsl_ae$RACE <- tools::toTitleCase(adsl_ae$RACE)
adae <- metalite_sl_adae

analysis_plan <- plan(
  analysis = "ae_specific",
  population = "apat",
  observation = "wk12",
  parameter = "rel;ser"
)

meta_ae <- meta_adam(observation = adae, population = adsl_ae) |>
  define_plan(analysis_plan) |>
  define_population(
    name = "apat",
    var = c(
      "USUBJID", "SAFFL", "TRTA", "TRTDUR",
      "SITEID", "SEX", "RACE", "AGE"
    ),
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "All Participants as Treated"
  ) |>
  define_observation(
    name = "wk12",
    var = c(
      "USUBJID", "SAFFL", "TRTA", "SEX", "AEDECOD", "AEBODSYS", "AEREL",
      "AESER", "AEOUT", "AEACN", "AESDTH", "ASTDT", "AENDT"
    ),
    group = "TRTA",
    subset = SAFFL == "Y",
    label = "Weeks 0 to 12"
  ) |>
  define_parameter(
    name = "rel",
    term1 = "Drug-Related",
    term2 = "",
    subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
    var = "AEDECOD",
    soc = "AEBODSYS",
    label = "Drug-related AEs"
  ) |>
  define_parameter(
    name = "ser",
    term1 = "Serious",
    term2 = "",
    subset = AESER == "Y",
    var = "AEDECOD",
    soc = "AEBODSYS",
    label = "Serious AEs"
  ) |>
  define_analysis(
    name = "ae_specific",
    title = "Participants With Drug-Related Adverse Events"
  ) |>
  meta_build()
```

## Customization (Optional)

If you want to capitalize only the first letter of "RACE" (e.g., Black or african american) or any other character variable, 
you can customize the `react_base_char` function at the beginning of the code.


```{r}
# function to capitalize the first letter of a string that has multiple words
capitalize_words <- function(x) {
  sapply(x, function(word) {
    paste0(toupper(substr(word, 1, 1)), tolower(substr(word, 2, nchar(word))))
  })
}
```

```{r}
# 1) In "data_population": extract the RACE values as a character vector
race_values_pop <- meta_sl[["data_population"]]$RACE # Use $ to get a vector

# Capitalize the race values
meta_sl[["data_population"]]$RACE <- capitalize_words(race_values_pop) # Assign back as a vector

# 2) In "data_observation": extract the RACE values as a character vector
race_values_obs <- meta_sl[["data_observation"]]$RACE # Use $ to get a vector

# Capitalize the race values
meta_sl[["data_observation"]]$RACE <- capitalize_words(race_values_obs) # Assign back as a vector
```

# Build a reactable {.tabset}

## Baseline characteristic table + Participants With Drug-Related AE

```{r, eval = TRUE}
react_base_char(
  metadata_sl = meta_sl,
  metadata_ae = meta_ae,
  ae_subgroup = c("age", "race", "gender"),
  ae_specific = "rel",
  width = 1200
)
```

## Baseline characteristic table + Participants With Serious AE

```{r, eval=TRUE}
react_base_char(
  metadata_sl = meta_sl,
  metadata_ae = meta_ae,
  ae_subgroup = c("age", "race", "gender"),
  ae_specific = "ser",
  col_title = "Participants With Serious Adverse Events",
  width = 1200
)
```

# rtf output: n, and prop, NO total. With 2 decimal places.

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw12240\paperh15840
      
      \margl1800\margr1440\margt2520\margb1800\headery2520\footery1449
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 1 day and <7 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.16)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (3.57)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.38)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 7 days and <28 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 13}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (15.12)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 10}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (11.90)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (16.67)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 28 days and <12 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (32.56)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.95)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.57)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 12 weeks and <24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.00)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (52.38)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.19)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.16)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.19)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.19)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 89.8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 83.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 48.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 85.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 90.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Q1 to Q3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 36.75 to 129.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 52 to 135}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 41.5 to 128.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7000
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8000
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 4 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 SD=Standard deviation; SE=Standard error; Q1=First quartile, Q3=Third quartile.\line Each participant is counted once on each applicable duration category row.\line Duration of Exposure is the time from the first dose date to the last dose date.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adexsum]}\par}
      
      }

# rtf output: n, prop and total, with Landscape

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5563
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7788
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10013
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12238
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 1 day and <7 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (3.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 7 days and <28 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 13}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (15.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 10}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (11.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (16.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 28 days and <12 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (32.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (31.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.7)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 12 weeks and <24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (52.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 130}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 89.8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 83.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 48.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 49.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      
      
      {\pard\fs2\par}\page{\pard\fs2\par}
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5563
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7788
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10013
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12238
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 85.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 90.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Q1 to Q3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 36.75 to 129.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 52 to 135}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 41.5 to 128.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43.5 to 134}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3338
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4451
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5564
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6677
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7790
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8903
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11129
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12242
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 4 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 SD=Standard deviation; SE=Standard error; Q1=First quartile, Q3=Third quartile.\line Each participant is counted once on each applicable duration category row.\line Duration of Exposure is the time from the first dose date to the last dose date.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adexsum]}\par}
      
      }

# rtf output: n, prop and total, with no value of col_rel_width

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw12240\paperh15840
      
      \margl1800\margr1440\margt2520\margb1800\headery2520\footery1449
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Exposure Duration}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8999
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8998
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Exposure Duration (Days)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 1 day and <7 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (3.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (2.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 7 days and <28 days}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 13}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (15.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 10}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (11.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (16.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 28 days and <12 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (32.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (31.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.7)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 12 weeks and <24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (52.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 130}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (51.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 \uc1\u8805* 24 weeks}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0  (1.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 89.8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 83.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 50.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 48.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 49.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 SE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 5.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 3.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 85.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 90.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 87.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Q1 to Q3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 36.75 to 129.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 52 to 135}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 41.5 to 128.75}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 43.5 to 134}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1636
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2454
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3272
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4090
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4908
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5726
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6544
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7771
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8998
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 6 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 4 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 1 to 168}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9000
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 SD=Standard deviation; SE=Standard error; Q1=First quartile, Q3=Third quartile.\line Each participant is counted once on each applicable duration category row.\line Duration of Exposure is the time from the first dose date to the last dose date.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adexsum]}\par}
      
      }

# rtf output: n and prop including subgroup total w/o total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 143}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 111}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (54.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 66}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (59.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 46}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (32.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 31}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (27.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1360
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2040
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2720
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3400
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4760
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5440
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6800
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7480
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8840
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9520
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10880
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11560
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n and prop including subgroup total w/ total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3767
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6592
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9417
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 143}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 111}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (16.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.0)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (48.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 55}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (65.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (54.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 66}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (59.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 144}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.7)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 29}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (21.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 46}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (32.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 31}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (27.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (30.3)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n and prop not including subgroup total w/o total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5246
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8743
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3498
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5247
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6996
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8745
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10494
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12243
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n and prop not including subgroup total w/ total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Age (years)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 <65}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 14}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (16.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (8.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (13.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 65-80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 20}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (60.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (48.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 19}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (55.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (70.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 27}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (61.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 55}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (65.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 >80}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 22}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (41.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (24.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (35.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 29}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (34.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (17.5)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 11}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (25.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (21.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Mean}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 73.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 75.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.4}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 SD}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.7}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 8.2}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 7.9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Median}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 77.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 76.0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1224
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1836
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2448
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3060
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3672
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4284
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4896
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5508
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6732
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7344
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7956
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8568
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9792
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10404
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11016
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11628
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 Range}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 59 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 85}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 52 to 89}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 54 to 87}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 51 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 56 to 88}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: no group/subgroup total when a subgroup has no subject

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5246
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8743
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3498
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5247
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6996
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8745
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10494
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12243
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Race}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 AMERICAN INDIAN OR ALASKA NATIVE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (2.3)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 BLACK OR AFRICAN AMERICAN}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (6.8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1749
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2623
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3497
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4371
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5245
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6119
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6993
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7867
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8741
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9615
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10489
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11363
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12237
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 WHITE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 48}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (100.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (85.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: group/subgroup total when a subgroup has no subject

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Participant by Age Category and Sex}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3767
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6592
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9417
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12242
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Female}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Male}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 53}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 33}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 50}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 143}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 111}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 Race}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 AMERICAN INDIAN OR ALASKA NATIVE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (2.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (1.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   1}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (0.4)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 BLACK OR AFRICAN AMERICAN}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  5}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  8}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (12.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  0}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   (0.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (7.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (15.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  3}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (6.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  9}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (10.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  17}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (11.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0   6}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (5.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  23}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0  (9.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx942
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1413
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx1884
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2355
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx2826
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3297
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx3768
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4239
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx4710
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5181
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx5652
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6123
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx6594
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7065
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx7536
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8007
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8478
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx8949
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9420
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx9891
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10362
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx10833
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11304
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx11775
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12246
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs16{\f0 WHITE}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 48}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 44}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (100.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 78}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (92.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 34}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (85.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 40}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 74}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 126}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (88.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 104}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (93.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 230}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 (90.6)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs16{\f0 SD=Standard deviation.}\cell
      \intbl\row\pard
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs16{\f0 Source:  [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n, prop, total

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Treatment Compliance}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 64}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (25.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 74}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (86.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (71.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 190}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (74.8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 16)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (20.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 107}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (42.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 68}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (79.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (44.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 147}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (57.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 24)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 54}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (64.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 136}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (53.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (69.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (35.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 118}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (46.5)}\cell
      \intbl\row\pard
      
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adsl]}\par}
      
      }

# rtf output: n, prop, total (no display_stat)

    Code
      writeLines(rtf_content)
    Output
      {\rtf1\ansi
      \deff0\deflang1033
      {\fonttbl{\f0\froman\fcharset1\fprq2 Times New Roman;}
      {\f1\froman\fcharset161\fprq2 Times New Roman Greek;}
      {\f2\fswiss\fcharset161\fprq2 Arial Greek;}
      {\f3\fswiss\fcharset0\fprq2 Arial;}
      {\f4\fswiss\fcharset1\fprq2 Helvetica;}
      {\f5\fswiss\fcharset1\fprq2 Calibri;}
      {\f6\froman\fcharset1\fprq2 Georgia;}
      {\f7\ffroman\fcharset1\fprq2 Cambria;}
      {\f8\fmodern\fcharset0\fprq2 Courier New;}
      {\f9\ftech\fcharset2\fprq2 Symbol;}
      }
      
      
      \paperw15840\paperh12240\landscape
      
      \margl1440\margr1440\margt2880\margb1800\headery1800\footery1800
      
      {\pard\hyphpar\sb180\sa180\fi0\li0\ri0\qc\fs24{\f0 Summary of Treatment Compliance}\line\fs24{\f0 All Participants as Treated}\par}
      
      
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrdb\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Placebo}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Low Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 High Dose}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Total}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalb\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalb\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 n}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (%)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0 Participants in population}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 86}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 84}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 254}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 }\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 12}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (14.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 24}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (28.6)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 64}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (25.2)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 74}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (86.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (71.4)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 190}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (74.8)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 16)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 18}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (20.9)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 47}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (56.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 107}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (42.1)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 68}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (79.1)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 42}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (50.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 37}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (44.0)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 147}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (57.9)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrs\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrs\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\ql\fs18{\f0\b Compliance (Week 24)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 N}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 26}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (30.2)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 56}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (66.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 54}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (64.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 136}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (53.5)}\cell
      \intbl\row\pard
      \trowd\trgaph108\trleft0\trqc
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx4080
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx5100
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx6120
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx7140
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx8160
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx9180
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx10200
      \clbrdrl\brdrs\brdrw15\clbrdrt\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx11220
      \clbrdrl\brdrw15\clbrdrt\brdrw15\clbrdrr\brdrs\brdrw15\clbrdrb\brdrdb\brdrw15\clvertalt\cellx12240
      \pard\hyphpar0\sb15\sa15\fi100\li100\ri0\ql\fs18{\f0 Y}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 60}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (69.8)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 28}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (33.3)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 30}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (35.7)}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 118}\cell
      \pard\hyphpar0\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 (46.5)}\cell
      \intbl\row\pard
      
      {\pard\hyphpar\sb15\sa15\fi0\li0\ri0\qc\fs18{\f0 Source: [CDISCpilot: adam-adsl]}\par}
      
      }

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/collect.R
\name{collect_baseline}
\alias{collect_baseline}
\title{Count number of subjects}
\usage{
collect_baseline(
  meta,
  population,
  parameter,
  type = "Subjects",
  use_na = c("ifany", "no", "always"),
  display_total = TRUE
)
}
\arguments{
\item{meta}{A metadata object created by metalite.}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{parameter}{A character value of parameter term name.
The term name is used as key to link information.}

\item{type}{A character value to control title name,
e.g., Subjects or Records.}

\item{use_na}{A character value for whether to include \code{NA} values
in the table. See the \code{useNA} argument in \code{\link[base:table]{base::table()}} for more details.}

\item{display_total}{A logical value to display total column.}
}
\value{
A list containing number of subjects
}
\description{
Count number of subjects
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char",
    population = "apat",
    observation = "apat",
    parameter = "age"
  )) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  metalite::define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group"
  ) |>
  metalite::meta_build()

meta |> collect_baseline(
  population = "apat",
  parameter = "age"
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotly_exp_duration.R
\name{plotly_exp_duration}
\alias{plotly_exp_duration}
\title{Create an interactive plot for exposure duration}
\usage{
plotly_exp_duration(
  outdata,
  color = NULL,
  display = c("n", "prop"),
  display_total = TRUE,
  display_standard_histogram = TRUE,
  standard_histogram_label =
    "Comparison of Exposure Duration (> = x days) by Treatment Groups",
  display_stacked_histogram = TRUE,
  stacked_histogram_label =
    "Comparison of Exposure Duration (> = x days and < y days) by Treatment Groups",
  display_horizontal_histogram = TRUE,
  horizontal_histogram_label = "Comparison by Exposure Duration (> = x days)",
  plot_group_label = "Treatment group",
  plot_category_label = "Exposure duration",
  hover_summary_var = c("n", "median", "sd", "se", "median", "min", "max", "q1 to q3",
    "range"),
  width = 1000,
  height = 400
)
}
\arguments{
\item{outdata}{An \code{outdata} object created from \code{prepare_exp_duration()}.
\code{extend_exp_duration()} can also be applied.}

\item{color}{Color for a histogram.}

\item{display}{A character vector of display type.
\code{n} or \code{prop} can be selected.}

\item{display_total}{A logical value to display total.}

\item{display_standard_histogram}{A logical value if the standard histogram
is displayed.}

\item{standard_histogram_label}{A character value of label for
the standard histogram.}

\item{display_stacked_histogram}{A logical value if the stacked histogram
is displayed.}

\item{stacked_histogram_label}{A character value of label for
the stacked histogram.}

\item{display_horizontal_histogram}{A logical value if the horizontal histogram
is displayed.}

\item{horizontal_histogram_label}{A character value of label for}

\item{plot_group_label}{A label for grouping.}

\item{plot_category_label}{A label for category.}

\item{hover_summary_var}{A character vector of statistics to be displayed
on hover label of bar.}

\item{width}{Width of the plot.}

\item{height}{Height of the plot.}
}
\value{
Interactive plot for exposure duration.
}
\description{
Create an interactive plot for exposure duration
}
\examples{
# Only run this example in interactive R sessions
if (interactive()) {
  meta <- metalite::meta_adam(
    population = metalite_sl_adexsum,
    observation = metalite_sl_adexsum
  ) |>
    metalite::define_plan(metalite::plan(
      analysis = "exp_dur", population = "apat",
      observation = "apat", parameter = "expdur"
    )) |>
    metalite::define_population(
      name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
    ) |>
    metalite::define_parameter(
      name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
      label = "Exposure Duration (Days)", vargroup = "EXDURGR"
    ) |>
    metalite::define_analysis(
      name = "exp_dur", title = "Summary of Exposure Duration",
      label = "exposure duration table"
    ) |>
    metalite::meta_build()

  outdata <- meta |>
    prepare_exp_duration() |>
    extend_exp_duration(
      duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
      duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
    )

  outdata |> plotly_exp_duration()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{defmt_pct}
\alias{defmt_pct}
\title{Deformat percent}
\usage{
defmt_pct(pct)
}
\arguments{
\item{pct}{string eager to remove percent}
}
\value{
Numeric value without percent
}
\description{
Deformat percent
}
\examples{
defmt_pct("10.0\%")
defmt_pct(c("10.0\%", "(11.2\%)"))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/format_exp_duration.R
\name{format_exp_duration}
\alias{format_exp_duration}
\title{Format Exposure Duration Analysis}
\usage{
format_exp_duration(
  outdata,
  display_col = c("n", "prop", "n_cum", "prop_cum", "total"),
  digits_prop = 1,
  display_stat = c("mean", "sd", "se", "median", "q1 to q3", "range")
)
}
\arguments{
\item{outdata}{A metadata object created by \code{\link[=prepare_sl_summary]{prepare_sl_summary()}}.}

\item{display_col}{Column wants to display on the table.
"n_cum", "prop_cum" can additionally be selected.
\itemize{
\item \code{n_cum}: Number of subjects created by \code{extend_exp_duration()}.
\item \code{prop_cum}: Proportion of subjects created by \code{extend_exp_duration()}.
}}

\item{digits_prop}{Number of digits for proportion columns.}

\item{display_stat}{A vector of statistics term name.
The term name could be selected from
\code{c("mean", "sd", "se", "median", "q1 to q3", "range", "q1", "q3", "min", "max")}.}
}
\value{
A list of analysis raw datasets.
}
\description{
Format Exposure Duration Analysis
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adexsum,
  observation = metalite_sl_adexsum
) |>
  metalite::define_plan(metalite::plan(
    analysis = "exp_dur", population = "apat",
    observation = "apat", parameter = "expdur"
  )) |>
  metalite::define_population(
    name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
  ) |>
  metalite::define_parameter(
    name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
    label = "Exposure Duration (Days)", vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur", title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()

meta |>
  prepare_exp_duration(population = "apat", parameter = "expdur") |>
  format_exp_duration(display_col = c("n", "prop", "total"))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prepare_sl_summary.R
\name{prepare_sl_summary}
\alias{prepare_sl_summary}
\title{Prepare data for baseline characteristic table}
\usage{
prepare_sl_summary(
  meta,
  population,
  analysis,
  parameter = paste(names(meta$parameter), collapse = ";")
)
}
\arguments{
\item{meta}{A metadata object created by metalite.}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{analysis}{A character value of analysis term name.
The term name is used as key to link information.}

\item{parameter}{A character value of parameter term name.
The term name is used as key to link information.}
}
\value{
A list of analysis raw datasets.
}
\description{
Prepare data for baseline characteristic table
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char",
    population = "apat",
    observation = "apat",
    parameter = "age;gender;race"
  )) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
  metalite::define_parameter(name = "race", var = "RACE", label = "Race") |>
  metalite::define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group"
  ) |>
  metalite::meta_build()

meta |> prepare_sl_summary(population = "apat", analysis = "base_char")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extend_exp_duration.R
\name{extend_exp_duration}
\alias{extend_exp_duration}
\title{Add cumulative count and summary stats for categories for exposure duration analysis}
\usage{
extend_exp_duration(
  outdata,
  category_section_label = paste0(metalite::collect_adam_mapping(outdata$meta,
    outdata$parameter)$label, " (extend)"),
  duration_category_list = extract_duration_category_ranges(duration_category_labels),
  duration_category_labels =
    levels(outdata$meta$data_population[[metalite::collect_adam_mapping(outdata$meta,
    outdata$parameter)$vargroup]])
)
}
\arguments{
\item{outdata}{An \code{outdata} object created by \code{\link[=prepare_exp_duration]{prepare_exp_duration()}}.}

\item{category_section_label}{A character value of section label.
If \code{NULL}, the parameter label is used with "(cumulative)".}

\item{duration_category_list}{A list of duration category ranges.
Must be real numbers and may overlap or be mutually exclusive.
A list should be in the form of \code{list(c(low1, high1), c(low2, high2), ...)}.
If \code{NA} is included in the range, it is treated as \code{-Inf} or \code{Inf}.
The range is defined as \verb{low <= x < high} for each.}

\item{duration_category_labels}{A character vector of internal labels.
Labels to be displayed for the duration_category_list values.
Must be the same length as duration_category_list.}
}
\value{
A list of analysis raw datasets.
}
\description{
Add cumulative count and summary stats for categories for exposure duration analysis
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adexsum,
  observation = metalite_sl_adexsum
) |>
  metalite::define_plan(metalite::plan(
    analysis = "exp_dur", population = "apat",
    observation = "apat", parameter = "expdur"
  )) |>
  metalite::define_population(
    name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
  ) |>
  metalite::define_parameter(
    name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
    label = "Exposure Duration (Days)", vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur", title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()

outdata <- meta |> prepare_exp_duration()
outdata |>
  extend_exp_duration(
    duration_category_list = list(c(1, NA), c(7, NA), c(28, NA), c(12 * 7, NA), c(24 * 7, NA)),
    duration_category_labels = c(">=1 day", ">=7 days", ">=28 days", ">=12 weeks", ">=24 weeks")
  )
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/format_sl_summary.R
\name{format_base_char}
\alias{format_base_char}
\title{Format Baseline Characteristics Analysis}
\usage{
format_base_char(
  outdata,
  display_col = c("n", "prop", "total"),
  digits_prop = 1,
  display_stat = c("mean", "sd", "se", "median", "q1 to q3", "range")
)
}
\arguments{
\item{outdata}{A metadata object created by \code{\link[=prepare_sl_summary]{prepare_sl_summary()}}.}

\item{display_col}{Column wants to display on the table.
The term could be selected from \code{c("n", "prop", "total")}.}

\item{digits_prop}{Number of digits for proportion columns.}

\item{display_stat}{A vector of statistics term name.
The term name could be selected from
\code{c("mean", "sd", "se", "median", "q1 to q3", "range", "q1", "q3", "min", "max")}.}
}
\value{
A list of analysis raw datasets.
}
\description{
Format Baseline Characteristics Analysis
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char", population = "apat",
    observation = "apat", parameter = "age;gender"
  )) |>
  metalite::define_population(
    name = "apat", group = "TRTA", subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
  ) |>
  metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
  metalite::define_analysis(
    name = "base_char",
    title = "Participant Baseline Characteristics by Treatment Group"
  ) |>
  metalite::meta_build()

meta |>
  prepare_base_char(population = "apat", parameter = "age;gender") |>
  format_base_char()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/react_base_char.R
\name{react_base_char}
\alias{react_base_char}
\title{Display interactive baseline characteristic tables with AE subgroup analysis}
\usage{
react_base_char(
  metadata_sl,
  metadata_ae,
  population = "apat",
  observation = "wk12",
  display_total = TRUE,
  sl_parameter = "age;gender;race",
  ae_subgroup = c("gender", "race"),
  ae_specific = "rel",
  ae_analysis = "ae_specific",
  col_title = metalite::collect_title(metadata_ae, population, observation, ae_specific,
    ae_analysis, "analysis"),
  width = 1200
)
}
\arguments{
\item{metadata_sl}{A metadata created by metalite,
which builds the baseline characteristic table}

\item{metadata_ae}{A metadata created by metalite,
which builds the AE subgroup specific table}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{observation}{A character value of observation term name.
The term name is used as key to link information.}

\item{display_total}{Display total column or not.}

\item{sl_parameter}{A character value of parameter term name for
the baseline characteristic table.
The term name is used as key to link information.}

\item{ae_subgroup}{A vector of strubf to specify the subgroups
in the AE subgroup specific table.}

\item{ae_specific}{A string specifying the AE specific category.}

\item{ae_analysis}{A character value of analysis term name for
the AE specific table.}

\item{col_title}{A character value of column title for the AE specific table.}

\item{width}{A numeric value of width of the table in pixels.}
}
\value{
An reactable combing both baseline characteristic table
and AE subgroup specific tables.
}
\description{
Display interactive baseline characteristic tables with AE subgroup analysis
}
\examples{
if (interactive()) {
  sl_plan <- metalite::plan(
    analysis = "base_char",
    population = "apat",
    observation = "apat",
    parameter = "age;gender;race"
  )

  metadata_sl <- metalite::meta_adam(
    observation = metalite_sl_adsl,
    population = metalite_sl_adsl
  ) |>
    metalite::define_plan(sl_plan) |>
    metalite::define_population(
      name = "apat",
      group = "TRTA",
      subset = SAFFL == "Y"
    ) |>
    metalite::define_parameter(
      name = "age",
      var = "AGE",
      label = "Age (years)",
      vargroup = "AGEGR1"
    ) |>
    metalite::define_parameter(name = "gender", var = "SEX", label = "Gender") |>
    metalite::define_parameter(name = "race", var = "RACE", label = "Race") |>
    metalite::define_analysis(
      name = "base_char",
      title = "Participant Baseline Characteristics by Treatment Group"
    ) |>
    metalite::meta_build()

  analysis_plan <- metalite::plan(
    analysis = "ae_specific",
    population = "apat",
    observation = "wk12",
    parameter = "rel"
  )

  metadata_ae <- metalite::meta_adam(
    observation = metalite_sl_adae,
    population = metalite_sl_adsl
  ) |>
    metalite::define_plan(analysis_plan) |>
    metalite::define_population(
      name = "apat",
      group = "TRTA",
      subset = SAFFL == "Y",
      label = "All Participants as Treated"
    ) |>
    metalite::define_observation(
      name = "wk12",
      group = "TRTA",
      subset = SAFFL == "Y",
      label = "Weeks 0 to 12"
    ) |>
    metalite::define_parameter(
      name = "rel",
      term1 = "Drug-Related",
      term2 = "",
      subset = AEREL \%in\% c("POSSIBLE", "PROBABLE"),
      var = "AEDECOD",
      soc = "AEBODSYS",
      label = "Drug-related AEs"
    ) |>
    metalite::define_analysis(
      name = "ae_specific",
      title = "Participants With Drug-Related Adverse Events"
    ) |>
    metalite::meta_build()

  react_base_char(
    metadata_sl = metadata_sl,
    metadata_ae = metadata_ae,
    population = "apat",
    observation = "wk12",
    display_total = TRUE,
    sl_parameter = "age;gender;race",
    ae_subgroup = c("age", "race", "gender"),
    ae_specific = "rel",
    width = 1200
  )
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prepare_base_char_subgroup.R
\name{prepare_base_char_subgroup}
\alias{prepare_base_char_subgroup}
\title{Prepare data for treatment compliance table}
\usage{
prepare_base_char_subgroup(
  meta,
  population,
  analysis = "base_char_subgroup",
  parameter,
  subgroup_var,
  subgroup_header = c(meta$population[[population]]$group, subgroup_var)
)
}
\arguments{
\item{meta}{A metadata object created by metalite.}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{analysis}{A character value of analysis term name.
The term name is used as key to link information.}

\item{parameter}{A character value of parameter term name.
The term name is used as key to link information.}

\item{subgroup_var}{A character value of subgroup variable name in
observation data saved in \code{meta$data_observation}.}

\item{subgroup_header}{A character vector for column header hierarchy.
The first element will be the first level header and the second element
will be second level header.}
}
\value{
A list of analysis raw datasets.
}
\description{
Prepare data for treatment compliance table
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char_subgroup",
    population = "apat",
    observation = "apat",
    parameter = "age"
  )) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  metalite::define_analysis(
    name = "base_char_subgroup",
    title = "Participant by Age Category and Sex"
  ) |>
  metalite::meta_build()

outdata <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "age",
  subgroup_var = "TRTA",
  subgroup_header = c("SEX", "TRTA")
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{metalite_sl_adsl}
\alias{metalite_sl_adsl}
\title{A subject level demographic dataset}
\format{
A data frame with 254 rows and 54 variables.
}
\source{
\url{https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc}
}
\usage{
metalite_sl_adsl
}
\description{
A dataset containing the demographic information of a clinical trial
following the CDISC ADaM standard.
}
\details{
Definition of each variable can be found at
\url{https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc}.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rtf_sl_summary.R
\name{rtf_disposition}
\alias{rtf_disposition}
\title{Disposition table}
\usage{
rtf_disposition(
  outdata,
  source,
  col_rel_width = NULL,
  text_font_size = 9,
  orientation = "portrait",
  footnotes = NULL,
  title = NULL,
  path_outdata = NULL,
  path_outtable = NULL
)
}
\arguments{
\item{outdata}{An \code{outdata} object created by \code{\link[=prepare_sl_summary]{prepare_sl_summary()}}.}

\item{source}{A character value of the data source.}

\item{col_rel_width}{Column relative width in a vector e.g. c(2,1,1) refers to 2:1:1.
Default is NULL for equal column width.}

\item{text_font_size}{Text font size.  To vary text font size by column, use
numeric vector with length of vector equal to number of columns
displayed e.g. c(9,20,40).}

\item{orientation}{Orientation in 'portrait' or 'landscape'.}

\item{footnotes}{A character vector of table footnotes.}

\item{title}{Term "analysis", "observation" and "population") for collecting title from metadata or a character vector of table titles.}

\item{path_outdata}{A character string of the outdata path.}

\item{path_outtable}{A character string of the outtable path.}
}
\value{
A list of analysis raw datasets.
}
\description{
Disposition table
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "disp", population = "apat",
    observation = "apat", parameter = "disposition;medical-disposition"
  )) |>
  metalite::define_population(
    name = "apat", group = "TRTA", subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "disposition", var = "EOSSTT", label = "Trial Disposition",
    var_lower = "DCSREAS"
  ) |>
  metalite::define_parameter(
    name = "medical-disposition", var = "EOTSTT",
    label = "Participant Study Medication Disposition", var_lower = "DCTREAS"
  ) |>
  metalite::define_analysis(
    name = "disp", title = "Disposition of Participant"
  ) |>
  metalite::meta_build()

meta |>
  prepare_disposition(population = "apat", parameter = "disposition;medical-disposition") |>
  format_disposition() |>
  rtf_disposition(
    source = "Source: [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = tempfile(fileext = ".rtf")
  )
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{metalite_sl_adexsum}
\alias{metalite_sl_adexsum}
\title{ADEXSUM dataset}
\format{
A data frame with 508 rows and 50 variables.
}
\source{
\url{https://github.com/phuse-org/phuse-scripts/tree/master/data/sdtm/cdiscpilot01}
}
\usage{
metalite_sl_adexsum
}
\value{
An analysis data frame.
}
\description{
A dataset containing exposure details in Basic Data Structure (BDS).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prepare_exp_duration.R
\name{prepare_exp_duration}
\alias{prepare_exp_duration}
\title{Prepare data for exposure duration table}
\usage{
prepare_exp_duration(
  meta,
  analysis = "exp_dur",
  population = meta$plan[meta$plan$analysis == analysis, ]$population,
  parameter = paste(meta$plan[meta$plan$analysis == analysis, ]$parameter, collapse =
    ";")
)
}
\arguments{
\item{meta}{A metadata object created by metalite.}

\item{analysis}{A character value of analysis term name.
The term name is used as key to link information.}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{parameter}{A character value of parameter term name.
The term name is used as key to link information.}
}
\value{
A list of analysis raw datasets.
}
\description{
Prepare data for exposure duration table
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adexsum,
  observation = metalite_sl_adexsum
) |>
  metalite::define_plan(metalite::plan(
    analysis = "exp_dur", population = "apat",
    observation = "apat", parameter = "expdur"
  )) |>
  metalite::define_population(
    name = "apat", group = "TRTA", subset = APERIOD == 1 & AVAL > 0
  ) |>
  metalite::define_parameter(
    name = "expdur", subset = PARAMCD == "TRTDURD", var = "AVAL",
    label = "Exposure Duration (Days)", vargroup = "EXDURGR"
  ) |>
  metalite::define_analysis(
    name = "exp_dur", title = "Summary of Exposure Duration",
    label = "exposure duration table"
  ) |>
  metalite::meta_build()

meta |> prepare_exp_duration()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rtf_base_char_subgroup.R
\name{rtf_base_char_subgroup}
\alias{rtf_base_char_subgroup}
\title{Subgroup Analysis for Baseline Characteristic}
\usage{
rtf_base_char_subgroup(
  outdata,
  source,
  col_rel_width = NULL,
  text_font_size = 8,
  orientation = "landscape",
  footnotes = NULL,
  title = NULL,
  path_outdata = NULL,
  path_outtable = NULL
)
}
\arguments{
\item{outdata}{An \code{outdata} object created by \code{\link[=prepare_base_char_subgroup]{prepare_base_char_subgroup()}}}

\item{source}{A character value of the data source.}

\item{col_rel_width}{Column relative width in a vector e.g. c(2,1,1) refers to 2:1:1.
Default is NULL for equal column width.}

\item{text_font_size}{Text font size.  To vary text font size by column, use
numeric vector with length of vector equal to number of columns
displayed e.g. c(9,20,40).}

\item{orientation}{Orientation in 'portrait' or 'landscape'.}

\item{footnotes}{A character vector of table footnotes.}

\item{title}{Term "analysis", "observation" and "population") for collecting title from metadata or a character vector of table titles.}

\item{path_outdata}{A character string of the outdata path.}

\item{path_outtable}{A character string of the outtable path.}
}
\value{
RTF file and source dataset for baseline characteristic table.
}
\description{
Subgroup Analysis for Baseline Characteristic
}
\examples{
\donttest{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char_subgroup", population = "apat",
    observation = "apat", parameter = "age"
  )) |>
  metalite::define_population(
    name = "apat", group = "TRTA", subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age", var = "AGE", label = "Age (years)", vargroup = "AGEGR1"
  ) |>
  metalite::define_analysis(
    name = "base_char_subgroup", title = "Participant by Age Category and Sex"
  ) |>
  metalite::meta_build()

outdata <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "age",
  subgroup_var = "TRTA",
  subgroup_header = c("SEX", "TRTA")
)

outdata |>
  format_base_char_subgroup() |>
  rtf_base_char_subgroup(
    source = "Source:  [CDISCpilot: adam-adsl]",
    path_outdata = tempfile(fileext = ".Rdata"),
    path_outtable = tempfile(fileext = ".rtf")
  )
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/react_disposition.R
\name{react_disposition}
\alias{react_disposition}
\title{Display interactive disposition tables with AE subgroup analysis}
\usage{
react_disposition(
  metadata_sl,
  metadata_ae,
  analysis = "disp",
  trtvar = metalite::collect_adam_mapping(metadata_sl, population)$group,
  population = metadata_sl$plan$population[metadata_sl$plan$analysis == analysis],
  sl_parameter = paste(metadata_sl$plan$parameter[metadata_sl$plan$analysis == analysis],
    collapse = ";"),
  sl_col_selected = c("siteid", "subjid", "sex", "age", "weightbl"),
  sl_col_names = c("Site", "Subject ID", "Sex", "Age (Year)", "Weight (kg)"),
  ae_observation = "wk12",
  ae_population = population,
  ae_parameter = "any",
  ae_col_selected = c("AESOC", "ASTDT", "AENDT", "AETERM", "duration", "AESEV", "AESER",
    "related", "AEACN", "AEOUT"),
  ae_col_names = c("SOC", "Onset Date", "End Date", "AE", "Duraion", "Intensity",
    "Serious", "Related", "Action Taken", "Outcome"),
  display_total = TRUE,
  width = 1200
)
}
\arguments{
\item{metadata_sl}{A metadata created by metalite,
which builds the baseline characteristic table}

\item{metadata_ae}{A metadata created by metalite,
which builds the AE subgroup specific table}

\item{analysis}{The analysis label provided in \code{metadata_sl}.}

\item{trtvar}{A character that indicate variable for the treatment group.}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{sl_parameter}{A character value of parameter term name for
the baseline characteristic table.
The term name is used as key to link information.}

\item{sl_col_selected}{A character vector of variable which will be shown in the participant detail.}

\item{sl_col_names}{A character vector for the columns names of the participant detail. Same length as sl_col_selected.}

\item{ae_observation}{The meta parameter of the observation in adverse event listing.}

\item{ae_population}{The meta parameter of the population in adverse event listing.}

\item{ae_parameter}{A character value of the parameter in adverse event listing.}

\item{ae_col_selected}{A character vector of variable which will be shown in the AE detail.}

\item{ae_col_names}{A character vector for the columns names of the AE detail. Same length as ae_col_selected.}

\item{display_total}{Display total column or not.}

\item{width}{A numeric value of width of the table in pixels.}
}
\value{
An reactable combing both baseline characteristic table
and AE subgroup specific tables.
}
\description{
Display interactive disposition tables with AE subgroup analysis
}
\examples{
if (interactive()) {
  sl_plan <- metalite::plan(
    analysis = "disp",
    population = "apat",
    observation = "apat",
    parameter = "disposition;medical-disposition"
  )

  metadata_sl <- metalite::meta_adam(
    observation = metalite_sl_adsl,
    population = metalite_sl_adsl
  ) |>
    metalite::define_plan(sl_plan) |>
    metalite::define_population(
      name = "apat",
      group = "TRTA",
      subset = SAFFL == "Y"
    ) |>
    metalite::define_parameter(
      name = "disposition",
      var = "EOSSTT",
      label = "Trial Disposition",
      var_lower = "DCSREAS"
    ) |>
    metalite::define_parameter(
      name = "medical-disposition",
      var = "EOTSTT",
      label = "Participant Study Medication Disposition",
      var_lower = "DCTREAS"
    ) |>
    metalite::define_analysis(
      name = "disp",
      title = "Disposition of Participant"
    ) |>
    metalite::meta_build()

  analysis_plan <- metalite::plan(
    analysis = "ae_specific",
    population = "apat",
    observation = "wk12",
    parameter = "any"
  )

  metadata_ae <- metalite::meta_adam(
    observation = metalite_sl_adae,
    population = metalite_sl_adsl
  ) |>
    metalite::define_plan(analysis_plan) |>
    metalite::define_population(
      name = "apat",
      group = "TRTA",
      subset = SAFFL == "Y",
      label = "All Participants as Treated"
    ) |>
    metalite::define_observation(
      name = "wk12",
      group = "TRTA",
      subset = SAFFL == "Y",
      label = "Weeks 0 to 12"
    ) |>
    metalite::define_parameter(
      name = "any",
      term1 = "",
      term2 = "",
      var = "AEDECOD",
      soc = "AEBODSYS",
      label = "All AEs"
    ) |>
    metalite::define_analysis(
      name = "ae_specific",
      title = "Participants With Adverse Events"
    ) |>
    metalite::meta_build()

  react_disposition(
    metadata_sl = metadata_sl,
    metadata_ae = metadata_ae
  )
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/meta_sl.R
\name{meta_sl}
\alias{meta_sl}
\title{Create metadata for subject-level analysis table}
\usage{
meta_sl(
  dataset_population,
  dataset_observation = NULL,
  population_term,
  observation_term = NULL,
  parameter_term = "age;race;gender",
  parameter_var = "AGE^AGEGR1;RACE;SEX",
  parameter_labels = NULL,
  analysis_term = "base_char",
  analysis_title = "Participant Baseline Characteristics by Treatment Group",
  population_subset = SAFFL == "Y",
  observation_subset = NULL,
  population_label = "All Participants as Treated",
  treatment_group = "TRT01A"
)
}
\arguments{
\item{dataset_population}{Source dataset of population.}

\item{dataset_observation}{Source dataset of observation}

\item{population_term}{A character value of population term name.}

\item{observation_term}{A character value of observation term name.}

\item{parameter_term}{A character value of parameter term name.
If there are multiple terms, they are separated by the semicolon (;).}

\item{parameter_var}{A character value of parameter variable name.
If there are multiple variables, they are separated by the semicolon (;).
A group variable can be specified followed by a variable
and the hat symbol (^).}

\item{parameter_labels}{A character vector of parameter label name.
The length of vector should be the same as the number of parameter terms.
A label from an input data is used if \code{NA} for a variable is specified.}

\item{analysis_term}{A character value of analysis term name.}

\item{analysis_title}{A character value of analysis title name.}

\item{population_subset}{An unquoted condition for selecting the
populations from dataset of population.}

\item{observation_subset}{An unquoted condition for selecting the
populations from dataset of observation}

\item{population_label}{A character value of population label.}

\item{treatment_group}{A character value of treatment group name.}
}
\value{
A metalite object.
}
\description{
Create metadata for subject-level analysis table
}
\examples{
meta_sl(
  dataset_population = r2rtf::r2rtf_adsl,
  population_term = "apat",
  parameter_term = "age;race",
  parameter_var = "AGE^AGEGR1;RACE"
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prepare_disposition.R
\name{prepare_disposition}
\alias{prepare_disposition}
\title{Prepare data for treatment compliance table}
\usage{
prepare_disposition(
  meta,
  analysis = "disp",
  population = meta$plan[meta$plan$analysis == analysis, ]$population,
  parameter = paste(meta$plan[meta$plan$analysis == analysis, ]$parameter, collapse =
    ";")
)
}
\arguments{
\item{meta}{A metadata object created by metalite.}

\item{analysis}{A character value of analysis term name.
The term name is used as key to link information.}

\item{population}{A character value of population term name.
The term name is used as key to link information.}

\item{parameter}{A character value of parameter term name.
The term name is used as key to link information.}
}
\value{
A list of analysis raw datasets.
}
\description{
Prepare data for treatment compliance table
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "disp",
    population = "apat",
    observation = "apat",
    parameter = "disposition;medical-disposition"
  )) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "disposition",
    var = "EOSSTT",
    label = "Trial Disposition",
    var_lower = "DCSREAS"
  ) |>
  metalite::define_parameter(
    name = "medical-disposition",
    var = "EOTSTT",
    label = "Participant Study Medication Disposition",
    var_lower = "DCTREAS"
  ) |>
  metalite::define_analysis(
    name = "disp",
    title = "Disposition of Participant"
  ) |>
  metalite::meta_build()

meta |> prepare_disposition()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/format_base_char_subgroup.R
\name{format_base_char_subgroup}
\alias{format_base_char_subgroup}
\title{Prepare data for Subgroup Analysis for Baseline Characteristic}
\usage{
format_base_char_subgroup(
  outdata,
  display = c("n", "prop", "total"),
  display_stat = c("mean", "sd", "median", "range"),
  display_total = TRUE
)
}
\arguments{
\item{outdata}{A metadata object created by \code{\link[=prepare_base_char_subgroup]{prepare_base_char_subgroup()}}.}

\item{display}{Column wants to display on the table.
The term could be selected from \code{c("n", "prop", "total")}.
"total" can display the total column for the first level header.}

\item{display_stat}{A vector of statistics term name.
The term name could be selected from
\code{c("mean", "sd", "se", "median", "q1 to q3", "range", "q1", "q3", "min", "max")}.}

\item{display_total}{A logic value of displaying the total column
for the second level header.}
}
\value{
A list of analysis raw datasets.
}
\description{
Prepare data for Subgroup Analysis for Baseline Characteristic
}
\examples{
meta <- metalite::meta_adam(
  population = metalite_sl_adsl,
  observation = metalite_sl_adsl
) |>
  metalite::define_plan(metalite::plan(
    analysis = "base_char_subgroup",
    population = "apat",
    observation = "apat",
    parameter = "age"
  )) |>
  metalite::define_population(
    name = "apat",
    group = "TRTA",
    subset = SAFFL == "Y"
  ) |>
  metalite::define_parameter(
    name = "age",
    var = "AGE",
    label = "Age (years)",
    vargroup = "AGEGR1"
  ) |>
  metalite::define_analysis(
    name = "base_char_subgroup",
    title = "Participant by Age Category and Sex"
  ) |>
  metalite::meta_build()

outdata <- prepare_base_char_subgroup(
  meta,
  population = "apat",
  parameter = "age",
  subgroup_var = "TRTA",
  subgroup_header = c("SEX", "TRTA")
)

outdata |> format_base_char_subgroup()
}
